EXPECTED = {'EUTRA-InterNodeDefinitions': {'extensibility-implied': False,
                                'imports': {'EUTRA-RRC-Definitions': ['ARFCN-ValueEUTRA',
                                                                      'AntennaInfoCommon',
                                                                      'C-RNTI',
                                                                      'CellIdentity',
                                                                      'DL-DCCH-Message',
                                                                      'MasterInformationBlock',
                                                                      'MeasConfig',
                                                                      'PhysCellId',
                                                                      'RadioResourceConfigDedicated',
                                                                      'SecurityAlgorithmConfig',
                                                                      'ShortMAC-I',
                                                                      'SystemInformationBlockType1',
                                                                      'SystemInformationBlockType2',
                                                                      'UE-CapabilityRAT-ContainerList',
                                                                      'UECapabilityInformation']},
                                'object-classes': {},
                                'object-sets': {},
                                'tags': 'AUTOMATIC',
                                'types': {'AS-Config': {'members': [{'name': 'sourceMeasConfig',
                                                                     'type': 'MeasConfig'},
                                                                    {'name': 'sourceRadioResourceConfig',
                                                                     'type': 'RadioResourceConfigDedicated'},
                                                                    {'name': 'sourceSecurityAlgorithmConfig',
                                                                     'type': 'SecurityAlgorithmConfig'},
                                                                    {'name': 'sourceUE-Identity',
                                                                     'type': 'C-RNTI'},
                                                                    {'name': 'sourceMasterInformationBlock',
                                                                     'type': 'MasterInformationBlock'},
                                                                    {'name': 'sourceSystemInformationBlockType1',
                                                                     'type': 'SystemInformationBlockType1'},
                                                                    {'name': 'sourceSystemInformationBlockType2',
                                                                     'type': 'SystemInformationBlockType2'},
                                                                    {'name': 'antennaInfoCommon',
                                                                     'type': 'AntennaInfoCommon'},
                                                                    {'name': 'sourceDl-CarrierFreq',
                                                                     'type': 'ARFCN-ValueEUTRA'},
                                                                    None],
                                                        'type': 'SEQUENCE'},
                                          'AS-Context': {'members': [{'name': 'reestablishmentInfo',
                                                                      'optional': True,
                                                                      'type': 'ReestablishmentInfo'}],
                                                         'type': 'SEQUENCE'},
                                          'AdditionalReestabInfo': {'members': [{'name': 'cellIdentity',
                                                                                 'type': 'CellIdentity'},
                                                                                {'name': 'key-eNodeB-Star',
                                                                                 'type': 'Key-eNodeB-Star'},
                                                                                {'name': 'shortMAC-I',
                                                                                 'type': 'ShortMAC-I'}],
                                                                    'type': 'SEQUENCE'},
                                          'AdditionalReestabInfoList': {'element': {'type': 'AdditionalReestabInfo'},
                                                                        'size': [(1,
                                                                                  'maxReestabInfo')],
                                                                        'type': 'SEQUENCE '
                                                                                'OF'},
                                          'HandoverCommand': {'members': [{'members': [{'members': [{'name': 'handoverCommand-r8',
                                                                                                     'type': 'HandoverCommand-r8-IEs'},
                                                                                                    {'name': 'spare7',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare6',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare5',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare4',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare3',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare2',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare1',
                                                                                                     'type': 'NULL'}],
                                                                                        'name': 'c1',
                                                                                        'type': 'CHOICE'},
                                                                                       {'members': [],
                                                                                        'name': 'criticalExtensionsFuture',
                                                                                        'type': 'SEQUENCE'}],
                                                                           'name': 'criticalExtensions',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                          'HandoverCommand-r8-IEs': {'members': [{'name': 'handoverCommandMessage',
                                                                                  'type': 'OCTET '
                                                                                          'STRING'},
                                                                                 {'members': [],
                                                                                  'name': 'nonCriticalExtension',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'}],
                                                                     'type': 'SEQUENCE'},
                                          'HandoverPreparationInformation': {'members': [{'members': [{'members': [{'name': 'handoverPreparationInformation-r8',
                                                                                                                    'type': 'HandoverPreparationInformation-r8-IEs'},
                                                                                                                   {'name': 'spare7',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare6',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare5',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare4',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare3',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare2',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare1',
                                                                                                                    'type': 'NULL'}],
                                                                                                       'name': 'c1',
                                                                                                       'type': 'CHOICE'},
                                                                                                      {'members': [],
                                                                                                       'name': 'criticalExtensionsFuture',
                                                                                                       'type': 'SEQUENCE'}],
                                                                                          'name': 'criticalExtensions',
                                                                                          'type': 'CHOICE'}],
                                                                             'type': 'SEQUENCE'},
                                          'HandoverPreparationInformation-r8-IEs': {'members': [{'name': 'ue-RadioAccessCapabilityInfo',
                                                                                                 'type': 'UE-CapabilityRAT-ContainerList'},
                                                                                                {'name': 'as-Config',
                                                                                                 'optional': True,
                                                                                                 'type': 'AS-Config'},
                                                                                                {'name': 'rrm-Config',
                                                                                                 'optional': True,
                                                                                                 'type': 'RRM-Config'},
                                                                                                {'name': 'as-Context',
                                                                                                 'optional': True,
                                                                                                 'type': 'AS-Context'},
                                                                                                {'members': [],
                                                                                                 'name': 'nonCriticalExtension',
                                                                                                 'optional': True,
                                                                                                 'type': 'SEQUENCE'}],
                                                                                    'type': 'SEQUENCE'},
                                          'Key-eNodeB-Star': {'size': [256],
                                                              'type': 'BIT '
                                                                      'STRING'},
                                          'RRM-Config': {'members': [{'name': 'ue-InactiveTime',
                                                                      'optional': True,
                                                                      'type': 'ENUMERATED',
                                                                      'values': [('s1',
                                                                                  0),
                                                                                 ('s2',
                                                                                  1),
                                                                                 ('s3',
                                                                                  2),
                                                                                 ('s5',
                                                                                  3),
                                                                                 ('s7',
                                                                                  4),
                                                                                 ('s10',
                                                                                  5),
                                                                                 ('s15',
                                                                                  6),
                                                                                 ('s20',
                                                                                  7),
                                                                                 ('s25',
                                                                                  8),
                                                                                 ('s30',
                                                                                  9),
                                                                                 ('s40',
                                                                                  10),
                                                                                 ('s50',
                                                                                  11),
                                                                                 ('min1',
                                                                                  12),
                                                                                 ('min1s20c',
                                                                                  13),
                                                                                 ('min1s40',
                                                                                  14),
                                                                                 ('min2',
                                                                                  15),
                                                                                 ('min2s30',
                                                                                  16),
                                                                                 ('min3',
                                                                                  17),
                                                                                 ('min3s30',
                                                                                  18),
                                                                                 ('min4',
                                                                                  19),
                                                                                 ('min5',
                                                                                  20),
                                                                                 ('min6',
                                                                                  21),
                                                                                 ('min7',
                                                                                  22),
                                                                                 ('min8',
                                                                                  23),
                                                                                 ('min9',
                                                                                  24),
                                                                                 ('min10',
                                                                                  25),
                                                                                 ('min12',
                                                                                  26),
                                                                                 ('min14',
                                                                                  27),
                                                                                 ('min17',
                                                                                  28),
                                                                                 ('min20',
                                                                                  29),
                                                                                 ('min24',
                                                                                  30),
                                                                                 ('min28',
                                                                                  31),
                                                                                 ('min33',
                                                                                  32),
                                                                                 ('min38',
                                                                                  33),
                                                                                 ('min44',
                                                                                  34),
                                                                                 ('min50',
                                                                                  35),
                                                                                 ('hr1',
                                                                                  36),
                                                                                 ('hr1min30',
                                                                                  37),
                                                                                 ('hr2',
                                                                                  38),
                                                                                 ('hr2min30',
                                                                                  39),
                                                                                 ('hr3',
                                                                                  40),
                                                                                 ('hr3min30',
                                                                                  41),
                                                                                 ('hr4',
                                                                                  42),
                                                                                 ('hr5',
                                                                                  43),
                                                                                 ('hr6',
                                                                                  44),
                                                                                 ('hr8',
                                                                                  45),
                                                                                 ('hr10',
                                                                                  46),
                                                                                 ('hr13',
                                                                                  47),
                                                                                 ('hr16',
                                                                                  48),
                                                                                 ('hr20',
                                                                                  49),
                                                                                 ('day1',
                                                                                  50),
                                                                                 ('day1hr12',
                                                                                  51),
                                                                                 ('day2',
                                                                                  52),
                                                                                 ('day2hr12',
                                                                                  53),
                                                                                 ('day3',
                                                                                  54),
                                                                                 ('day4',
                                                                                  55),
                                                                                 ('day5',
                                                                                  56),
                                                                                 ('day7',
                                                                                  57),
                                                                                 ('day10',
                                                                                  58),
                                                                                 ('day14',
                                                                                  59),
                                                                                 ('day19',
                                                                                  60),
                                                                                 ('day24',
                                                                                  61),
                                                                                 ('day30',
                                                                                  62),
                                                                                 ('dayMoreThan30',
                                                                                  63)]},
                                                                     None],
                                                         'type': 'SEQUENCE'},
                                          'ReestablishmentInfo': {'members': [{'name': 'sourcePhysCellId',
                                                                               'type': 'PhysCellId'},
                                                                              {'name': 'targetCellShortMAC-I',
                                                                               'type': 'ShortMAC-I'},
                                                                              {'name': 'additionalReestabInfoList',
                                                                               'optional': True,
                                                                               'type': 'AdditionalReestabInfoList'},
                                                                              None],
                                                                  'type': 'SEQUENCE'},
                                          'UERadioAccessCapabilityInformation': {'members': [{'members': [{'members': [{'name': 'ueRadioAccessCapabilityInformation-r8',
                                                                                                                        'type': 'UERadioAccessCapabilityInformation-r8-IEs'},
                                                                                                                       {'name': 'spare7',
                                                                                                                        'type': 'NULL'},
                                                                                                                       {'name': 'spare6',
                                                                                                                        'type': 'NULL'},
                                                                                                                       {'name': 'spare5',
                                                                                                                        'type': 'NULL'},
                                                                                                                       {'name': 'spare4',
                                                                                                                        'type': 'NULL'},
                                                                                                                       {'name': 'spare3',
                                                                                                                        'type': 'NULL'},
                                                                                                                       {'name': 'spare2',
                                                                                                                        'type': 'NULL'},
                                                                                                                       {'name': 'spare1',
                                                                                                                        'type': 'NULL'}],
                                                                                                           'name': 'c1',
                                                                                                           'type': 'CHOICE'},
                                                                                                          {'members': [],
                                                                                                           'name': 'criticalExtensionsFuture',
                                                                                                           'type': 'SEQUENCE'}],
                                                                                              'name': 'criticalExtensions',
                                                                                              'type': 'CHOICE'}],
                                                                                 'type': 'SEQUENCE'},
                                          'UERadioAccessCapabilityInformation-r8-IEs': {'members': [{'name': 'ue-RadioAccessCapabilityInfo',
                                                                                                     'type': 'OCTET '
                                                                                                             'STRING'},
                                                                                                    {'members': [],
                                                                                                     'name': 'nonCriticalExtension',
                                                                                                     'optional': True,
                                                                                                     'type': 'SEQUENCE'}],
                                                                                        'type': 'SEQUENCE'}},
                                'values': {'maxReestabInfo': {'type': 'INTEGER',
                                                              'value': 32}}},
 'EUTRA-RRC-Definitions': {'extensibility-implied': False,
                           'imports': {},
                           'object-classes': {},
                           'object-sets': {},
                           'tags': 'AUTOMATIC',
                           'types': {'AC-BarringConfig': {'members': [{'name': 'ac-BarringFactor',
                                                                       'type': 'ENUMERATED',
                                                                       'values': [('p00',
                                                                                   0),
                                                                                  ('p05',
                                                                                   1),
                                                                                  ('p10',
                                                                                   2),
                                                                                  ('p15',
                                                                                   3),
                                                                                  ('p20',
                                                                                   4),
                                                                                  ('p25',
                                                                                   5),
                                                                                  ('p30',
                                                                                   6),
                                                                                  ('p40',
                                                                                   7),
                                                                                  ('p50',
                                                                                   8),
                                                                                  ('p60',
                                                                                   9),
                                                                                  ('p70',
                                                                                   10),
                                                                                  ('p75',
                                                                                   11),
                                                                                  ('p80',
                                                                                   12),
                                                                                  ('p85',
                                                                                   13),
                                                                                  ('p90',
                                                                                   14),
                                                                                  ('p95',
                                                                                   15)]},
                                                                      {'name': 'ac-BarringTime',
                                                                       'type': 'ENUMERATED',
                                                                       'values': [('s4',
                                                                                   0),
                                                                                  ('s8',
                                                                                   1),
                                                                                  ('s16',
                                                                                   2),
                                                                                  ('s32',
                                                                                   3),
                                                                                  ('s64',
                                                                                   4),
                                                                                  ('s128',
                                                                                   5),
                                                                                  ('s256',
                                                                                   6),
                                                                                  ('s512',
                                                                                   7)]},
                                                                      {'name': 'ac-BarringForSpecialAC',
                                                                       'size': [5],
                                                                       'type': 'BIT '
                                                                               'STRING'}],
                                                          'type': 'SEQUENCE'},
                                     'ARFCN-ValueCDMA2000': {'restricted-to': [(0,
                                                                                2047)],
                                                             'type': 'INTEGER'},
                                     'ARFCN-ValueEUTRA': {'restricted-to': [(0,
                                                                             'maxEARFCN')],
                                                          'type': 'INTEGER'},
                                     'ARFCN-ValueGERAN': {'restricted-to': [(0,
                                                                             1023)],
                                                          'type': 'INTEGER'},
                                     'ARFCN-ValueUTRA': {'restricted-to': [(0,
                                                                            16383)],
                                                         'type': 'INTEGER'},
                                     'AccessStratumRelease': {'type': 'ENUMERATED',
                                                              'values': [('rel8',
                                                                          0),
                                                                         ('spare7',
                                                                          1),
                                                                         ('spare6',
                                                                          2),
                                                                         ('spare5',
                                                                          3),
                                                                         ('spare4',
                                                                          4),
                                                                         ('spare3',
                                                                          5),
                                                                         ('spare2',
                                                                          6),
                                                                         ('spare1',
                                                                          7),
                                                                         None]},
                                     'AdditionalSpectrumEmission': {'restricted-to': [(1,
                                                                                       32)],
                                                                    'type': 'INTEGER'},
                                     'AllowedMeasBandwidth': {'type': 'ENUMERATED',
                                                              'values': [('mbw6',
                                                                          0),
                                                                         ('mbw15',
                                                                          1),
                                                                         ('mbw25',
                                                                          2),
                                                                         ('mbw50',
                                                                          3),
                                                                         ('mbw75',
                                                                          4),
                                                                         ('mbw100',
                                                                          5)]},
                                     'AntennaInfoCommon': {'members': [{'name': 'antennaPortsCount',
                                                                        'type': 'ENUMERATED',
                                                                        'values': [('an1',
                                                                                    0),
                                                                                   ('an2',
                                                                                    1),
                                                                                   ('an4',
                                                                                    2),
                                                                                   ('spare1',
                                                                                    3)]}],
                                                           'type': 'SEQUENCE'},
                                     'AntennaInfoDedicated': {'members': [{'name': 'transmissionMode',
                                                                           'type': 'ENUMERATED',
                                                                           'values': [('tm1',
                                                                                       0),
                                                                                      ('tm2',
                                                                                       1),
                                                                                      ('tm3',
                                                                                       2),
                                                                                      ('tm4',
                                                                                       3),
                                                                                      ('tm5',
                                                                                       4),
                                                                                      ('tm6',
                                                                                       5),
                                                                                      ('tm7',
                                                                                       6),
                                                                                      ('spare1',
                                                                                       7)]},
                                                                          {'members': [{'name': 'n2TxAntenna-tm3',
                                                                                        'size': [2],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'n4TxAntenna-tm3',
                                                                                        'size': [4],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'n2TxAntenna-tm4',
                                                                                        'size': [6],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'n4TxAntenna-tm4',
                                                                                        'size': [64],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'n2TxAntenna-tm5',
                                                                                        'size': [4],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'n4TxAntenna-tm5',
                                                                                        'size': [16],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'n2TxAntenna-tm6',
                                                                                        'size': [4],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'n4TxAntenna-tm6',
                                                                                        'size': [16],
                                                                                        'type': 'BIT '
                                                                                                'STRING'}],
                                                                           'name': 'codebookSubsetRestriction',
                                                                           'optional': True,
                                                                           'type': 'CHOICE'},
                                                                          {'members': [{'name': 'release',
                                                                                        'type': 'NULL'},
                                                                                       {'name': 'setup',
                                                                                        'type': 'ENUMERATED',
                                                                                        'values': [('closedLoop',
                                                                                                    0),
                                                                                                   ('openLoop',
                                                                                                    1)]}],
                                                                           'name': 'ue-TransmitAntennaSelection',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                     'BCCH-BCH-Message': {'members': [{'name': 'message',
                                                                       'type': 'BCCH-BCH-MessageType'}],
                                                          'type': 'SEQUENCE'},
                                     'BCCH-BCH-MessageType': {'type': 'MasterInformationBlock'},
                                     'BCCH-Config': {'members': [{'name': 'modificationPeriodCoeff',
                                                                  'type': 'ENUMERATED',
                                                                  'values': [('n2',
                                                                              0),
                                                                             ('n4',
                                                                              1),
                                                                             ('n8',
                                                                              2),
                                                                             ('n16',
                                                                              3)]}],
                                                     'type': 'SEQUENCE'},
                                     'BCCH-DL-SCH-Message': {'members': [{'name': 'message',
                                                                          'type': 'BCCH-DL-SCH-MessageType'}],
                                                             'type': 'SEQUENCE'},
                                     'BCCH-DL-SCH-MessageType': {'members': [{'members': [{'name': 'systemInformation',
                                                                                           'type': 'SystemInformation'},
                                                                                          {'name': 'systemInformationBlockType1',
                                                                                           'type': 'SystemInformationBlockType1'}],
                                                                              'name': 'c1',
                                                                              'type': 'CHOICE'},
                                                                             {'members': [],
                                                                              'name': 'messageClassExtension',
                                                                              'type': 'SEQUENCE'}],
                                                                 'type': 'CHOICE'},
                                     'BandClassInfoCDMA2000': {'members': [{'name': 'bandClass',
                                                                            'type': 'BandclassCDMA2000'},
                                                                           {'name': 'cellReselectionPriority',
                                                                            'optional': True,
                                                                            'type': 'CellReselectionPriority'},
                                                                           {'name': 'threshX-High',
                                                                            'restricted-to': [(0,
                                                                                               63)],
                                                                            'type': 'INTEGER'},
                                                                           {'name': 'threshX-Low',
                                                                            'restricted-to': [(0,
                                                                                               63)],
                                                                            'type': 'INTEGER'},
                                                                           None],
                                                               'type': 'SEQUENCE'},
                                     'BandClassListCDMA2000': {'element': {'type': 'BandClassInfoCDMA2000'},
                                                               'size': [(1,
                                                                         'maxCDMA-BandClass')],
                                                               'type': 'SEQUENCE '
                                                                       'OF'},
                                     'BandClassPriority1XRTT': {'members': [{'name': 'bandClass',
                                                                             'type': 'BandclassCDMA2000'},
                                                                            {'name': 'cellReselectionPriority',
                                                                             'type': 'CellReselectionPriority'}],
                                                                'type': 'SEQUENCE'},
                                     'BandClassPriorityHRPD': {'members': [{'name': 'bandClass',
                                                                            'type': 'BandclassCDMA2000'},
                                                                           {'name': 'cellReselectionPriority',
                                                                            'type': 'CellReselectionPriority'}],
                                                               'type': 'SEQUENCE'},
                                     'BandClassPriorityList1XRTT': {'element': {'type': 'BandClassPriority1XRTT'},
                                                                    'size': [(1,
                                                                              'maxCDMA-BandClass')],
                                                                    'type': 'SEQUENCE '
                                                                            'OF'},
                                     'BandClassPriorityListHRPD': {'element': {'type': 'BandClassPriorityHRPD'},
                                                                   'size': [(1,
                                                                             'maxCDMA-BandClass')],
                                                                   'type': 'SEQUENCE '
                                                                           'OF'},
                                     'BandIndicatorGERAN': {'type': 'ENUMERATED',
                                                            'values': [('dcs1800',
                                                                        0),
                                                                       ('pcs1900',
                                                                        1)]},
                                     'BandInfoEUTRA': {'members': [{'name': 'interFreqBandList',
                                                                    'type': 'InterFreqBandList'},
                                                                   {'name': 'interRAT-BandList',
                                                                    'optional': True,
                                                                    'type': 'InterRAT-BandList'}],
                                                       'type': 'SEQUENCE'},
                                     'BandListEUTRA': {'element': {'type': 'BandInfoEUTRA'},
                                                       'size': [(1,
                                                                 'maxBands')],
                                                       'type': 'SEQUENCE OF'},
                                     'BandclassCDMA2000': {'type': 'ENUMERATED',
                                                           'values': [('bc0',
                                                                       0),
                                                                      ('bc1',
                                                                       1),
                                                                      ('bc2',
                                                                       2),
                                                                      ('bc3',
                                                                       3),
                                                                      ('bc4',
                                                                       4),
                                                                      ('bc5',
                                                                       5),
                                                                      ('bc6',
                                                                       6),
                                                                      ('bc7',
                                                                       7),
                                                                      ('bc8',
                                                                       8),
                                                                      ('bc9',
                                                                       9),
                                                                      ('bc10',
                                                                       10),
                                                                      ('bc11',
                                                                       11),
                                                                      ('bc12',
                                                                       12),
                                                                      ('bc13',
                                                                       13),
                                                                      ('bc14',
                                                                       14),
                                                                      ('bc15',
                                                                       15),
                                                                      ('bc16',
                                                                       16),
                                                                      ('bc17',
                                                                       17),
                                                                      ('spare14',
                                                                       18),
                                                                      ('spare13',
                                                                       19),
                                                                      ('spare12',
                                                                       20),
                                                                      ('spare11',
                                                                       21),
                                                                      ('spare10',
                                                                       22),
                                                                      ('spare9',
                                                                       23),
                                                                      ('spare8',
                                                                       24),
                                                                      ('spare7',
                                                                       25),
                                                                      ('spare6',
                                                                       26),
                                                                      ('spare5',
                                                                       27),
                                                                      ('spare4',
                                                                       28),
                                                                      ('spare3',
                                                                       29),
                                                                      ('spare2',
                                                                       30),
                                                                      ('spare1',
                                                                       31),
                                                                      None]},
                                     'BlackCellsToAddMod': {'members': [{'name': 'cellIndex',
                                                                         'restricted-to': [(1,
                                                                                            'maxCellMeas')],
                                                                         'type': 'INTEGER'},
                                                                        {'name': 'physCellIdRange',
                                                                         'type': 'PhysCellIdRange'}],
                                                            'type': 'SEQUENCE'},
                                     'BlackCellsToAddModList': {'element': {'type': 'BlackCellsToAddMod'},
                                                                'size': [(1,
                                                                          'maxCellMeas')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'C-RNTI': {'size': [16],
                                                'type': 'BIT STRING'},
                                     'CDMA2000-Type': {'type': 'ENUMERATED',
                                                       'values': [('type1XRTT',
                                                                   0),
                                                                  ('typeHRPD',
                                                                   1)]},
                                     'CQI-ReportConfig': {'members': [{'name': 'cqi-ReportModeAperiodic',
                                                                       'optional': True,
                                                                       'type': 'ENUMERATED',
                                                                       'values': [('rm12',
                                                                                   0),
                                                                                  ('rm20',
                                                                                   1),
                                                                                  ('rm22',
                                                                                   2),
                                                                                  ('rm30',
                                                                                   3),
                                                                                  ('rm31',
                                                                                   4),
                                                                                  ('spare3',
                                                                                   5),
                                                                                  ('spare2',
                                                                                   6),
                                                                                  ('spare1',
                                                                                   7)]},
                                                                      {'name': 'nomPDSCH-RS-EPRE-Offset',
                                                                       'restricted-to': [(-1,
                                                                                          6)],
                                                                       'type': 'INTEGER'},
                                                                      {'name': 'cqi-ReportPeriodic',
                                                                       'optional': True,
                                                                       'type': 'CQI-ReportPeriodic'}],
                                                          'type': 'SEQUENCE'},
                                     'CQI-ReportPeriodic': {'members': [{'name': 'release',
                                                                         'type': 'NULL'},
                                                                        {'members': [{'name': 'cqi-PUCCH-ResourceIndex',
                                                                                      'restricted-to': [(0,
                                                                                                         1185)],
                                                                                      'type': 'INTEGER'},
                                                                                     {'name': 'cqi-pmi-ConfigIndex',
                                                                                      'restricted-to': [(0,
                                                                                                         1023)],
                                                                                      'type': 'INTEGER'},
                                                                                     {'members': [{'name': 'widebandCQI',
                                                                                                   'type': 'NULL'},
                                                                                                  {'members': [{'name': 'k',
                                                                                                                'restricted-to': [(1,
                                                                                                                                   4)],
                                                                                                                'type': 'INTEGER'}],
                                                                                                   'name': 'subbandCQI',
                                                                                                   'type': 'SEQUENCE'}],
                                                                                      'name': 'cqi-FormatIndicatorPeriodic',
                                                                                      'type': 'CHOICE'},
                                                                                     {'name': 'ri-ConfigIndex',
                                                                                      'optional': True,
                                                                                      'restricted-to': [(0,
                                                                                                         1023)],
                                                                                      'type': 'INTEGER'},
                                                                                     {'name': 'simultaneousAckNackAndCQI',
                                                                                      'type': 'BOOLEAN'}],
                                                                         'name': 'setup',
                                                                         'type': 'SEQUENCE'}],
                                                            'type': 'CHOICE'},
                                     'CSFB-RegistrationParam1XRTT': {'members': [{'name': 'sid',
                                                                                  'size': [15],
                                                                                  'type': 'BIT '
                                                                                          'STRING'},
                                                                                 {'name': 'nid',
                                                                                  'size': [16],
                                                                                  'type': 'BIT '
                                                                                          'STRING'},
                                                                                 {'name': 'multipleSID',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'multipleNID',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'homeReg',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'foreignSIDReg',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'foreignNIDReg',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'parameterReg',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'powerUpReg',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'registrationPeriod',
                                                                                  'size': [7],
                                                                                  'type': 'BIT '
                                                                                          'STRING'},
                                                                                 {'name': 'registrationZone',
                                                                                  'size': [12],
                                                                                  'type': 'BIT '
                                                                                          'STRING'},
                                                                                 {'name': 'totalZone',
                                                                                  'size': [3],
                                                                                  'type': 'BIT '
                                                                                          'STRING'},
                                                                                 {'name': 'zoneTimer',
                                                                                  'size': [3],
                                                                                  'type': 'BIT '
                                                                                          'STRING'}],
                                                                     'type': 'SEQUENCE'},
                                     'CSFBParametersRequestCDMA2000': {'members': [{'members': [{'name': 'csfbParametersRequestCDMA2000-r8',
                                                                                                 'type': 'CSFBParametersRequestCDMA2000-r8-IEs'},
                                                                                                {'members': [],
                                                                                                 'name': 'criticalExtensionsFuture',
                                                                                                 'type': 'SEQUENCE'}],
                                                                                    'name': 'criticalExtensions',
                                                                                    'type': 'CHOICE'}],
                                                                       'type': 'SEQUENCE'},
                                     'CSFBParametersRequestCDMA2000-r8-IEs': {'members': [{'members': [],
                                                                                           'name': 'nonCriticalExtension',
                                                                                           'optional': True,
                                                                                           'type': 'SEQUENCE'}],
                                                                              'type': 'SEQUENCE'},
                                     'CSFBParametersResponseCDMA2000': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                                     'type': 'RRC-TransactionIdentifier'},
                                                                                    {'members': [{'name': 'csfbParametersResponseCDMA2000-r8',
                                                                                                  'type': 'CSFBParametersResponseCDMA2000-r8-IEs'},
                                                                                                 {'members': [],
                                                                                                  'name': 'criticalExtensionsFuture',
                                                                                                  'type': 'SEQUENCE'}],
                                                                                     'name': 'criticalExtensions',
                                                                                     'type': 'CHOICE'}],
                                                                        'type': 'SEQUENCE'},
                                     'CSFBParametersResponseCDMA2000-r8-IEs': {'members': [{'name': 'rand',
                                                                                            'type': 'RAND-CDMA2000'},
                                                                                           {'name': 'mobilityParameters',
                                                                                            'type': 'MobilityParametersCDMA2000'},
                                                                                           {'members': [],
                                                                                            'name': 'nonCriticalExtension',
                                                                                            'optional': True,
                                                                                            'type': 'SEQUENCE'}],
                                                                               'type': 'SEQUENCE'},
                                     'CarrierBandwidthEUTRA': {'members': [{'name': 'dl-Bandwidth',
                                                                            'type': 'ENUMERATED',
                                                                            'values': [('n6',
                                                                                        0),
                                                                                       ('n15',
                                                                                        1),
                                                                                       ('n25',
                                                                                        2),
                                                                                       ('n50',
                                                                                        3),
                                                                                       ('n75',
                                                                                        4),
                                                                                       ('n100',
                                                                                        5),
                                                                                       ('spare10',
                                                                                        6),
                                                                                       ('spare9',
                                                                                        7),
                                                                                       ('spare8',
                                                                                        8),
                                                                                       ('spare7',
                                                                                        9),
                                                                                       ('spare6',
                                                                                        10),
                                                                                       ('spare5',
                                                                                        11),
                                                                                       ('spare4',
                                                                                        12),
                                                                                       ('spare3',
                                                                                        13),
                                                                                       ('spare2',
                                                                                        14),
                                                                                       ('spare1',
                                                                                        15)]},
                                                                           {'name': 'ul-Bandwidth',
                                                                            'optional': True,
                                                                            'type': 'ENUMERATED',
                                                                            'values': [('n6',
                                                                                        0),
                                                                                       ('n15',
                                                                                        1),
                                                                                       ('n25',
                                                                                        2),
                                                                                       ('n50',
                                                                                        3),
                                                                                       ('n75',
                                                                                        4),
                                                                                       ('n100',
                                                                                        5),
                                                                                       ('spare10',
                                                                                        6),
                                                                                       ('spare9',
                                                                                        7),
                                                                                       ('spare8',
                                                                                        8),
                                                                                       ('spare7',
                                                                                        9),
                                                                                       ('spare6',
                                                                                        10),
                                                                                       ('spare5',
                                                                                        11),
                                                                                       ('spare4',
                                                                                        12),
                                                                                       ('spare3',
                                                                                        13),
                                                                                       ('spare2',
                                                                                        14),
                                                                                       ('spare1',
                                                                                        15)]}],
                                                               'type': 'SEQUENCE'},
                                     'CarrierFreqCDMA2000': {'members': [{'name': 'bandClass',
                                                                          'type': 'BandclassCDMA2000'},
                                                                         {'name': 'arfcn',
                                                                          'type': 'ARFCN-ValueCDMA2000'}],
                                                             'type': 'SEQUENCE'},
                                     'CarrierFreqEUTRA': {'members': [{'name': 'dl-CarrierFreq',
                                                                       'type': 'ARFCN-ValueEUTRA'},
                                                                      {'name': 'ul-CarrierFreq',
                                                                       'optional': True,
                                                                       'type': 'ARFCN-ValueEUTRA'}],
                                                          'type': 'SEQUENCE'},
                                     'CarrierFreqGERAN': {'members': [{'name': 'arfcn',
                                                                       'type': 'ARFCN-ValueGERAN'},
                                                                      {'name': 'bandIndicator',
                                                                       'type': 'BandIndicatorGERAN'}],
                                                          'type': 'SEQUENCE'},
                                     'CarrierFreqListUTRA-FDD': {'element': {'type': 'CarrierFreqUTRA-FDD'},
                                                                 'size': [(1,
                                                                           'maxUTRA-FDD-Carrier')],
                                                                 'type': 'SEQUENCE '
                                                                         'OF'},
                                     'CarrierFreqListUTRA-TDD': {'element': {'type': 'CarrierFreqUTRA-TDD'},
                                                                 'size': [(1,
                                                                           'maxUTRA-TDD-Carrier')],
                                                                 'type': 'SEQUENCE '
                                                                         'OF'},
                                     'CarrierFreqUTRA-FDD': {'members': [{'name': 'carrierFreq',
                                                                          'type': 'ARFCN-ValueUTRA'},
                                                                         {'name': 'cellReselectionPriority',
                                                                          'optional': True,
                                                                          'type': 'CellReselectionPriority'},
                                                                         {'name': 'threshX-High',
                                                                          'type': 'ReselectionThreshold'},
                                                                         {'name': 'threshX-Low',
                                                                          'type': 'ReselectionThreshold'},
                                                                         {'name': 'q-RxLevMin',
                                                                          'restricted-to': [(-60,
                                                                                             -13)],
                                                                          'type': 'INTEGER'},
                                                                         {'name': 'p-MaxUTRA',
                                                                          'restricted-to': [(-50,
                                                                                             33)],
                                                                          'type': 'INTEGER'},
                                                                         {'name': 'q-QualMin',
                                                                          'restricted-to': [(-24,
                                                                                             0)],
                                                                          'type': 'INTEGER'},
                                                                         None],
                                                             'type': 'SEQUENCE'},
                                     'CarrierFreqUTRA-TDD': {'members': [{'name': 'carrierFreq',
                                                                          'type': 'ARFCN-ValueUTRA'},
                                                                         {'name': 'cellReselectionPriority',
                                                                          'optional': True,
                                                                          'type': 'CellReselectionPriority'},
                                                                         {'name': 'threshX-High',
                                                                          'type': 'ReselectionThreshold'},
                                                                         {'name': 'threshX-Low',
                                                                          'type': 'ReselectionThreshold'},
                                                                         {'name': 'q-RxLevMin',
                                                                          'restricted-to': [(-60,
                                                                                             -13)],
                                                                          'type': 'INTEGER'},
                                                                         {'name': 'p-MaxUTRA',
                                                                          'restricted-to': [(-50,
                                                                                             33)],
                                                                          'type': 'INTEGER'},
                                                                         None],
                                                             'type': 'SEQUENCE'},
                                     'CarrierFreqsGERAN': {'members': [{'name': 'startingARFCN',
                                                                        'type': 'ARFCN-ValueGERAN'},
                                                                       {'name': 'bandIndicator',
                                                                        'type': 'BandIndicatorGERAN'},
                                                                       {'members': [{'name': 'explicitListOfARFCNs',
                                                                                     'type': 'ExplicitListOfARFCNs'},
                                                                                    {'members': [{'name': 'arfcn-Spacing',
                                                                                                  'restricted-to': [(1,
                                                                                                                     8)],
                                                                                                  'type': 'INTEGER'},
                                                                                                 {'name': 'numberOfFollowingARFCNs',
                                                                                                  'restricted-to': [(0,
                                                                                                                     31)],
                                                                                                  'type': 'INTEGER'}],
                                                                                     'name': 'equallySpacedARFCNs',
                                                                                     'type': 'SEQUENCE'},
                                                                                    {'name': 'variableBitMapOfARFCNs',
                                                                                     'size': [(1,
                                                                                               16)],
                                                                                     'type': 'OCTET '
                                                                                             'STRING'}],
                                                                        'name': 'followingARFCNs',
                                                                        'type': 'CHOICE'}],
                                                           'type': 'SEQUENCE'},
                                     'CarrierFreqsInfoGERAN': {'members': [{'name': 'carrierFreqs',
                                                                            'type': 'CarrierFreqsGERAN'},
                                                                           {'members': [{'name': 'cellReselectionPriority',
                                                                                         'optional': True,
                                                                                         'type': 'CellReselectionPriority'},
                                                                                        {'name': 'ncc-Permitted',
                                                                                         'size': [8],
                                                                                         'type': 'BIT '
                                                                                                 'STRING'},
                                                                                        {'name': 'q-RxLevMin',
                                                                                         'restricted-to': [(0,
                                                                                                            45)],
                                                                                         'type': 'INTEGER'},
                                                                                        {'name': 'p-MaxGERAN',
                                                                                         'optional': True,
                                                                                         'restricted-to': [(0,
                                                                                                            39)],
                                                                                         'type': 'INTEGER'},
                                                                                        {'name': 'threshX-High',
                                                                                         'type': 'ReselectionThreshold'},
                                                                                        {'name': 'threshX-Low',
                                                                                         'type': 'ReselectionThreshold'}],
                                                                            'name': 'commonInfo',
                                                                            'type': 'SEQUENCE'},
                                                                           None],
                                                               'type': 'SEQUENCE'},
                                     'CarrierFreqsInfoListGERAN': {'element': {'type': 'CarrierFreqsInfoGERAN'},
                                                                   'size': [(1,
                                                                             'maxGNFG')],
                                                                   'type': 'SEQUENCE '
                                                                           'OF'},
                                     'CellChangeOrder': {'members': [{'name': 't304',
                                                                      'type': 'ENUMERATED',
                                                                      'values': [('ms100',
                                                                                  0),
                                                                                 ('ms200',
                                                                                  1),
                                                                                 ('ms500',
                                                                                  2),
                                                                                 ('ms1000',
                                                                                  3),
                                                                                 ('ms2000',
                                                                                  4),
                                                                                 ('ms4000',
                                                                                  5),
                                                                                 ('ms8000',
                                                                                  6),
                                                                                 ('spare1',
                                                                                  7)]},
                                                                     {'members': [{'members': [{'name': 'physCellId',
                                                                                                'type': 'PhysCellIdGERAN'},
                                                                                               {'name': 'carrierFreq',
                                                                                                'type': 'CarrierFreqGERAN'},
                                                                                               {'name': 'networkControlOrder',
                                                                                                'optional': True,
                                                                                                'size': [2],
                                                                                                'type': 'BIT '
                                                                                                        'STRING'},
                                                                                               {'name': 'systemInformation',
                                                                                                'optional': True,
                                                                                                'type': 'SI-OrPSI-GERAN'}],
                                                                                   'name': 'geran',
                                                                                   'type': 'SEQUENCE'},
                                                                                  None],
                                                                      'name': 'targetRAT-Type',
                                                                      'type': 'CHOICE'}],
                                                         'type': 'SEQUENCE'},
                                     'CellGlobalIdCDMA2000': {'members': [{'name': 'cellGlobalId1XRTT',
                                                                           'size': [47],
                                                                           'type': 'BIT '
                                                                                   'STRING'},
                                                                          {'name': 'cellGlobalIdHRPD',
                                                                           'size': [128],
                                                                           'type': 'BIT '
                                                                                   'STRING'}],
                                                              'type': 'CHOICE'},
                                     'CellGlobalIdEUTRA': {'members': [{'name': 'plmn-Identity',
                                                                        'type': 'PLMN-Identity'},
                                                                       {'name': 'cellIdentity',
                                                                        'type': 'CellIdentity'}],
                                                           'type': 'SEQUENCE'},
                                     'CellGlobalIdGERAN': {'members': [{'name': 'plmn-Identity',
                                                                        'type': 'PLMN-Identity'},
                                                                       {'name': 'locationAreaCode',
                                                                        'size': [16],
                                                                        'type': 'BIT '
                                                                                'STRING'},
                                                                       {'name': 'cellIdentity',
                                                                        'size': [16],
                                                                        'type': 'BIT '
                                                                                'STRING'}],
                                                           'type': 'SEQUENCE'},
                                     'CellGlobalIdUTRA': {'members': [{'name': 'plmn-Identity',
                                                                       'type': 'PLMN-Identity'},
                                                                      {'name': 'cellIdentity',
                                                                       'size': [28],
                                                                       'type': 'BIT '
                                                                               'STRING'}],
                                                          'type': 'SEQUENCE'},
                                     'CellIdentity': {'size': [28],
                                                      'type': 'BIT STRING'},
                                     'CellIndex': {'restricted-to': [(1,
                                                                      'maxCellMeas')],
                                                   'type': 'INTEGER'},
                                     'CellIndexList': {'element': {'type': 'CellIndex'},
                                                       'size': [(1,
                                                                 'maxCellMeas')],
                                                       'type': 'SEQUENCE OF'},
                                     'CellReselectionParametersCDMA2000': {'members': [{'name': 'bandClassList',
                                                                                        'type': 'BandClassListCDMA2000'},
                                                                                       {'name': 'neighCellList',
                                                                                        'type': 'NeighCellListCDMA2000'},
                                                                                       {'name': 't-ReselectionCDMA2000',
                                                                                        'type': 'T-Reselection'},
                                                                                       {'name': 't-ReselectionCDMA2000-SF',
                                                                                        'optional': True,
                                                                                        'type': 'SpeedStateScaleFactors'}],
                                                                           'type': 'SEQUENCE'},
                                     'CellReselectionPriority': {'restricted-to': [(0,
                                                                                    7)],
                                                                 'type': 'INTEGER'},
                                     'CellsToAddMod': {'members': [{'name': 'cellIndex',
                                                                    'restricted-to': [(1,
                                                                                       'maxCellMeas')],
                                                                    'type': 'INTEGER'},
                                                                   {'name': 'physCellId',
                                                                    'type': 'PhysCellId'},
                                                                   {'name': 'cellIndividualOffset',
                                                                    'type': 'Q-OffsetRange'}],
                                                       'type': 'SEQUENCE'},
                                     'CellsToAddModCDMA2000': {'members': [{'name': 'cellIndex',
                                                                            'restricted-to': [(1,
                                                                                               'maxCellMeas')],
                                                                            'type': 'INTEGER'},
                                                                           {'name': 'physCellId',
                                                                            'type': 'PhysCellIdCDMA2000'}],
                                                               'type': 'SEQUENCE'},
                                     'CellsToAddModList': {'element': {'type': 'CellsToAddMod'},
                                                           'size': [(1,
                                                                     'maxCellMeas')],
                                                           'type': 'SEQUENCE '
                                                                   'OF'},
                                     'CellsToAddModListCDMA2000': {'element': {'type': 'CellsToAddModCDMA2000'},
                                                                   'size': [(1,
                                                                             'maxCellMeas')],
                                                                   'type': 'SEQUENCE '
                                                                           'OF'},
                                     'CellsToAddModListUTRA-FDD': {'element': {'type': 'CellsToAddModUTRA-FDD'},
                                                                   'size': [(1,
                                                                             'maxCellMeas')],
                                                                   'type': 'SEQUENCE '
                                                                           'OF'},
                                     'CellsToAddModListUTRA-TDD': {'element': {'type': 'CellsToAddModUTRA-TDD'},
                                                                   'size': [(1,
                                                                             'maxCellMeas')],
                                                                   'type': 'SEQUENCE '
                                                                           'OF'},
                                     'CellsToAddModUTRA-FDD': {'members': [{'name': 'cellIndex',
                                                                            'restricted-to': [(1,
                                                                                               'maxCellMeas')],
                                                                            'type': 'INTEGER'},
                                                                           {'name': 'physCellId',
                                                                            'type': 'PhysCellIdUTRA-FDD'}],
                                                               'type': 'SEQUENCE'},
                                     'CellsToAddModUTRA-TDD': {'members': [{'name': 'cellIndex',
                                                                            'restricted-to': [(1,
                                                                                               'maxCellMeas')],
                                                                            'type': 'INTEGER'},
                                                                           {'name': 'physCellId',
                                                                            'type': 'PhysCellIdUTRA-TDD'}],
                                                               'type': 'SEQUENCE'},
                                     'CounterCheck': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                   'type': 'RRC-TransactionIdentifier'},
                                                                  {'members': [{'members': [{'name': 'counterCheck-r8',
                                                                                             'type': 'CounterCheck-r8-IEs'},
                                                                                            {'name': 'spare3',
                                                                                             'type': 'NULL'},
                                                                                            {'name': 'spare2',
                                                                                             'type': 'NULL'},
                                                                                            {'name': 'spare1',
                                                                                             'type': 'NULL'}],
                                                                                'name': 'c1',
                                                                                'type': 'CHOICE'},
                                                                               {'members': [],
                                                                                'name': 'criticalExtensionsFuture',
                                                                                'type': 'SEQUENCE'}],
                                                                   'name': 'criticalExtensions',
                                                                   'type': 'CHOICE'}],
                                                      'type': 'SEQUENCE'},
                                     'CounterCheck-r8-IEs': {'members': [{'name': 'drb-CountMSB-InfoList',
                                                                          'type': 'DRB-CountMSB-InfoList'},
                                                                         {'members': [],
                                                                          'name': 'nonCriticalExtension',
                                                                          'optional': True,
                                                                          'type': 'SEQUENCE'}],
                                                             'type': 'SEQUENCE'},
                                     'CounterCheckResponse': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                           'type': 'RRC-TransactionIdentifier'},
                                                                          {'members': [{'name': 'counterCheckResponse-r8',
                                                                                        'type': 'CounterCheckResponse-r8-IEs'},
                                                                                       {'members': [],
                                                                                        'name': 'criticalExtensionsFuture',
                                                                                        'type': 'SEQUENCE'}],
                                                                           'name': 'criticalExtensions',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                     'CounterCheckResponse-r8-IEs': {'members': [{'name': 'drb-CountInfoList',
                                                                                  'type': 'DRB-CountInfoList'},
                                                                                 {'members': [],
                                                                                  'name': 'nonCriticalExtension',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'}],
                                                                     'type': 'SEQUENCE'},
                                     'DL-AM-RLC': {'members': [{'name': 't-Reordering',
                                                                'type': 'T-Reordering'},
                                                               {'name': 't-StatusProhibit',
                                                                'type': 'T-StatusProhibit'}],
                                                   'type': 'SEQUENCE'},
                                     'DL-CCCH-Message': {'members': [{'name': 'message',
                                                                      'type': 'DL-CCCH-MessageType'}],
                                                         'type': 'SEQUENCE'},
                                     'DL-CCCH-MessageType': {'members': [{'members': [{'name': 'rrcConnectionReestablishment',
                                                                                       'type': 'RRCConnectionReestablishment'},
                                                                                      {'name': 'rrcConnectionReestablishmentReject',
                                                                                       'type': 'RRCConnectionReestablishmentReject'},
                                                                                      {'name': 'rrcConnectionReject',
                                                                                       'type': 'RRCConnectionReject'},
                                                                                      {'name': 'rrcConnectionSetup',
                                                                                       'type': 'RRCConnectionSetup'}],
                                                                          'name': 'c1',
                                                                          'type': 'CHOICE'},
                                                                         {'members': [],
                                                                          'name': 'messageClassExtension',
                                                                          'type': 'SEQUENCE'}],
                                                             'type': 'CHOICE'},
                                     'DL-DCCH-Message': {'members': [{'name': 'message',
                                                                      'type': 'DL-DCCH-MessageType'}],
                                                         'type': 'SEQUENCE'},
                                     'DL-DCCH-MessageType': {'members': [{'members': [{'name': 'csfbParametersResponseCDMA2000',
                                                                                       'type': 'CSFBParametersResponseCDMA2000'},
                                                                                      {'name': 'dlInformationTransfer',
                                                                                       'type': 'DLInformationTransfer'},
                                                                                      {'name': 'handoverFromEUTRAPreparationRequest',
                                                                                       'type': 'HandoverFromEUTRAPreparationRequest'},
                                                                                      {'name': 'mobilityFromEUTRACommand',
                                                                                       'type': 'MobilityFromEUTRACommand'},
                                                                                      {'name': 'rrcConnectionReconfiguration',
                                                                                       'type': 'RRCConnectionReconfiguration'},
                                                                                      {'name': 'rrcConnectionRelease',
                                                                                       'type': 'RRCConnectionRelease'},
                                                                                      {'name': 'securityModeCommand',
                                                                                       'type': 'SecurityModeCommand'},
                                                                                      {'name': 'ueCapabilityEnquiry',
                                                                                       'type': 'UECapabilityEnquiry'},
                                                                                      {'name': 'counterCheck',
                                                                                       'type': 'CounterCheck'},
                                                                                      {'name': 'spare7',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare6',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare5',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare4',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare3',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare2',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare1',
                                                                                       'type': 'NULL'}],
                                                                          'name': 'c1',
                                                                          'type': 'CHOICE'},
                                                                         {'members': [],
                                                                          'name': 'messageClassExtension',
                                                                          'type': 'SEQUENCE'}],
                                                             'type': 'CHOICE'},
                                     'DL-UM-RLC': {'members': [{'name': 'sn-FieldLength',
                                                                'type': 'SN-FieldLength'},
                                                               {'name': 't-Reordering',
                                                                'type': 'T-Reordering'}],
                                                   'type': 'SEQUENCE'},
                                     'DLInformationTransfer': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                            'type': 'RRC-TransactionIdentifier'},
                                                                           {'members': [{'members': [{'name': 'dlInformationTransfer-r8',
                                                                                                      'type': 'DLInformationTransfer-r8-IEs'},
                                                                                                     {'name': 'spare3',
                                                                                                      'type': 'NULL'},
                                                                                                     {'name': 'spare2',
                                                                                                      'type': 'NULL'},
                                                                                                     {'name': 'spare1',
                                                                                                      'type': 'NULL'}],
                                                                                         'name': 'c1',
                                                                                         'type': 'CHOICE'},
                                                                                        {'members': [],
                                                                                         'name': 'criticalExtensionsFuture',
                                                                                         'type': 'SEQUENCE'}],
                                                                            'name': 'criticalExtensions',
                                                                            'type': 'CHOICE'}],
                                                               'type': 'SEQUENCE'},
                                     'DLInformationTransfer-r8-IEs': {'members': [{'members': [{'name': 'dedicatedInfoNAS',
                                                                                                'type': 'DedicatedInfoNAS'},
                                                                                               {'name': 'dedicatedInfoCDMA2000-1XRTT',
                                                                                                'type': 'DedicatedInfoCDMA2000'},
                                                                                               {'name': 'dedicatedInfoCDMA2000-HRPD',
                                                                                                'type': 'DedicatedInfoCDMA2000'}],
                                                                                   'name': 'dedicatedInfoType',
                                                                                   'type': 'CHOICE'},
                                                                                  {'members': [],
                                                                                   'name': 'nonCriticalExtension',
                                                                                   'optional': True,
                                                                                   'type': 'SEQUENCE'}],
                                                                      'type': 'SEQUENCE'},
                                     'DRB-CountInfo': {'members': [{'name': 'drb-Identity',
                                                                    'type': 'DRB-Identity'},
                                                                   {'name': 'count-Uplink',
                                                                    'restricted-to': [(0,
                                                                                       4294967295)],
                                                                    'type': 'INTEGER'},
                                                                   {'name': 'count-Downlink',
                                                                    'restricted-to': [(0,
                                                                                       4294967295)],
                                                                    'type': 'INTEGER'}],
                                                       'type': 'SEQUENCE'},
                                     'DRB-CountInfoList': {'element': {'type': 'DRB-CountInfo'},
                                                           'size': [(0,
                                                                     'maxDRB')],
                                                           'type': 'SEQUENCE '
                                                                   'OF'},
                                     'DRB-CountMSB-Info': {'members': [{'name': 'drb-Identity',
                                                                        'type': 'DRB-Identity'},
                                                                       {'name': 'countMSB-Uplink',
                                                                        'restricted-to': [(0,
                                                                                           33554431)],
                                                                        'type': 'INTEGER'},
                                                                       {'name': 'countMSB-Downlink',
                                                                        'restricted-to': [(0,
                                                                                           33554431)],
                                                                        'type': 'INTEGER'}],
                                                           'type': 'SEQUENCE'},
                                     'DRB-CountMSB-InfoList': {'element': {'type': 'DRB-CountMSB-Info'},
                                                               'size': [(1,
                                                                         'maxDRB')],
                                                               'type': 'SEQUENCE '
                                                                       'OF'},
                                     'DRB-Identity': {'restricted-to': [(1,
                                                                         32)],
                                                      'type': 'INTEGER'},
                                     'DRB-ToAddMod': {'members': [{'name': 'eps-BearerIdentity',
                                                                   'optional': True,
                                                                   'restricted-to': [(0,
                                                                                      15)],
                                                                   'type': 'INTEGER'},
                                                                  {'name': 'drb-Identity',
                                                                   'type': 'DRB-Identity'},
                                                                  {'name': 'pdcp-Config',
                                                                   'optional': True,
                                                                   'type': 'PDCP-Config'},
                                                                  {'name': 'rlc-Config',
                                                                   'optional': True,
                                                                   'type': 'RLC-Config'},
                                                                  {'name': 'logicalChannelIdentity',
                                                                   'optional': True,
                                                                   'restricted-to': [(3,
                                                                                      10)],
                                                                   'type': 'INTEGER'},
                                                                  {'name': 'logicalChannelConfig',
                                                                   'optional': True,
                                                                   'type': 'LogicalChannelConfig'},
                                                                  None],
                                                      'type': 'SEQUENCE'},
                                     'DRB-ToAddModList': {'element': {'type': 'DRB-ToAddMod'},
                                                          'size': [(1,
                                                                    'maxDRB')],
                                                          'type': 'SEQUENCE '
                                                                  'OF'},
                                     'DRB-ToReleaseList': {'element': {'type': 'DRB-Identity'},
                                                           'size': [(1,
                                                                     'maxDRB')],
                                                           'type': 'SEQUENCE '
                                                                   'OF'},
                                     'DRX-Config': {'members': [{'name': 'release',
                                                                 'type': 'NULL'},
                                                                {'members': [{'name': 'onDurationTimer',
                                                                              'type': 'ENUMERATED',
                                                                              'values': [('psf1',
                                                                                          0),
                                                                                         ('psf2',
                                                                                          1),
                                                                                         ('psf3',
                                                                                          2),
                                                                                         ('psf4',
                                                                                          3),
                                                                                         ('psf5',
                                                                                          4),
                                                                                         ('psf6',
                                                                                          5),
                                                                                         ('psf8',
                                                                                          6),
                                                                                         ('psf10',
                                                                                          7),
                                                                                         ('psf20',
                                                                                          8),
                                                                                         ('psf30',
                                                                                          9),
                                                                                         ('psf40',
                                                                                          10),
                                                                                         ('psf50',
                                                                                          11),
                                                                                         ('psf60',
                                                                                          12),
                                                                                         ('psf80',
                                                                                          13),
                                                                                         ('psf100',
                                                                                          14),
                                                                                         ('psf200',
                                                                                          15)]},
                                                                             {'name': 'drx-InactivityTimer',
                                                                              'type': 'ENUMERATED',
                                                                              'values': [('psf1',
                                                                                          0),
                                                                                         ('psf2',
                                                                                          1),
                                                                                         ('psf3',
                                                                                          2),
                                                                                         ('psf4',
                                                                                          3),
                                                                                         ('psf5',
                                                                                          4),
                                                                                         ('psf6',
                                                                                          5),
                                                                                         ('psf8',
                                                                                          6),
                                                                                         ('psf10',
                                                                                          7),
                                                                                         ('psf20',
                                                                                          8),
                                                                                         ('psf30',
                                                                                          9),
                                                                                         ('psf40',
                                                                                          10),
                                                                                         ('psf50',
                                                                                          11),
                                                                                         ('psf60',
                                                                                          12),
                                                                                         ('psf80',
                                                                                          13),
                                                                                         ('psf100',
                                                                                          14),
                                                                                         ('psf200',
                                                                                          15),
                                                                                         ('psf300',
                                                                                          16),
                                                                                         ('psf500',
                                                                                          17),
                                                                                         ('psf750',
                                                                                          18),
                                                                                         ('psf1280',
                                                                                          19),
                                                                                         ('psf1920',
                                                                                          20),
                                                                                         ('psf2560',
                                                                                          21),
                                                                                         ('spare10',
                                                                                          22),
                                                                                         ('spare9',
                                                                                          23),
                                                                                         ('spare8',
                                                                                          24),
                                                                                         ('spare7',
                                                                                          25),
                                                                                         ('spare6',
                                                                                          26),
                                                                                         ('spare5',
                                                                                          27),
                                                                                         ('spare4',
                                                                                          28),
                                                                                         ('spare3',
                                                                                          29),
                                                                                         ('spare2',
                                                                                          30),
                                                                                         ('spare1',
                                                                                          31)]},
                                                                             {'name': 'drx-RetransmissionTimer',
                                                                              'type': 'ENUMERATED',
                                                                              'values': [('psf1',
                                                                                          0),
                                                                                         ('psf2',
                                                                                          1),
                                                                                         ('psf4',
                                                                                          2),
                                                                                         ('psf6',
                                                                                          3),
                                                                                         ('psf8',
                                                                                          4),
                                                                                         ('psf16',
                                                                                          5),
                                                                                         ('psf24',
                                                                                          6),
                                                                                         ('psf33',
                                                                                          7)]},
                                                                             {'members': [{'name': 'sf10',
                                                                                           'restricted-to': [(0,
                                                                                                              9)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf20',
                                                                                           'restricted-to': [(0,
                                                                                                              19)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf32',
                                                                                           'restricted-to': [(0,
                                                                                                              31)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf40',
                                                                                           'restricted-to': [(0,
                                                                                                              39)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf64',
                                                                                           'restricted-to': [(0,
                                                                                                              63)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf80',
                                                                                           'restricted-to': [(0,
                                                                                                              79)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf128',
                                                                                           'restricted-to': [(0,
                                                                                                              127)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf160',
                                                                                           'restricted-to': [(0,
                                                                                                              159)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf256',
                                                                                           'restricted-to': [(0,
                                                                                                              255)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf320',
                                                                                           'restricted-to': [(0,
                                                                                                              319)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf512',
                                                                                           'restricted-to': [(0,
                                                                                                              511)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf640',
                                                                                           'restricted-to': [(0,
                                                                                                              639)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf1024',
                                                                                           'restricted-to': [(0,
                                                                                                              1023)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf1280',
                                                                                           'restricted-to': [(0,
                                                                                                              1279)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf2048',
                                                                                           'restricted-to': [(0,
                                                                                                              2047)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf2560',
                                                                                           'restricted-to': [(0,
                                                                                                              2559)],
                                                                                           'type': 'INTEGER'}],
                                                                              'name': 'longDRX-CycleStartOffset',
                                                                              'type': 'CHOICE'},
                                                                             {'members': [{'name': 'shortDRX-Cycle',
                                                                                           'type': 'ENUMERATED',
                                                                                           'values': [('sf2',
                                                                                                       0),
                                                                                                      ('sf5',
                                                                                                       1),
                                                                                                      ('sf8',
                                                                                                       2),
                                                                                                      ('sf10',
                                                                                                       3),
                                                                                                      ('sf16',
                                                                                                       4),
                                                                                                      ('sf20',
                                                                                                       5),
                                                                                                      ('sf32',
                                                                                                       6),
                                                                                                      ('sf40',
                                                                                                       7),
                                                                                                      ('sf64',
                                                                                                       8),
                                                                                                      ('sf80',
                                                                                                       9),
                                                                                                      ('sf128',
                                                                                                       10),
                                                                                                      ('sf160',
                                                                                                       11),
                                                                                                      ('sf256',
                                                                                                       12),
                                                                                                      ('sf320',
                                                                                                       13),
                                                                                                      ('sf512',
                                                                                                       14),
                                                                                                      ('sf640',
                                                                                                       15)]},
                                                                                          {'name': 'drxShortCycleTimer',
                                                                                           'restricted-to': [(1,
                                                                                                              16)],
                                                                                           'type': 'INTEGER'}],
                                                                              'name': 'shortDRX',
                                                                              'optional': True,
                                                                              'type': 'SEQUENCE'}],
                                                                 'name': 'setup',
                                                                 'type': 'SEQUENCE'}],
                                                    'type': 'CHOICE'},
                                     'DedicatedInfoCDMA2000': {'type': 'OCTET '
                                                                       'STRING'},
                                     'DedicatedInfoNAS': {'type': 'OCTET '
                                                                  'STRING'},
                                     'DeltaFList-PUCCH': {'members': [{'name': 'deltaF-PUCCH-Format1',
                                                                       'type': 'ENUMERATED',
                                                                       'values': [('deltaF-2',
                                                                                   0),
                                                                                  ('deltaF0',
                                                                                   1),
                                                                                  ('deltaF2',
                                                                                   2)]},
                                                                      {'name': 'deltaF-PUCCH-Format1b',
                                                                       'type': 'ENUMERATED',
                                                                       'values': [('deltaF1',
                                                                                   0),
                                                                                  ('deltaF3',
                                                                                   1),
                                                                                  ('deltaF5',
                                                                                   2)]},
                                                                      {'name': 'deltaF-PUCCH-Format2',
                                                                       'type': 'ENUMERATED',
                                                                       'values': [('deltaF-2',
                                                                                   0),
                                                                                  ('deltaF0',
                                                                                   1),
                                                                                  ('deltaF1',
                                                                                   2),
                                                                                  ('deltaF2',
                                                                                   3)]},
                                                                      {'name': 'deltaF-PUCCH-Format2a',
                                                                       'type': 'ENUMERATED',
                                                                       'values': [('deltaF-2',
                                                                                   0),
                                                                                  ('deltaF0',
                                                                                   1),
                                                                                  ('deltaF2',
                                                                                   2)]},
                                                                      {'name': 'deltaF-PUCCH-Format2b',
                                                                       'type': 'ENUMERATED',
                                                                       'values': [('deltaF-2',
                                                                                   0),
                                                                                  ('deltaF0',
                                                                                   1),
                                                                                  ('deltaF2',
                                                                                   2)]}],
                                                          'type': 'SEQUENCE'},
                                     'EstablishmentCause': {'type': 'ENUMERATED',
                                                            'values': [('emergency',
                                                                        0),
                                                                       ('highPriorityAccess',
                                                                        1),
                                                                       ('mt-Access',
                                                                        2),
                                                                       ('mo-Signalling',
                                                                        3),
                                                                       ('mo-Data',
                                                                        4),
                                                                       ('spare3',
                                                                        5),
                                                                       ('spare2',
                                                                        6),
                                                                       ('spare1',
                                                                        7)]},
                                     'ExplicitListOfARFCNs': {'element': {'type': 'ARFCN-ValueGERAN'},
                                                              'size': [(0, 31)],
                                                              'type': 'SEQUENCE '
                                                                      'OF'},
                                     'FilterCoefficient': {'type': 'ENUMERATED',
                                                           'values': [('fc0',
                                                                       0),
                                                                      ('fc1',
                                                                       1),
                                                                      ('fc2',
                                                                       2),
                                                                      ('fc3',
                                                                       3),
                                                                      ('fc4',
                                                                       4),
                                                                      ('fc5',
                                                                       5),
                                                                      ('fc6',
                                                                       6),
                                                                      ('fc7',
                                                                       7),
                                                                      ('fc8',
                                                                       8),
                                                                      ('fc9',
                                                                       9),
                                                                      ('fc11',
                                                                       10),
                                                                      ('fc13',
                                                                       11),
                                                                      ('fc15',
                                                                       12),
                                                                      ('fc17',
                                                                       13),
                                                                      ('fc19',
                                                                       14),
                                                                      ('spare1',
                                                                       15),
                                                                      None]},
                                     'FreqPriorityEUTRA': {'members': [{'name': 'carrierFreq',
                                                                        'type': 'ARFCN-ValueEUTRA'},
                                                                       {'name': 'cellReselectionPriority',
                                                                        'type': 'CellReselectionPriority'}],
                                                           'type': 'SEQUENCE'},
                                     'FreqPriorityListEUTRA': {'element': {'type': 'FreqPriorityEUTRA'},
                                                               'size': [(1,
                                                                         'maxFreq')],
                                                               'type': 'SEQUENCE '
                                                                       'OF'},
                                     'FreqPriorityListUTRA-FDD': {'element': {'type': 'FreqPriorityUTRA-FDD'},
                                                                  'size': [(1,
                                                                            'maxUTRA-FDD-Carrier')],
                                                                  'type': 'SEQUENCE '
                                                                          'OF'},
                                     'FreqPriorityListUTRA-TDD': {'element': {'type': 'FreqPriorityUTRA-TDD'},
                                                                  'size': [(1,
                                                                            'maxUTRA-TDD-Carrier')],
                                                                  'type': 'SEQUENCE '
                                                                          'OF'},
                                     'FreqPriorityUTRA-FDD': {'members': [{'name': 'carrierFreq',
                                                                           'type': 'ARFCN-ValueUTRA'},
                                                                          {'name': 'cellReselectionPriority',
                                                                           'type': 'CellReselectionPriority'}],
                                                              'type': 'SEQUENCE'},
                                     'FreqPriorityUTRA-TDD': {'members': [{'name': 'carrierFreq',
                                                                           'type': 'ARFCN-ValueUTRA'},
                                                                          {'name': 'cellReselectionPriority',
                                                                           'type': 'CellReselectionPriority'}],
                                                              'type': 'SEQUENCE'},
                                     'FreqsPriorityGERAN': {'members': [{'name': 'carrierFreqs',
                                                                         'type': 'CarrierFreqsGERAN'},
                                                                        {'name': 'cellReselectionPriority',
                                                                         'type': 'CellReselectionPriority'}],
                                                            'type': 'SEQUENCE'},
                                     'FreqsPriorityListGERAN': {'element': {'type': 'FreqsPriorityGERAN'},
                                                                'size': [(1,
                                                                          'maxGNFG')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'Handover': {'members': [{'name': 'targetRAT-Type',
                                                               'type': 'ENUMERATED',
                                                               'values': [('utra',
                                                                           0),
                                                                          ('geran',
                                                                           1),
                                                                          ('cdma2000-1XRTT',
                                                                           2),
                                                                          ('cdma2000-HRPD',
                                                                           3),
                                                                          ('spare4',
                                                                           4),
                                                                          ('spare3',
                                                                           5),
                                                                          ('spare2',
                                                                           6),
                                                                          ('spare1',
                                                                           7),
                                                                          None]},
                                                              {'name': 'targetRAT-MessageContainer',
                                                               'type': 'OCTET '
                                                                       'STRING'},
                                                              {'name': 'nas-SecurityParamFromEUTRA',
                                                               'optional': True,
                                                               'size': [1],
                                                               'type': 'OCTET '
                                                                       'STRING'},
                                                              {'name': 'systemInformation',
                                                               'optional': True,
                                                               'type': 'SI-OrPSI-GERAN'}],
                                                  'type': 'SEQUENCE'},
                                     'HandoverFromEUTRAPreparationRequest': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                                          'type': 'RRC-TransactionIdentifier'},
                                                                                         {'members': [{'members': [{'name': 'handoverFromEUTRAPreparationRequest-r8',
                                                                                                                    'type': 'HandoverFromEUTRAPreparationRequest-r8-IEs'},
                                                                                                                   {'name': 'spare3',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare2',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare1',
                                                                                                                    'type': 'NULL'}],
                                                                                                       'name': 'c1',
                                                                                                       'type': 'CHOICE'},
                                                                                                      {'members': [],
                                                                                                       'name': 'criticalExtensionsFuture',
                                                                                                       'type': 'SEQUENCE'}],
                                                                                          'name': 'criticalExtensions',
                                                                                          'type': 'CHOICE'}],
                                                                             'type': 'SEQUENCE'},
                                     'HandoverFromEUTRAPreparationRequest-r8-IEs': {'members': [{'name': 'cdma2000-Type',
                                                                                                 'type': 'CDMA2000-Type'},
                                                                                                {'name': 'rand',
                                                                                                 'optional': True,
                                                                                                 'type': 'RAND-CDMA2000'},
                                                                                                {'name': 'mobilityParameters',
                                                                                                 'optional': True,
                                                                                                 'type': 'MobilityParametersCDMA2000'},
                                                                                                {'members': [],
                                                                                                 'name': 'nonCriticalExtension',
                                                                                                 'optional': True,
                                                                                                 'type': 'SEQUENCE'}],
                                                                                    'type': 'SEQUENCE'},
                                     'Hysteresis': {'restricted-to': [(0, 30)],
                                                    'type': 'INTEGER'},
                                     'IMSI': {'element': {'type': 'IMSI-Digit'},
                                              'size': [(6, 21)],
                                              'type': 'SEQUENCE OF'},
                                     'IMSI-Digit': {'restricted-to': [(0, 9)],
                                                    'type': 'INTEGER'},
                                     'IRAT-ParametersCDMA2000-1XRTT': {'members': [{'name': 'supportedBandList1XRTT',
                                                                                    'type': 'SupportedBandList1XRTT'},
                                                                                   {'name': 'tx-Config1XRTT',
                                                                                    'type': 'ENUMERATED',
                                                                                    'values': [('single',
                                                                                                0),
                                                                                               ('dual',
                                                                                                1)]},
                                                                                   {'name': 'rx-Config1XRTT',
                                                                                    'type': 'ENUMERATED',
                                                                                    'values': [('single',
                                                                                                0),
                                                                                               ('dual',
                                                                                                1)]}],
                                                                       'type': 'SEQUENCE'},
                                     'IRAT-ParametersCDMA2000-HRPD': {'members': [{'name': 'supportedBandListHRPD',
                                                                                   'type': 'SupportedBandListHRPD'},
                                                                                  {'name': 'tx-ConfigHRPD',
                                                                                   'type': 'ENUMERATED',
                                                                                   'values': [('single',
                                                                                               0),
                                                                                              ('dual',
                                                                                               1)]},
                                                                                  {'name': 'rx-ConfigHRPD',
                                                                                   'type': 'ENUMERATED',
                                                                                   'values': [('single',
                                                                                               0),
                                                                                              ('dual',
                                                                                               1)]}],
                                                                      'type': 'SEQUENCE'},
                                     'IRAT-ParametersGERAN': {'members': [{'name': 'supportedBandListGERAN',
                                                                           'type': 'SupportedBandListGERAN'},
                                                                          {'name': 'interRAT-PS-HO-ToGERAN',
                                                                           'type': 'BOOLEAN'}],
                                                              'type': 'SEQUENCE'},
                                     'IRAT-ParametersUTRA-FDD': {'members': [{'name': 'supportedBandListUTRA-FDD',
                                                                              'type': 'SupportedBandListUTRA-FDD'}],
                                                                 'type': 'SEQUENCE'},
                                     'IRAT-ParametersUTRA-TDD128': {'members': [{'name': 'supportedBandListUTRA-TDD128',
                                                                                 'type': 'SupportedBandListUTRA-TDD128'}],
                                                                    'type': 'SEQUENCE'},
                                     'IRAT-ParametersUTRA-TDD384': {'members': [{'name': 'supportedBandListUTRA-TDD384',
                                                                                 'type': 'SupportedBandListUTRA-TDD384'}],
                                                                    'type': 'SEQUENCE'},
                                     'IRAT-ParametersUTRA-TDD768': {'members': [{'name': 'supportedBandListUTRA-TDD768',
                                                                                 'type': 'SupportedBandListUTRA-TDD768'}],
                                                                    'type': 'SEQUENCE'},
                                     'IdleModeMobilityControlInfo': {'members': [{'name': 'freqPriorityListEUTRA',
                                                                                  'optional': True,
                                                                                  'type': 'FreqPriorityListEUTRA'},
                                                                                 {'name': 'freqPriorityListGERAN',
                                                                                  'optional': True,
                                                                                  'type': 'FreqsPriorityListGERAN'},
                                                                                 {'name': 'freqPriorityListUTRA-FDD',
                                                                                  'optional': True,
                                                                                  'type': 'FreqPriorityListUTRA-FDD'},
                                                                                 {'name': 'freqPriorityListUTRA-TDD',
                                                                                  'optional': True,
                                                                                  'type': 'FreqPriorityListUTRA-TDD'},
                                                                                 {'name': 'bandClassPriorityListHRPD',
                                                                                  'optional': True,
                                                                                  'type': 'BandClassPriorityListHRPD'},
                                                                                 {'name': 'bandClassPriorityList1XRTT',
                                                                                  'optional': True,
                                                                                  'type': 'BandClassPriorityList1XRTT'},
                                                                                 {'name': 't320',
                                                                                  'optional': True,
                                                                                  'type': 'ENUMERATED',
                                                                                  'values': [('min5',
                                                                                              0),
                                                                                             ('min10',
                                                                                              1),
                                                                                             ('min20',
                                                                                              2),
                                                                                             ('min30',
                                                                                              3),
                                                                                             ('min60',
                                                                                              4),
                                                                                             ('min120',
                                                                                              5),
                                                                                             ('min180',
                                                                                              6),
                                                                                             ('spare1',
                                                                                              7)]},
                                                                                 None],
                                                                     'type': 'SEQUENCE'},
                                     'InitialUE-Identity': {'members': [{'name': 's-TMSI',
                                                                         'type': 'S-TMSI'},
                                                                        {'name': 'randomValue',
                                                                         'size': [40],
                                                                         'type': 'BIT '
                                                                                 'STRING'}],
                                                            'type': 'CHOICE'},
                                     'InterFreqBandInfo': {'members': [{'name': 'interFreqNeedForGaps',
                                                                        'type': 'BOOLEAN'}],
                                                           'type': 'SEQUENCE'},
                                     'InterFreqBandList': {'element': {'type': 'InterFreqBandInfo'},
                                                           'size': [(1,
                                                                     'maxBands')],
                                                           'type': 'SEQUENCE '
                                                                   'OF'},
                                     'InterFreqBlackCellList': {'element': {'type': 'PhysCellIdRange'},
                                                                'size': [(1,
                                                                          'maxCellBlack')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'InterFreqCarrierFreqInfo': {'members': [{'name': 'dl-CarrierFreq',
                                                                               'type': 'ARFCN-ValueEUTRA'},
                                                                              {'name': 'q-RxLevMin',
                                                                               'type': 'Q-RxLevMin'},
                                                                              {'name': 'p-Max',
                                                                               'optional': True,
                                                                               'type': 'P-Max'},
                                                                              {'name': 't-ReselectionEUTRA',
                                                                               'type': 'T-Reselection'},
                                                                              {'name': 't-ReselectionEUTRA-SF',
                                                                               'optional': True,
                                                                               'type': 'SpeedStateScaleFactors'},
                                                                              {'name': 'threshX-High',
                                                                               'type': 'ReselectionThreshold'},
                                                                              {'name': 'threshX-Low',
                                                                               'type': 'ReselectionThreshold'},
                                                                              {'name': 'allowedMeasBandwidth',
                                                                               'type': 'AllowedMeasBandwidth'},
                                                                              {'name': 'presenceAntennaPort1',
                                                                               'type': 'PresenceAntennaPort1'},
                                                                              {'name': 'cellReselectionPriority',
                                                                               'optional': True,
                                                                               'type': 'CellReselectionPriority'},
                                                                              {'name': 'neighCellConfig',
                                                                               'type': 'NeighCellConfig'},
                                                                              {'default': 'dB0',
                                                                               'name': 'q-OffsetFreq',
                                                                               'type': 'Q-OffsetRange'},
                                                                              {'name': 'interFreqNeighCellList',
                                                                               'optional': True,
                                                                               'type': 'InterFreqNeighCellList'},
                                                                              {'name': 'interFreqBlackCellList',
                                                                               'optional': True,
                                                                               'type': 'InterFreqBlackCellList'},
                                                                              None],
                                                                  'type': 'SEQUENCE'},
                                     'InterFreqCarrierFreqList': {'element': {'type': 'InterFreqCarrierFreqInfo'},
                                                                  'size': [(1,
                                                                            'maxFreq')],
                                                                  'type': 'SEQUENCE '
                                                                          'OF'},
                                     'InterFreqNeighCellInfo': {'members': [{'name': 'physCellId',
                                                                             'type': 'PhysCellId'},
                                                                            {'name': 'q-OffsetCell',
                                                                             'type': 'Q-OffsetRange'}],
                                                                'type': 'SEQUENCE'},
                                     'InterFreqNeighCellList': {'element': {'type': 'InterFreqNeighCellInfo'},
                                                                'size': [(1,
                                                                          'maxCellInter')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'InterRAT-BandInfo': {'members': [{'name': 'interRAT-NeedForGaps',
                                                                        'type': 'BOOLEAN'}],
                                                           'type': 'SEQUENCE'},
                                     'InterRAT-BandList': {'element': {'type': 'InterRAT-BandInfo'},
                                                           'size': [(1,
                                                                     'maxBands')],
                                                           'type': 'SEQUENCE '
                                                                   'OF'},
                                     'IntraFreqBlackCellList': {'element': {'type': 'PhysCellIdRange'},
                                                                'size': [(1,
                                                                          'maxCellBlack')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'IntraFreqNeighCellInfo': {'members': [{'name': 'physCellId',
                                                                             'type': 'PhysCellId'},
                                                                            {'name': 'q-OffsetCell',
                                                                             'type': 'Q-OffsetRange'},
                                                                            None],
                                                                'type': 'SEQUENCE'},
                                     'IntraFreqNeighCellList': {'element': {'type': 'IntraFreqNeighCellInfo'},
                                                                'size': [(1,
                                                                          'maxCellIntra')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'LogicalChannelConfig': {'members': [{'members': [{'name': 'priority',
                                                                                        'restricted-to': [(1,
                                                                                                           16)],
                                                                                        'type': 'INTEGER'},
                                                                                       {'name': 'prioritisedBitRate',
                                                                                        'type': 'ENUMERATED',
                                                                                        'values': [('kBps0',
                                                                                                    0),
                                                                                                   ('kBps8',
                                                                                                    1),
                                                                                                   ('kBps16',
                                                                                                    2),
                                                                                                   ('kBps32',
                                                                                                    3),
                                                                                                   ('kBps64',
                                                                                                    4),
                                                                                                   ('kBps128',
                                                                                                    5),
                                                                                                   ('kBps256',
                                                                                                    6),
                                                                                                   ('infinity',
                                                                                                    7),
                                                                                                   ('spare8',
                                                                                                    8),
                                                                                                   ('spare7',
                                                                                                    9),
                                                                                                   ('spare6',
                                                                                                    10),
                                                                                                   ('spare5',
                                                                                                    11),
                                                                                                   ('spare4',
                                                                                                    12),
                                                                                                   ('spare3',
                                                                                                    13),
                                                                                                   ('spare2',
                                                                                                    14),
                                                                                                   ('spare1',
                                                                                                    15)]},
                                                                                       {'name': 'bucketSizeDuration',
                                                                                        'type': 'ENUMERATED',
                                                                                        'values': [('ms50',
                                                                                                    0),
                                                                                                   ('ms100',
                                                                                                    1),
                                                                                                   ('ms150',
                                                                                                    2),
                                                                                                   ('ms300',
                                                                                                    3),
                                                                                                   ('ms500',
                                                                                                    4),
                                                                                                   ('ms1000',
                                                                                                    5),
                                                                                                   ('spare2',
                                                                                                    6),
                                                                                                   ('spare1',
                                                                                                    7)]},
                                                                                       {'name': 'logicalChannelGroup',
                                                                                        'optional': True,
                                                                                        'restricted-to': [(0,
                                                                                                           3)],
                                                                                        'type': 'INTEGER'}],
                                                                           'name': 'ul-SpecificParameters',
                                                                           'optional': True,
                                                                           'type': 'SEQUENCE'},
                                                                          None],
                                                              'type': 'SEQUENCE'},
                                     'MAC-MainConfig': {'members': [{'members': [{'name': 'maxHARQ-Tx',
                                                                                  'optional': True,
                                                                                  'type': 'ENUMERATED',
                                                                                  'values': [('n1',
                                                                                              0),
                                                                                             ('n2',
                                                                                              1),
                                                                                             ('n3',
                                                                                              2),
                                                                                             ('n4',
                                                                                              3),
                                                                                             ('n5',
                                                                                              4),
                                                                                             ('n6',
                                                                                              5),
                                                                                             ('n7',
                                                                                              6),
                                                                                             ('n8',
                                                                                              7),
                                                                                             ('n10',
                                                                                              8),
                                                                                             ('n12',
                                                                                              9),
                                                                                             ('n16',
                                                                                              10),
                                                                                             ('n20',
                                                                                              11),
                                                                                             ('n24',
                                                                                              12),
                                                                                             ('n28',
                                                                                              13),
                                                                                             ('spare2',
                                                                                              14),
                                                                                             ('spare1',
                                                                                              15)]},
                                                                                 {'name': 'periodicBSR-Timer',
                                                                                  'optional': True,
                                                                                  'type': 'ENUMERATED',
                                                                                  'values': [('sf5',
                                                                                              0),
                                                                                             ('sf10',
                                                                                              1),
                                                                                             ('sf16',
                                                                                              2),
                                                                                             ('sf20',
                                                                                              3),
                                                                                             ('sf32',
                                                                                              4),
                                                                                             ('sf40',
                                                                                              5),
                                                                                             ('sf64',
                                                                                              6),
                                                                                             ('sf80',
                                                                                              7),
                                                                                             ('sf128',
                                                                                              8),
                                                                                             ('sf160',
                                                                                              9),
                                                                                             ('sf320',
                                                                                              10),
                                                                                             ('sf640',
                                                                                              11),
                                                                                             ('sf1280',
                                                                                              12),
                                                                                             ('sf2560',
                                                                                              13),
                                                                                             ('infinity',
                                                                                              14),
                                                                                             ('spare1',
                                                                                              15)]},
                                                                                 {'name': 'retxBSR-Timer',
                                                                                  'type': 'ENUMERATED',
                                                                                  'values': [('sf320',
                                                                                              0),
                                                                                             ('sf640',
                                                                                              1),
                                                                                             ('sf1280',
                                                                                              2),
                                                                                             ('sf2560',
                                                                                              3),
                                                                                             ('sf5120',
                                                                                              4),
                                                                                             ('sf10240',
                                                                                              5),
                                                                                             ('spare2',
                                                                                              6),
                                                                                             ('spare1',
                                                                                              7)]},
                                                                                 {'name': 'ttiBundling',
                                                                                  'type': 'BOOLEAN'}],
                                                                     'name': 'ul-SCH-Config',
                                                                     'optional': True,
                                                                     'type': 'SEQUENCE'},
                                                                    {'name': 'drx-Config',
                                                                     'optional': True,
                                                                     'type': 'DRX-Config'},
                                                                    {'name': 'timeAlignmentTimerDedicated',
                                                                     'type': 'TimeAlignmentTimer'},
                                                                    {'members': [{'name': 'release',
                                                                                  'type': 'NULL'},
                                                                                 {'members': [{'name': 'periodicPHR-Timer',
                                                                                               'type': 'ENUMERATED',
                                                                                               'values': [('sf10',
                                                                                                           0),
                                                                                                          ('sf20',
                                                                                                           1),
                                                                                                          ('sf50',
                                                                                                           2),
                                                                                                          ('sf100',
                                                                                                           3),
                                                                                                          ('sf200',
                                                                                                           4),
                                                                                                          ('sf500',
                                                                                                           5),
                                                                                                          ('sf1000',
                                                                                                           6),
                                                                                                          ('infinity',
                                                                                                           7)]},
                                                                                              {'name': 'prohibitPHR-Timer',
                                                                                               'type': 'ENUMERATED',
                                                                                               'values': [('sf0',
                                                                                                           0),
                                                                                                          ('sf10',
                                                                                                           1),
                                                                                                          ('sf20',
                                                                                                           2),
                                                                                                          ('sf50',
                                                                                                           3),
                                                                                                          ('sf100',
                                                                                                           4),
                                                                                                          ('sf200',
                                                                                                           5),
                                                                                                          ('sf500',
                                                                                                           6),
                                                                                                          ('sf1000',
                                                                                                           7)]},
                                                                                              {'name': 'dl-PathlossChange',
                                                                                               'type': 'ENUMERATED',
                                                                                               'values': [('dB1',
                                                                                                           0),
                                                                                                          ('dB3',
                                                                                                           1),
                                                                                                          ('dB6',
                                                                                                           2),
                                                                                                          ('infinity',
                                                                                                           3)]}],
                                                                                  'name': 'setup',
                                                                                  'type': 'SEQUENCE'}],
                                                                     'name': 'phr-Config',
                                                                     'optional': True,
                                                                     'type': 'CHOICE'},
                                                                    None],
                                                        'type': 'SEQUENCE'},
                                     'MBSFN-SubframeConfig': {'members': [{'name': 'radioframeAllocationPeriod',
                                                                           'type': 'ENUMERATED',
                                                                           'values': [('n1',
                                                                                       0),
                                                                                      ('n2',
                                                                                       1),
                                                                                      ('n4',
                                                                                       2),
                                                                                      ('n8',
                                                                                       3),
                                                                                      ('n16',
                                                                                       4),
                                                                                      ('n32',
                                                                                       5)]},
                                                                          {'name': 'radioframeAllocationOffset',
                                                                           'restricted-to': [(0,
                                                                                              7)],
                                                                           'type': 'INTEGER'},
                                                                          {'members': [{'name': 'oneFrame',
                                                                                        'size': [6],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'fourFrames',
                                                                                        'size': [24],
                                                                                        'type': 'BIT '
                                                                                                'STRING'}],
                                                                           'name': 'subframeAllocation',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                     'MBSFN-SubframeConfigList': {'element': {'type': 'MBSFN-SubframeConfig'},
                                                                  'size': [(1,
                                                                            'maxMBSFN-Allocations')],
                                                                  'type': 'SEQUENCE '
                                                                          'OF'},
                                     'MCC': {'element': {'type': 'MCC-MNC-Digit'},
                                             'size': [3],
                                             'type': 'SEQUENCE OF'},
                                     'MCC-MNC-Digit': {'restricted-to': [(0,
                                                                          9)],
                                                       'type': 'INTEGER'},
                                     'MMEC': {'size': [8],
                                              'type': 'BIT STRING'},
                                     'MNC': {'element': {'type': 'MCC-MNC-Digit'},
                                             'size': [(2, 3)],
                                             'type': 'SEQUENCE OF'},
                                     'MasterInformationBlock': {'members': [{'name': 'dl-Bandwidth',
                                                                             'type': 'ENUMERATED',
                                                                             'values': [('n6',
                                                                                         0),
                                                                                        ('n15',
                                                                                         1),
                                                                                        ('n25',
                                                                                         2),
                                                                                        ('n50',
                                                                                         3),
                                                                                        ('n75',
                                                                                         4),
                                                                                        ('n100',
                                                                                         5)]},
                                                                            {'name': 'phich-Config',
                                                                             'type': 'PHICH-Config'},
                                                                            {'name': 'systemFrameNumber',
                                                                             'size': [8],
                                                                             'type': 'BIT '
                                                                                     'STRING'},
                                                                            {'name': 'spare',
                                                                             'size': [10],
                                                                             'type': 'BIT '
                                                                                     'STRING'}],
                                                                'type': 'SEQUENCE'},
                                     'MeasConfig': {'members': [{'name': 'measObjectToRemoveList',
                                                                 'optional': True,
                                                                 'type': 'MeasObjectToRemoveList'},
                                                                {'name': 'measObjectToAddModList',
                                                                 'optional': True,
                                                                 'type': 'MeasObjectToAddModList'},
                                                                {'name': 'reportConfigToRemoveList',
                                                                 'optional': True,
                                                                 'type': 'ReportConfigToRemoveList'},
                                                                {'name': 'reportConfigToAddModList',
                                                                 'optional': True,
                                                                 'type': 'ReportConfigToAddModList'},
                                                                {'name': 'measIdToRemoveList',
                                                                 'optional': True,
                                                                 'type': 'MeasIdToRemoveList'},
                                                                {'name': 'measIdToAddModList',
                                                                 'optional': True,
                                                                 'type': 'MeasIdToAddModList'},
                                                                {'name': 'quantityConfig',
                                                                 'optional': True,
                                                                 'type': 'QuantityConfig'},
                                                                {'name': 'measGapConfig',
                                                                 'optional': True,
                                                                 'type': 'MeasGapConfig'},
                                                                {'name': 's-Measure',
                                                                 'optional': True,
                                                                 'type': 'RSRP-Range'},
                                                                {'name': 'preRegistrationInfoHRPD',
                                                                 'optional': True,
                                                                 'type': 'PreRegistrationInfoHRPD'},
                                                                {'members': [{'name': 'release',
                                                                              'type': 'NULL'},
                                                                             {'members': [{'name': 'mobilityStateParameters',
                                                                                           'type': 'MobilityStateParameters'},
                                                                                          {'name': 'timeToTrigger-SF',
                                                                                           'type': 'SpeedStateScaleFactors'}],
                                                                              'name': 'setup',
                                                                              'type': 'SEQUENCE'}],
                                                                 'name': 'speedStatePars',
                                                                 'optional': True,
                                                                 'type': 'CHOICE'},
                                                                None],
                                                    'type': 'SEQUENCE'},
                                     'MeasGapConfig': {'members': [{'name': 'release',
                                                                    'type': 'NULL'},
                                                                   {'members': [{'members': [{'name': 'gp0',
                                                                                              'restricted-to': [(0,
                                                                                                                 39)],
                                                                                              'type': 'INTEGER'},
                                                                                             {'name': 'gp1',
                                                                                              'restricted-to': [(0,
                                                                                                                 79)],
                                                                                              'type': 'INTEGER'},
                                                                                             None],
                                                                                 'name': 'gapOffset',
                                                                                 'type': 'CHOICE'}],
                                                                    'name': 'setup',
                                                                    'type': 'SEQUENCE'}],
                                                       'type': 'CHOICE'},
                                     'MeasId': {'restricted-to': [(1,
                                                                   'maxMeasId')],
                                                'type': 'INTEGER'},
                                     'MeasIdToAddMod': {'members': [{'name': 'measId',
                                                                     'type': 'MeasId'},
                                                                    {'name': 'measObjectId',
                                                                     'type': 'MeasObjectId'},
                                                                    {'name': 'reportConfigId',
                                                                     'type': 'ReportConfigId'}],
                                                        'type': 'SEQUENCE'},
                                     'MeasIdToAddModList': {'element': {'type': 'MeasIdToAddMod'},
                                                            'size': [(1,
                                                                      'maxMeasId')],
                                                            'type': 'SEQUENCE '
                                                                    'OF'},
                                     'MeasIdToRemoveList': {'element': {'type': 'MeasId'},
                                                            'size': [(1,
                                                                      'maxMeasId')],
                                                            'type': 'SEQUENCE '
                                                                    'OF'},
                                     'MeasObjectCDMA2000': {'members': [{'name': 'cdma2000-Type',
                                                                         'type': 'CDMA2000-Type'},
                                                                        {'name': 'carrierFreq',
                                                                         'type': 'CarrierFreqCDMA2000'},
                                                                        {'name': 'searchWindowSize',
                                                                         'optional': True,
                                                                         'restricted-to': [(0,
                                                                                            15)],
                                                                         'type': 'INTEGER'},
                                                                        {'default': 0,
                                                                         'name': 'offsetFreq',
                                                                         'type': 'Q-OffsetRangeInterRAT'},
                                                                        {'name': 'cellsToRemoveList',
                                                                         'optional': True,
                                                                         'type': 'CellIndexList'},
                                                                        {'name': 'cellsToAddModList',
                                                                         'optional': True,
                                                                         'type': 'CellsToAddModListCDMA2000'},
                                                                        {'name': 'cellForWhichToReportCGI',
                                                                         'optional': True,
                                                                         'type': 'PhysCellIdCDMA2000'},
                                                                        None],
                                                            'type': 'SEQUENCE'},
                                     'MeasObjectEUTRA': {'members': [{'name': 'carrierFreq',
                                                                      'type': 'ARFCN-ValueEUTRA'},
                                                                     {'name': 'allowedMeasBandwidth',
                                                                      'type': 'AllowedMeasBandwidth'},
                                                                     {'name': 'presenceAntennaPort1',
                                                                      'type': 'PresenceAntennaPort1'},
                                                                     {'name': 'neighCellConfig',
                                                                      'type': 'NeighCellConfig'},
                                                                     {'default': 'dB0',
                                                                      'name': 'offsetFreq',
                                                                      'type': 'Q-OffsetRange'},
                                                                     {'name': 'cellsToRemoveList',
                                                                      'optional': True,
                                                                      'type': 'CellIndexList'},
                                                                     {'name': 'cellsToAddModList',
                                                                      'optional': True,
                                                                      'type': 'CellsToAddModList'},
                                                                     {'name': 'blackCellsToRemoveList',
                                                                      'optional': True,
                                                                      'type': 'CellIndexList'},
                                                                     {'name': 'blackCellsToAddModList',
                                                                      'optional': True,
                                                                      'type': 'BlackCellsToAddModList'},
                                                                     {'name': 'cellForWhichToReportCGI',
                                                                      'optional': True,
                                                                      'type': 'PhysCellId'},
                                                                     None],
                                                         'type': 'SEQUENCE'},
                                     'MeasObjectGERAN': {'members': [{'name': 'carrierFreqs',
                                                                      'type': 'CarrierFreqsGERAN'},
                                                                     {'default': 0,
                                                                      'name': 'offsetFreq',
                                                                      'type': 'Q-OffsetRangeInterRAT'},
                                                                     {'default': '0b11111111',
                                                                      'name': 'ncc-Permitted',
                                                                      'size': [8],
                                                                      'type': 'BIT '
                                                                              'STRING'},
                                                                     {'name': 'cellForWhichToReportCGI',
                                                                      'optional': True,
                                                                      'type': 'PhysCellIdGERAN'},
                                                                     None],
                                                         'type': 'SEQUENCE'},
                                     'MeasObjectId': {'restricted-to': [(1,
                                                                         'maxObjectId')],
                                                      'type': 'INTEGER'},
                                     'MeasObjectToAddMod': {'members': [{'name': 'measObjectId',
                                                                         'type': 'MeasObjectId'},
                                                                        {'members': [{'name': 'measObjectEUTRA',
                                                                                      'type': 'MeasObjectEUTRA'},
                                                                                     {'name': 'measObjectUTRA',
                                                                                      'type': 'MeasObjectUTRA'},
                                                                                     {'name': 'measObjectGERAN',
                                                                                      'type': 'MeasObjectGERAN'},
                                                                                     {'name': 'measObjectCDMA2000',
                                                                                      'type': 'MeasObjectCDMA2000'},
                                                                                     None],
                                                                         'name': 'measObject',
                                                                         'type': 'CHOICE'}],
                                                            'type': 'SEQUENCE'},
                                     'MeasObjectToAddModList': {'element': {'type': 'MeasObjectToAddMod'},
                                                                'size': [(1,
                                                                          'maxObjectId')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'MeasObjectToRemoveList': {'element': {'type': 'MeasObjectId'},
                                                                'size': [(1,
                                                                          'maxObjectId')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'MeasObjectUTRA': {'members': [{'name': 'carrierFreq',
                                                                     'type': 'ARFCN-ValueUTRA'},
                                                                    {'default': 0,
                                                                     'name': 'offsetFreq',
                                                                     'type': 'Q-OffsetRangeInterRAT'},
                                                                    {'name': 'cellsToRemoveList',
                                                                     'optional': True,
                                                                     'type': 'CellIndexList'},
                                                                    {'members': [{'name': 'cellsToAddModListUTRA-FDD',
                                                                                  'type': 'CellsToAddModListUTRA-FDD'},
                                                                                 {'name': 'cellsToAddModListUTRA-TDD',
                                                                                  'type': 'CellsToAddModListUTRA-TDD'}],
                                                                     'name': 'cellsToAddModList',
                                                                     'optional': True,
                                                                     'type': 'CHOICE'},
                                                                    {'members': [{'name': 'utra-FDD',
                                                                                  'type': 'PhysCellIdUTRA-FDD'},
                                                                                 {'name': 'utra-TDD',
                                                                                  'type': 'PhysCellIdUTRA-TDD'}],
                                                                     'name': 'cellForWhichToReportCGI',
                                                                     'optional': True,
                                                                     'type': 'CHOICE'},
                                                                    None],
                                                        'type': 'SEQUENCE'},
                                     'MeasParameters': {'members': [{'name': 'bandListEUTRA',
                                                                     'type': 'BandListEUTRA'}],
                                                        'type': 'SEQUENCE'},
                                     'MeasResultCDMA2000': {'members': [{'name': 'physCellId',
                                                                         'type': 'PhysCellIdCDMA2000'},
                                                                        {'name': 'cgi-Info',
                                                                         'optional': True,
                                                                         'type': 'CellGlobalIdCDMA2000'},
                                                                        {'members': [{'name': 'pilotPnPhase',
                                                                                      'optional': True,
                                                                                      'restricted-to': [(0,
                                                                                                         32767)],
                                                                                      'type': 'INTEGER'},
                                                                                     {'name': 'pilotStrength',
                                                                                      'restricted-to': [(0,
                                                                                                         63)],
                                                                                      'type': 'INTEGER'},
                                                                                     None],
                                                                         'name': 'measResult',
                                                                         'type': 'SEQUENCE'}],
                                                            'type': 'SEQUENCE'},
                                     'MeasResultEUTRA': {'members': [{'name': 'physCellId',
                                                                      'type': 'PhysCellId'},
                                                                     {'members': [{'name': 'cellGlobalId',
                                                                                   'type': 'CellGlobalIdEUTRA'},
                                                                                  {'name': 'trackingAreaCode',
                                                                                   'type': 'TrackingAreaCode'},
                                                                                  {'name': 'plmn-IdentityList',
                                                                                   'optional': True,
                                                                                   'type': 'PLMN-IdentityList2'}],
                                                                      'name': 'cgi-Info',
                                                                      'optional': True,
                                                                      'type': 'SEQUENCE'},
                                                                     {'members': [{'name': 'rsrpResult',
                                                                                   'optional': True,
                                                                                   'type': 'RSRP-Range'},
                                                                                  {'name': 'rsrqResult',
                                                                                   'optional': True,
                                                                                   'type': 'RSRQ-Range'},
                                                                                  None],
                                                                      'name': 'measResult',
                                                                      'type': 'SEQUENCE'}],
                                                         'type': 'SEQUENCE'},
                                     'MeasResultGERAN': {'members': [{'name': 'carrierFreq',
                                                                      'type': 'CarrierFreqGERAN'},
                                                                     {'name': 'physCellId',
                                                                      'type': 'PhysCellIdGERAN'},
                                                                     {'members': [{'name': 'cellGlobalId',
                                                                                   'type': 'CellGlobalIdGERAN'},
                                                                                  {'name': 'routingAreaCode',
                                                                                   'optional': True,
                                                                                   'size': [8],
                                                                                   'type': 'BIT '
                                                                                           'STRING'}],
                                                                      'name': 'cgi-Info',
                                                                      'optional': True,
                                                                      'type': 'SEQUENCE'},
                                                                     {'members': [{'name': 'rssi',
                                                                                   'restricted-to': [(0,
                                                                                                      63)],
                                                                                   'type': 'INTEGER'},
                                                                                  None],
                                                                      'name': 'measResult',
                                                                      'type': 'SEQUENCE'}],
                                                         'type': 'SEQUENCE'},
                                     'MeasResultListCDMA2000': {'element': {'type': 'MeasResultCDMA2000'},
                                                                'size': [(1,
                                                                          'maxCellReport')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'MeasResultListEUTRA': {'element': {'type': 'MeasResultEUTRA'},
                                                             'size': [(1,
                                                                       'maxCellReport')],
                                                             'type': 'SEQUENCE '
                                                                     'OF'},
                                     'MeasResultListGERAN': {'element': {'type': 'MeasResultGERAN'},
                                                             'size': [(1,
                                                                       'maxCellReport')],
                                                             'type': 'SEQUENCE '
                                                                     'OF'},
                                     'MeasResultListUTRA': {'element': {'type': 'MeasResultUTRA'},
                                                            'size': [(1,
                                                                      'maxCellReport')],
                                                            'type': 'SEQUENCE '
                                                                    'OF'},
                                     'MeasResultUTRA': {'members': [{'members': [{'name': 'fdd',
                                                                                  'type': 'PhysCellIdUTRA-FDD'},
                                                                                 {'name': 'tdd',
                                                                                  'type': 'PhysCellIdUTRA-TDD'}],
                                                                     'name': 'physCellId',
                                                                     'type': 'CHOICE'},
                                                                    {'members': [{'name': 'cellGlobalId',
                                                                                  'type': 'CellGlobalIdUTRA'},
                                                                                 {'name': 'locationAreaCode',
                                                                                  'optional': True,
                                                                                  'size': [16],
                                                                                  'type': 'BIT '
                                                                                          'STRING'},
                                                                                 {'name': 'routingAreaCode',
                                                                                  'optional': True,
                                                                                  'size': [8],
                                                                                  'type': 'BIT '
                                                                                          'STRING'},
                                                                                 {'name': 'plmn-IdentityList',
                                                                                  'optional': True,
                                                                                  'type': 'PLMN-IdentityList2'}],
                                                                     'name': 'cgi-Info',
                                                                     'optional': True,
                                                                     'type': 'SEQUENCE'},
                                                                    {'members': [{'name': 'utra-RSCP',
                                                                                  'optional': True,
                                                                                  'restricted-to': [(-5,
                                                                                                     91)],
                                                                                  'type': 'INTEGER'},
                                                                                 {'name': 'utra-EcN0',
                                                                                  'optional': True,
                                                                                  'restricted-to': [(0,
                                                                                                     49)],
                                                                                  'type': 'INTEGER'},
                                                                                 None],
                                                                     'name': 'measResult',
                                                                     'type': 'SEQUENCE'}],
                                                        'type': 'SEQUENCE'},
                                     'MeasResults': {'members': [{'name': 'measId',
                                                                  'type': 'MeasId'},
                                                                 {'members': [{'name': 'rsrpResult',
                                                                               'type': 'RSRP-Range'},
                                                                              {'name': 'rsrqResult',
                                                                               'type': 'RSRQ-Range'}],
                                                                  'name': 'measResultServCell',
                                                                  'type': 'SEQUENCE'},
                                                                 {'members': [{'name': 'measResultListEUTRA',
                                                                               'type': 'MeasResultListEUTRA'},
                                                                              {'name': 'measResultListUTRA',
                                                                               'type': 'MeasResultListUTRA'},
                                                                              {'name': 'measResultListGERAN',
                                                                               'type': 'MeasResultListGERAN'},
                                                                              {'name': 'measResultsCDMA2000',
                                                                               'type': 'MeasResultsCDMA2000'},
                                                                              None],
                                                                  'name': 'measResultNeighCells',
                                                                  'optional': True,
                                                                  'type': 'CHOICE'},
                                                                 None],
                                                     'type': 'SEQUENCE'},
                                     'MeasResultsCDMA2000': {'members': [{'name': 'preRegistrationStatusHRPD',
                                                                          'type': 'BOOLEAN'},
                                                                         {'name': 'measResultListCDMA2000',
                                                                          'type': 'MeasResultListCDMA2000'}],
                                                             'type': 'SEQUENCE'},
                                     'MeasurementReport': {'members': [{'members': [{'members': [{'name': 'measurementReport-r8',
                                                                                                  'type': 'MeasurementReport-r8-IEs'},
                                                                                                 {'name': 'spare7',
                                                                                                  'type': 'NULL'},
                                                                                                 {'name': 'spare6',
                                                                                                  'type': 'NULL'},
                                                                                                 {'name': 'spare5',
                                                                                                  'type': 'NULL'},
                                                                                                 {'name': 'spare4',
                                                                                                  'type': 'NULL'},
                                                                                                 {'name': 'spare3',
                                                                                                  'type': 'NULL'},
                                                                                                 {'name': 'spare2',
                                                                                                  'type': 'NULL'},
                                                                                                 {'name': 'spare1',
                                                                                                  'type': 'NULL'}],
                                                                                     'name': 'c1',
                                                                                     'type': 'CHOICE'},
                                                                                    {'members': [],
                                                                                     'name': 'criticalExtensionsFuture',
                                                                                     'type': 'SEQUENCE'}],
                                                                        'name': 'criticalExtensions',
                                                                        'type': 'CHOICE'}],
                                                           'type': 'SEQUENCE'},
                                     'MeasurementReport-r8-IEs': {'members': [{'name': 'measResults',
                                                                               'type': 'MeasResults'},
                                                                              {'members': [],
                                                                               'name': 'nonCriticalExtension',
                                                                               'optional': True,
                                                                               'type': 'SEQUENCE'}],
                                                                  'type': 'SEQUENCE'},
                                     'MobilityControlInfo': {'members': [{'name': 'targetPhysCellId',
                                                                          'type': 'PhysCellId'},
                                                                         {'name': 'carrierFreq',
                                                                          'optional': True,
                                                                          'type': 'CarrierFreqEUTRA'},
                                                                         {'name': 'carrierBandwidth',
                                                                          'optional': True,
                                                                          'type': 'CarrierBandwidthEUTRA'},
                                                                         {'name': 'additionalSpectrumEmission',
                                                                          'optional': True,
                                                                          'type': 'AdditionalSpectrumEmission'},
                                                                         {'name': 't304',
                                                                          'type': 'ENUMERATED',
                                                                          'values': [('ms50',
                                                                                      0),
                                                                                     ('ms100',
                                                                                      1),
                                                                                     ('ms150',
                                                                                      2),
                                                                                     ('ms200',
                                                                                      3),
                                                                                     ('ms500',
                                                                                      4),
                                                                                     ('ms1000',
                                                                                      5),
                                                                                     ('ms2000',
                                                                                      6),
                                                                                     ('spare1',
                                                                                      7)]},
                                                                         {'name': 'newUE-Identity',
                                                                          'type': 'C-RNTI'},
                                                                         {'name': 'radioResourceConfigCommon',
                                                                          'type': 'RadioResourceConfigCommon'},
                                                                         {'name': 'rach-ConfigDedicated',
                                                                          'optional': True,
                                                                          'type': 'RACH-ConfigDedicated'},
                                                                         None],
                                                             'type': 'SEQUENCE'},
                                     'MobilityFromEUTRACommand': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                               'type': 'RRC-TransactionIdentifier'},
                                                                              {'members': [{'members': [{'name': 'mobilityFromEUTRACommand-r8',
                                                                                                         'type': 'MobilityFromEUTRACommand-r8-IEs'},
                                                                                                        {'name': 'spare3',
                                                                                                         'type': 'NULL'},
                                                                                                        {'name': 'spare2',
                                                                                                         'type': 'NULL'},
                                                                                                        {'name': 'spare1',
                                                                                                         'type': 'NULL'}],
                                                                                            'name': 'c1',
                                                                                            'type': 'CHOICE'},
                                                                                           {'members': [],
                                                                                            'name': 'criticalExtensionsFuture',
                                                                                            'type': 'SEQUENCE'}],
                                                                               'name': 'criticalExtensions',
                                                                               'type': 'CHOICE'}],
                                                                  'type': 'SEQUENCE'},
                                     'MobilityFromEUTRACommand-r8-IEs': {'members': [{'name': 'cs-FallbackIndicator',
                                                                                      'type': 'BOOLEAN'},
                                                                                     {'members': [{'name': 'handover',
                                                                                                   'type': 'Handover'},
                                                                                                  {'name': 'cellChangeOrder',
                                                                                                   'type': 'CellChangeOrder'}],
                                                                                      'name': 'purpose',
                                                                                      'type': 'CHOICE'},
                                                                                     {'members': [],
                                                                                      'name': 'nonCriticalExtension',
                                                                                      'optional': True,
                                                                                      'type': 'SEQUENCE'}],
                                                                         'type': 'SEQUENCE'},
                                     'MobilityParametersCDMA2000': {'type': 'OCTET '
                                                                            'STRING'},
                                     'MobilityStateParameters': {'members': [{'name': 't-Evaluation',
                                                                              'type': 'ENUMERATED',
                                                                              'values': [('s30',
                                                                                          0),
                                                                                         ('s60',
                                                                                          1),
                                                                                         ('s120',
                                                                                          2),
                                                                                         ('s180',
                                                                                          3),
                                                                                         ('s240',
                                                                                          4),
                                                                                         ('spare3',
                                                                                          5),
                                                                                         ('spare2',
                                                                                          6),
                                                                                         ('spare1',
                                                                                          7)]},
                                                                             {'name': 't-HystNormal',
                                                                              'type': 'ENUMERATED',
                                                                              'values': [('s30',
                                                                                          0),
                                                                                         ('s60',
                                                                                          1),
                                                                                         ('s120',
                                                                                          2),
                                                                                         ('s180',
                                                                                          3),
                                                                                         ('s240',
                                                                                          4),
                                                                                         ('spare3',
                                                                                          5),
                                                                                         ('spare2',
                                                                                          6),
                                                                                         ('spare1',
                                                                                          7)]},
                                                                             {'name': 'n-CellChangeMedium',
                                                                              'restricted-to': [(1,
                                                                                                 16)],
                                                                              'type': 'INTEGER'},
                                                                             {'name': 'n-CellChangeHigh',
                                                                              'restricted-to': [(1,
                                                                                                 16)],
                                                                              'type': 'INTEGER'}],
                                                                 'type': 'SEQUENCE'},
                                     'N1-PUCCH-AN-PersistentList': {'element': {'restricted-to': [(0,
                                                                                                   2047)],
                                                                                'type': 'INTEGER'},
                                                                    'size': [(1,
                                                                              4)],
                                                                    'type': 'SEQUENCE '
                                                                            'OF'},
                                     'NeighCellCDMA2000': {'members': [{'name': 'bandClass',
                                                                        'type': 'BandclassCDMA2000'},
                                                                       {'name': 'neighCellsPerFreqList',
                                                                        'type': 'NeighCellsPerBandclassListCDMA2000'}],
                                                           'type': 'SEQUENCE'},
                                     'NeighCellConfig': {'size': [2],
                                                         'type': 'BIT STRING'},
                                     'NeighCellListCDMA2000': {'element': {'type': 'NeighCellCDMA2000'},
                                                               'size': [(1,
                                                                         16)],
                                                               'type': 'SEQUENCE '
                                                                       'OF'},
                                     'NeighCellsPerBandclassCDMA2000': {'members': [{'name': 'arfcn',
                                                                                     'type': 'ARFCN-ValueCDMA2000'},
                                                                                    {'name': 'physCellIdList',
                                                                                     'type': 'PhysCellIdListCDMA2000'}],
                                                                        'type': 'SEQUENCE'},
                                     'NeighCellsPerBandclassListCDMA2000': {'element': {'type': 'NeighCellsPerBandclassCDMA2000'},
                                                                            'size': [(1,
                                                                                      16)],
                                                                            'type': 'SEQUENCE '
                                                                                    'OF'},
                                     'NextHopChainingCount': {'restricted-to': [(0,
                                                                                 7)],
                                                              'type': 'INTEGER'},
                                     'P-Max': {'restricted-to': [(-30, 33)],
                                               'type': 'INTEGER'},
                                     'PCCH-Config': {'members': [{'name': 'defaultPagingCycle',
                                                                  'type': 'ENUMERATED',
                                                                  'values': [('rf32',
                                                                              0),
                                                                             ('rf64',
                                                                              1),
                                                                             ('rf128',
                                                                              2),
                                                                             ('rf256',
                                                                              3)]},
                                                                 {'name': 'nB',
                                                                  'type': 'ENUMERATED',
                                                                  'values': [('fourT',
                                                                              0),
                                                                             ('twoT',
                                                                              1),
                                                                             ('oneT',
                                                                              2),
                                                                             ('halfT',
                                                                              3),
                                                                             ('quarterT',
                                                                              4),
                                                                             ('oneEighthT',
                                                                              5),
                                                                             ('oneSixteenthT',
                                                                              6),
                                                                             ('oneThirtySecondT',
                                                                              7)]}],
                                                     'type': 'SEQUENCE'},
                                     'PCCH-Message': {'members': [{'name': 'message',
                                                                   'type': 'PCCH-MessageType'}],
                                                      'type': 'SEQUENCE'},
                                     'PCCH-MessageType': {'members': [{'members': [{'name': 'paging',
                                                                                    'type': 'Paging'}],
                                                                       'name': 'c1',
                                                                       'type': 'CHOICE'},
                                                                      {'members': [],
                                                                       'name': 'messageClassExtension',
                                                                       'type': 'SEQUENCE'}],
                                                          'type': 'CHOICE'},
                                     'PDCP-Config': {'members': [{'name': 'discardTimer',
                                                                  'optional': True,
                                                                  'type': 'ENUMERATED',
                                                                  'values': [('ms50',
                                                                              0),
                                                                             ('ms100',
                                                                              1),
                                                                             ('ms150',
                                                                              2),
                                                                             ('ms300',
                                                                              3),
                                                                             ('ms500',
                                                                              4),
                                                                             ('ms750',
                                                                              5),
                                                                             ('ms1500',
                                                                              6),
                                                                             ('infinity',
                                                                              7)]},
                                                                 {'members': [{'name': 'statusReportRequired',
                                                                               'type': 'BOOLEAN'}],
                                                                  'name': 'rlc-AM',
                                                                  'optional': True,
                                                                  'type': 'SEQUENCE'},
                                                                 {'members': [{'name': 'pdcp-SN-Size',
                                                                               'type': 'ENUMERATED',
                                                                               'values': [('len7bits',
                                                                                           0),
                                                                                          ('len12bits',
                                                                                           1)]}],
                                                                  'name': 'rlc-UM',
                                                                  'optional': True,
                                                                  'type': 'SEQUENCE'},
                                                                 {'members': [{'name': 'notUsed',
                                                                               'type': 'NULL'},
                                                                              {'members': [{'default': 15,
                                                                                            'name': 'maxCID',
                                                                                            'restricted-to': [(1,
                                                                                                               16383)],
                                                                                            'type': 'INTEGER'},
                                                                                           {'members': [{'name': 'profile0x0001',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0002',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0003',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0004',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0006',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0101',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0102',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0103',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0104',
                                                                                                         'type': 'BOOLEAN'}],
                                                                                            'name': 'profiles',
                                                                                            'type': 'SEQUENCE'},
                                                                                           None],
                                                                               'name': 'rohc',
                                                                               'type': 'SEQUENCE'}],
                                                                  'name': 'headerCompression',
                                                                  'type': 'CHOICE'},
                                                                 None],
                                                     'type': 'SEQUENCE'},
                                     'PDCP-Parameters': {'members': [{'members': [{'name': 'profile0x0001',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0002',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0003',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0004',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0006',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0101',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0102',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0103',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0104',
                                                                                   'type': 'BOOLEAN'}],
                                                                      'name': 'supportedROHC-Profiles',
                                                                      'type': 'SEQUENCE'},
                                                                     {'default': 'cs16',
                                                                      'name': 'maxNumberROHC-ContextSessions',
                                                                      'type': 'ENUMERATED',
                                                                      'values': [('cs2',
                                                                                  0),
                                                                                 ('cs4',
                                                                                  1),
                                                                                 ('cs8',
                                                                                  2),
                                                                                 ('cs12',
                                                                                  3),
                                                                                 ('cs16',
                                                                                  4),
                                                                                 ('cs24',
                                                                                  5),
                                                                                 ('cs32',
                                                                                  6),
                                                                                 ('cs48',
                                                                                  7),
                                                                                 ('cs64',
                                                                                  8),
                                                                                 ('cs128',
                                                                                  9),
                                                                                 ('cs256',
                                                                                  10),
                                                                                 ('cs512',
                                                                                  11),
                                                                                 ('cs1024',
                                                                                  12),
                                                                                 ('cs16384',
                                                                                  13),
                                                                                 ('spare2',
                                                                                  14),
                                                                                 ('spare1',
                                                                                  15)]},
                                                                     None],
                                                         'type': 'SEQUENCE'},
                                     'PDSCH-ConfigCommon': {'members': [{'name': 'referenceSignalPower',
                                                                         'restricted-to': [(-60,
                                                                                            50)],
                                                                         'type': 'INTEGER'},
                                                                        {'name': 'p-b',
                                                                         'restricted-to': [(0,
                                                                                            3)],
                                                                         'type': 'INTEGER'}],
                                                            'type': 'SEQUENCE'},
                                     'PDSCH-ConfigDedicated': {'members': [{'name': 'p-a',
                                                                            'type': 'ENUMERATED',
                                                                            'values': [('dB-6',
                                                                                        0),
                                                                                       ('dB-4dot77',
                                                                                        1),
                                                                                       ('dB-3',
                                                                                        2),
                                                                                       ('dB-1dot77',
                                                                                        3),
                                                                                       ('dB0',
                                                                                        4),
                                                                                       ('dB1',
                                                                                        5),
                                                                                       ('dB2',
                                                                                        6),
                                                                                       ('dB3',
                                                                                        7)]}],
                                                               'type': 'SEQUENCE'},
                                     'PHICH-Config': {'members': [{'name': 'phich-Duration',
                                                                   'type': 'ENUMERATED',
                                                                   'values': [('normal',
                                                                               0),
                                                                              ('extended',
                                                                               1)]},
                                                                  {'name': 'phich-Resource',
                                                                   'type': 'ENUMERATED',
                                                                   'values': [('oneSixth',
                                                                               0),
                                                                              ('half',
                                                                               1),
                                                                              ('one',
                                                                               2),
                                                                              ('two',
                                                                               3)]}],
                                                      'type': 'SEQUENCE'},
                                     'PLMN-Identity': {'members': [{'name': 'mcc',
                                                                    'optional': True,
                                                                    'type': 'MCC'},
                                                                   {'name': 'mnc',
                                                                    'type': 'MNC'}],
                                                       'type': 'SEQUENCE'},
                                     'PLMN-IdentityInfo': {'members': [{'name': 'plmn-Identity',
                                                                        'type': 'PLMN-Identity'},
                                                                       {'name': 'cellReservedForOperatorUse',
                                                                        'type': 'ENUMERATED',
                                                                        'values': [('reserved',
                                                                                    0),
                                                                                   ('notReserved',
                                                                                    1)]}],
                                                           'type': 'SEQUENCE'},
                                     'PLMN-IdentityList': {'element': {'type': 'PLMN-IdentityInfo'},
                                                           'size': [(1, 6)],
                                                           'type': 'SEQUENCE '
                                                                   'OF'},
                                     'PLMN-IdentityList2': {'element': {'type': 'PLMN-Identity'},
                                                            'size': [(1, 5)],
                                                            'type': 'SEQUENCE '
                                                                    'OF'},
                                     'PRACH-Config': {'members': [{'name': 'rootSequenceIndex',
                                                                   'restricted-to': [(0,
                                                                                      837)],
                                                                   'type': 'INTEGER'},
                                                                  {'name': 'prach-ConfigInfo',
                                                                   'optional': True,
                                                                   'type': 'PRACH-ConfigInfo'}],
                                                      'type': 'SEQUENCE'},
                                     'PRACH-ConfigInfo': {'members': [{'name': 'prach-ConfigIndex',
                                                                       'restricted-to': [(0,
                                                                                          63)],
                                                                       'type': 'INTEGER'},
                                                                      {'name': 'highSpeedFlag',
                                                                       'type': 'BOOLEAN'},
                                                                      {'name': 'zeroCorrelationZoneConfig',
                                                                       'restricted-to': [(0,
                                                                                          15)],
                                                                       'type': 'INTEGER'},
                                                                      {'name': 'prach-FreqOffset',
                                                                       'restricted-to': [(0,
                                                                                          94)],
                                                                       'type': 'INTEGER'}],
                                                          'type': 'SEQUENCE'},
                                     'PRACH-ConfigSIB': {'members': [{'name': 'rootSequenceIndex',
                                                                      'restricted-to': [(0,
                                                                                         837)],
                                                                      'type': 'INTEGER'},
                                                                     {'name': 'prach-ConfigInfo',
                                                                      'type': 'PRACH-ConfigInfo'}],
                                                         'type': 'SEQUENCE'},
                                     'PUCCH-ConfigCommon': {'members': [{'name': 'deltaPUCCH-Shift',
                                                                         'type': 'ENUMERATED',
                                                                         'values': [('ds1',
                                                                                     0),
                                                                                    ('ds2',
                                                                                     1),
                                                                                    ('ds3',
                                                                                     2)]},
                                                                        {'name': 'nRB-CQI',
                                                                         'restricted-to': [(0,
                                                                                            98)],
                                                                         'type': 'INTEGER'},
                                                                        {'name': 'nCS-AN',
                                                                         'restricted-to': [(0,
                                                                                            7)],
                                                                         'type': 'INTEGER'},
                                                                        {'name': 'n1PUCCH-AN',
                                                                         'restricted-to': [(0,
                                                                                            2047)],
                                                                         'type': 'INTEGER'}],
                                                            'type': 'SEQUENCE'},
                                     'PUCCH-ConfigDedicated': {'members': [{'members': [{'name': 'release',
                                                                                         'type': 'NULL'},
                                                                                        {'members': [{'name': 'repetitionFactor',
                                                                                                      'type': 'ENUMERATED',
                                                                                                      'values': [('n2',
                                                                                                                  0),
                                                                                                                 ('n4',
                                                                                                                  1),
                                                                                                                 ('n6',
                                                                                                                  2),
                                                                                                                 ('spare1',
                                                                                                                  3)]},
                                                                                                     {'name': 'n1PUCCH-AN-Rep',
                                                                                                      'restricted-to': [(0,
                                                                                                                         2047)],
                                                                                                      'type': 'INTEGER'}],
                                                                                         'name': 'setup',
                                                                                         'type': 'SEQUENCE'}],
                                                                            'name': 'ackNackRepetition',
                                                                            'type': 'CHOICE'},
                                                                           {'name': 'tdd-AckNackFeedbackMode',
                                                                            'optional': True,
                                                                            'type': 'ENUMERATED',
                                                                            'values': [('bundling',
                                                                                        0),
                                                                                       ('multiplexing',
                                                                                        1)]}],
                                                               'type': 'SEQUENCE'},
                                     'PUSCH-ConfigCommon': {'members': [{'members': [{'name': 'n-SB',
                                                                                      'restricted-to': [(1,
                                                                                                         4)],
                                                                                      'type': 'INTEGER'},
                                                                                     {'name': 'hoppingMode',
                                                                                      'type': 'ENUMERATED',
                                                                                      'values': [('interSubFrame',
                                                                                                  0),
                                                                                                 ('intraAndInterSubFrame',
                                                                                                  1)]},
                                                                                     {'name': 'pusch-HoppingOffset',
                                                                                      'restricted-to': [(0,
                                                                                                         98)],
                                                                                      'type': 'INTEGER'},
                                                                                     {'name': 'enable64QAM',
                                                                                      'type': 'BOOLEAN'}],
                                                                         'name': 'pusch-ConfigBasic',
                                                                         'type': 'SEQUENCE'},
                                                                        {'name': 'ul-ReferenceSignalsPUSCH',
                                                                         'type': 'UL-ReferenceSignalsPUSCH'}],
                                                            'type': 'SEQUENCE'},
                                     'PUSCH-ConfigDedicated': {'members': [{'name': 'betaOffset-ACK-Index',
                                                                            'restricted-to': [(0,
                                                                                               15)],
                                                                            'type': 'INTEGER'},
                                                                           {'name': 'betaOffset-RI-Index',
                                                                            'restricted-to': [(0,
                                                                                               15)],
                                                                            'type': 'INTEGER'},
                                                                           {'name': 'betaOffset-CQI-Index',
                                                                            'restricted-to': [(0,
                                                                                               15)],
                                                                            'type': 'INTEGER'}],
                                                               'type': 'SEQUENCE'},
                                     'Paging': {'members': [{'name': 'pagingRecordList',
                                                             'optional': True,
                                                             'type': 'PagingRecordList'},
                                                            {'name': 'systemInfoModification',
                                                             'optional': True,
                                                             'type': 'ENUMERATED',
                                                             'values': [('true',
                                                                         0)]},
                                                            {'name': 'etws-Indication',
                                                             'optional': True,
                                                             'type': 'ENUMERATED',
                                                             'values': [('true',
                                                                         0)]},
                                                            {'members': [],
                                                             'name': 'nonCriticalExtension',
                                                             'optional': True,
                                                             'type': 'SEQUENCE'}],
                                                'type': 'SEQUENCE'},
                                     'PagingRecord': {'members': [{'name': 'ue-Identity',
                                                                   'type': 'PagingUE-Identity'},
                                                                  {'name': 'cn-Domain',
                                                                   'type': 'ENUMERATED',
                                                                   'values': [('ps',
                                                                               0),
                                                                              ('cs',
                                                                               1)]},
                                                                  None],
                                                      'type': 'SEQUENCE'},
                                     'PagingRecordList': {'element': {'type': 'PagingRecord'},
                                                          'size': [(1,
                                                                    'maxPageRec')],
                                                          'type': 'SEQUENCE '
                                                                  'OF'},
                                     'PagingUE-Identity': {'members': [{'name': 's-TMSI',
                                                                        'type': 'S-TMSI'},
                                                                       {'name': 'imsi',
                                                                        'type': 'IMSI'},
                                                                       None],
                                                           'type': 'CHOICE'},
                                     'PhyLayerParameters': {'members': [{'name': 'ue-TxAntennaSelectionSupported',
                                                                         'type': 'BOOLEAN'},
                                                                        {'name': 'ue-SpecificRefSigsSupported',
                                                                         'type': 'BOOLEAN'}],
                                                            'type': 'SEQUENCE'},
                                     'PhysCellId': {'restricted-to': [(0, 503)],
                                                    'type': 'INTEGER'},
                                     'PhysCellIdCDMA2000': {'restricted-to': [(0,
                                                                               'maxPNOffset')],
                                                            'type': 'INTEGER'},
                                     'PhysCellIdGERAN': {'members': [{'name': 'networkColourCode',
                                                                      'size': [3],
                                                                      'type': 'BIT '
                                                                              'STRING'},
                                                                     {'name': 'baseStationColourCode',
                                                                      'size': [3],
                                                                      'type': 'BIT '
                                                                              'STRING'}],
                                                         'type': 'SEQUENCE'},
                                     'PhysCellIdListCDMA2000': {'element': {'type': 'PhysCellIdCDMA2000'},
                                                                'size': [(1,
                                                                          16)],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'PhysCellIdRange': {'members': [{'name': 'start',
                                                                      'type': 'PhysCellId'},
                                                                     {'name': 'range',
                                                                      'optional': True,
                                                                      'type': 'ENUMERATED',
                                                                      'values': [('n4',
                                                                                  0),
                                                                                 ('n8',
                                                                                  1),
                                                                                 ('n12',
                                                                                  2),
                                                                                 ('n16',
                                                                                  3),
                                                                                 ('n24',
                                                                                  4),
                                                                                 ('n32',
                                                                                  5),
                                                                                 ('n48',
                                                                                  6),
                                                                                 ('n64',
                                                                                  7),
                                                                                 ('n84',
                                                                                  8),
                                                                                 ('n96',
                                                                                  9),
                                                                                 ('n128',
                                                                                  10),
                                                                                 ('n168',
                                                                                  11),
                                                                                 ('n252',
                                                                                  12),
                                                                                 ('n504',
                                                                                  13),
                                                                                 ('spare2',
                                                                                  14),
                                                                                 ('spare1',
                                                                                  15)]}],
                                                         'type': 'SEQUENCE'},
                                     'PhysCellIdUTRA-FDD': {'restricted-to': [(0,
                                                                               511)],
                                                            'type': 'INTEGER'},
                                     'PhysCellIdUTRA-TDD': {'restricted-to': [(0,
                                                                               127)],
                                                            'type': 'INTEGER'},
                                     'PhysicalConfigDedicated': {'members': [{'name': 'pdsch-ConfigDedicated',
                                                                              'optional': True,
                                                                              'type': 'PDSCH-ConfigDedicated'},
                                                                             {'name': 'pucch-ConfigDedicated',
                                                                              'optional': True,
                                                                              'type': 'PUCCH-ConfigDedicated'},
                                                                             {'name': 'pusch-ConfigDedicated',
                                                                              'optional': True,
                                                                              'type': 'PUSCH-ConfigDedicated'},
                                                                             {'name': 'uplinkPowerControlDedicated',
                                                                              'optional': True,
                                                                              'type': 'UplinkPowerControlDedicated'},
                                                                             {'name': 'tpc-PDCCH-ConfigPUCCH',
                                                                              'optional': True,
                                                                              'type': 'TPC-PDCCH-Config'},
                                                                             {'name': 'tpc-PDCCH-ConfigPUSCH',
                                                                              'optional': True,
                                                                              'type': 'TPC-PDCCH-Config'},
                                                                             {'name': 'cqi-ReportConfig',
                                                                              'optional': True,
                                                                              'type': 'CQI-ReportConfig'},
                                                                             {'name': 'soundingRS-UL-ConfigDedicated',
                                                                              'optional': True,
                                                                              'type': 'SoundingRS-UL-ConfigDedicated'},
                                                                             {'members': [{'name': 'explicitValue',
                                                                                           'type': 'AntennaInfoDedicated'},
                                                                                          {'name': 'defaultValue',
                                                                                           'type': 'NULL'}],
                                                                              'name': 'antennaInfo',
                                                                              'optional': True,
                                                                              'type': 'CHOICE'},
                                                                             {'name': 'schedulingRequestConfig',
                                                                              'optional': True,
                                                                              'type': 'SchedulingRequestConfig'},
                                                                             None],
                                                                 'type': 'SEQUENCE'},
                                     'PollByte': {'type': 'ENUMERATED',
                                                  'values': [('kB25', 0),
                                                             ('kB50', 1),
                                                             ('kB75', 2),
                                                             ('kB100', 3),
                                                             ('kB125', 4),
                                                             ('kB250', 5),
                                                             ('kB375', 6),
                                                             ('kB500', 7),
                                                             ('kB750', 8),
                                                             ('kB1000', 9),
                                                             ('kB1250', 10),
                                                             ('kB1500', 11),
                                                             ('kB2000', 12),
                                                             ('kB3000', 13),
                                                             ('kBinfinity', 14),
                                                             ('spare1', 15)]},
                                     'PollPDU': {'type': 'ENUMERATED',
                                                 'values': [('p4', 0),
                                                            ('p8', 1),
                                                            ('p16', 2),
                                                            ('p32', 3),
                                                            ('p64', 4),
                                                            ('p128', 5),
                                                            ('p256', 6),
                                                            ('pInfinity', 7)]},
                                     'PreRegistrationInfoHRPD': {'members': [{'name': 'preRegistrationAllowed',
                                                                              'type': 'BOOLEAN'},
                                                                             {'name': 'preRegistrationZoneId',
                                                                              'optional': True,
                                                                              'type': 'PreRegistrationZoneIdHRPD'},
                                                                             {'name': 'secondaryPreRegistrationZoneIdList',
                                                                              'optional': True,
                                                                              'type': 'SecondaryPreRegistrationZoneIdListHRPD'}],
                                                                 'type': 'SEQUENCE'},
                                     'PreRegistrationZoneIdHRPD': {'restricted-to': [(0,
                                                                                      255)],
                                                                   'type': 'INTEGER'},
                                     'PresenceAntennaPort1': {'type': 'BOOLEAN'},
                                     'Q-OffsetRange': {'type': 'ENUMERATED',
                                                       'values': [('dB-24', 0),
                                                                  ('dB-22', 1),
                                                                  ('dB-20', 2),
                                                                  ('dB-18', 3),
                                                                  ('dB-16', 4),
                                                                  ('dB-14', 5),
                                                                  ('dB-12', 6),
                                                                  ('dB-10', 7),
                                                                  ('dB-8', 8),
                                                                  ('dB-6', 9),
                                                                  ('dB-5', 10),
                                                                  ('dB-4', 11),
                                                                  ('dB-3', 12),
                                                                  ('dB-2', 13),
                                                                  ('dB-1', 14),
                                                                  ('dB0', 15),
                                                                  ('dB1', 16),
                                                                  ('dB2', 17),
                                                                  ('dB3', 18),
                                                                  ('dB4', 19),
                                                                  ('dB5', 20),
                                                                  ('dB6', 21),
                                                                  ('dB8', 22),
                                                                  ('dB10', 23),
                                                                  ('dB12', 24),
                                                                  ('dB14', 25),
                                                                  ('dB16', 26),
                                                                  ('dB18', 27),
                                                                  ('dB20', 28),
                                                                  ('dB22', 29),
                                                                  ('dB24',
                                                                   30)]},
                                     'Q-OffsetRangeInterRAT': {'restricted-to': [(-15,
                                                                                  15)],
                                                               'type': 'INTEGER'},
                                     'Q-RxLevMin': {'restricted-to': [(-70,
                                                                       -22)],
                                                    'type': 'INTEGER'},
                                     'QuantityConfig': {'members': [{'name': 'quantityConfigEUTRA',
                                                                     'optional': True,
                                                                     'type': 'QuantityConfigEUTRA'},
                                                                    {'name': 'quantityConfigUTRA',
                                                                     'optional': True,
                                                                     'type': 'QuantityConfigUTRA'},
                                                                    {'name': 'quantityConfigGERAN',
                                                                     'optional': True,
                                                                     'type': 'QuantityConfigGERAN'},
                                                                    {'name': 'quantityConfigCDMA2000',
                                                                     'optional': True,
                                                                     'type': 'QuantityConfigCDMA2000'},
                                                                    None],
                                                        'type': 'SEQUENCE'},
                                     'QuantityConfigCDMA2000': {'members': [{'name': 'measQuantityCDMA2000',
                                                                             'type': 'ENUMERATED',
                                                                             'values': [('pilotStrength',
                                                                                         0),
                                                                                        ('pilotPnPhaseAndPilotStrength',
                                                                                         1)]}],
                                                                'type': 'SEQUENCE'},
                                     'QuantityConfigEUTRA': {'members': [{'default': 'fc4',
                                                                          'name': 'filterCoefficientRSRP',
                                                                          'type': 'FilterCoefficient'},
                                                                         {'default': 'fc4',
                                                                          'name': 'filterCoefficientRSRQ',
                                                                          'type': 'FilterCoefficient'}],
                                                             'type': 'SEQUENCE'},
                                     'QuantityConfigGERAN': {'members': [{'name': 'measQuantityGERAN',
                                                                          'type': 'ENUMERATED',
                                                                          'values': [('rssi',
                                                                                      0)]},
                                                                         {'default': 'fc2',
                                                                          'name': 'filterCoefficient',
                                                                          'type': 'FilterCoefficient'}],
                                                             'type': 'SEQUENCE'},
                                     'QuantityConfigUTRA': {'members': [{'name': 'measQuantityUTRA-FDD',
                                                                         'type': 'ENUMERATED',
                                                                         'values': [('cpich-RSCP',
                                                                                     0),
                                                                                    ('cpich-EcN0',
                                                                                     1)]},
                                                                        {'name': 'measQuantityUTRA-TDD',
                                                                         'type': 'ENUMERATED',
                                                                         'values': [('pccpch-RSCP',
                                                                                     0)]},
                                                                        {'default': 'fc4',
                                                                         'name': 'filterCoefficient',
                                                                         'type': 'FilterCoefficient'}],
                                                            'type': 'SEQUENCE'},
                                     'RACH-ConfigCommon': {'members': [{'members': [{'name': 'numberOfRA-Preambles',
                                                                                     'type': 'ENUMERATED',
                                                                                     'values': [('n4',
                                                                                                 0),
                                                                                                ('n8',
                                                                                                 1),
                                                                                                ('n12',
                                                                                                 2),
                                                                                                ('n16',
                                                                                                 3),
                                                                                                ('n20',
                                                                                                 4),
                                                                                                ('n24',
                                                                                                 5),
                                                                                                ('n28',
                                                                                                 6),
                                                                                                ('n32',
                                                                                                 7),
                                                                                                ('n36',
                                                                                                 8),
                                                                                                ('n40',
                                                                                                 9),
                                                                                                ('n44',
                                                                                                 10),
                                                                                                ('n48',
                                                                                                 11),
                                                                                                ('n52',
                                                                                                 12),
                                                                                                ('n56',
                                                                                                 13),
                                                                                                ('n60',
                                                                                                 14),
                                                                                                ('n64',
                                                                                                 15)]},
                                                                                    {'members': [{'name': 'sizeOfRA-PreamblesGroupA',
                                                                                                  'type': 'ENUMERATED',
                                                                                                  'values': [('n4',
                                                                                                              0),
                                                                                                             ('n8',
                                                                                                              1),
                                                                                                             ('n12',
                                                                                                              2),
                                                                                                             ('n16',
                                                                                                              3),
                                                                                                             ('n20',
                                                                                                              4),
                                                                                                             ('n24',
                                                                                                              5),
                                                                                                             ('n28',
                                                                                                              6),
                                                                                                             ('n32',
                                                                                                              7),
                                                                                                             ('n36',
                                                                                                              8),
                                                                                                             ('n40',
                                                                                                              9),
                                                                                                             ('n44',
                                                                                                              10),
                                                                                                             ('n48',
                                                                                                              11),
                                                                                                             ('n52',
                                                                                                              12),
                                                                                                             ('n56',
                                                                                                              13),
                                                                                                             ('n60',
                                                                                                              14)]},
                                                                                                 {'name': 'messageSizeGroupA',
                                                                                                  'type': 'ENUMERATED',
                                                                                                  'values': [('b56',
                                                                                                              0),
                                                                                                             ('b144',
                                                                                                              1),
                                                                                                             ('b208',
                                                                                                              2),
                                                                                                             ('b256',
                                                                                                              3)]},
                                                                                                 {'name': 'messagePowerOffsetGroupB',
                                                                                                  'type': 'ENUMERATED',
                                                                                                  'values': [('minusinfinity',
                                                                                                              0),
                                                                                                             ('dB0',
                                                                                                              1),
                                                                                                             ('dB5',
                                                                                                              2),
                                                                                                             ('dB8',
                                                                                                              3),
                                                                                                             ('dB10',
                                                                                                              4),
                                                                                                             ('dB12',
                                                                                                              5),
                                                                                                             ('dB15',
                                                                                                              6),
                                                                                                             ('dB18',
                                                                                                              7)]},
                                                                                                 None],
                                                                                     'name': 'preamblesGroupAConfig',
                                                                                     'optional': True,
                                                                                     'type': 'SEQUENCE'}],
                                                                        'name': 'preambleInfo',
                                                                        'type': 'SEQUENCE'},
                                                                       {'members': [{'name': 'powerRampingStep',
                                                                                     'type': 'ENUMERATED',
                                                                                     'values': [('dB0',
                                                                                                 0),
                                                                                                ('dB2',
                                                                                                 1),
                                                                                                ('dB4',
                                                                                                 2),
                                                                                                ('dB6',
                                                                                                 3)]},
                                                                                    {'name': 'preambleInitialReceivedTargetPower',
                                                                                     'type': 'ENUMERATED',
                                                                                     'values': [('dBm-120',
                                                                                                 0),
                                                                                                ('dBm-118',
                                                                                                 1),
                                                                                                ('dBm-116',
                                                                                                 2),
                                                                                                ('dBm-114',
                                                                                                 3),
                                                                                                ('dBm-112',
                                                                                                 4),
                                                                                                ('dBm-110',
                                                                                                 5),
                                                                                                ('dBm-108',
                                                                                                 6),
                                                                                                ('dBm-106',
                                                                                                 7),
                                                                                                ('dBm-104',
                                                                                                 8),
                                                                                                ('dBm-102',
                                                                                                 9),
                                                                                                ('dBm-100',
                                                                                                 10),
                                                                                                ('dBm-98',
                                                                                                 11),
                                                                                                ('dBm-96',
                                                                                                 12),
                                                                                                ('dBm-94',
                                                                                                 13),
                                                                                                ('dBm-92',
                                                                                                 14),
                                                                                                ('dBm-90',
                                                                                                 15)]}],
                                                                        'name': 'powerRampingParameters',
                                                                        'type': 'SEQUENCE'},
                                                                       {'members': [{'name': 'preambleTransMax',
                                                                                     'type': 'ENUMERATED',
                                                                                     'values': [('n3',
                                                                                                 0),
                                                                                                ('n4',
                                                                                                 1),
                                                                                                ('n5',
                                                                                                 2),
                                                                                                ('n6',
                                                                                                 3),
                                                                                                ('n7',
                                                                                                 4),
                                                                                                ('n8',
                                                                                                 5),
                                                                                                ('n10',
                                                                                                 6),
                                                                                                ('n20',
                                                                                                 7),
                                                                                                ('n50',
                                                                                                 8),
                                                                                                ('n100',
                                                                                                 9),
                                                                                                ('n200',
                                                                                                 10)]},
                                                                                    {'name': 'ra-ResponseWindowSize',
                                                                                     'type': 'ENUMERATED',
                                                                                     'values': [('sf2',
                                                                                                 0),
                                                                                                ('sf3',
                                                                                                 1),
                                                                                                ('sf4',
                                                                                                 2),
                                                                                                ('sf5',
                                                                                                 3),
                                                                                                ('sf6',
                                                                                                 4),
                                                                                                ('sf7',
                                                                                                 5),
                                                                                                ('sf8',
                                                                                                 6),
                                                                                                ('sf10',
                                                                                                 7)]},
                                                                                    {'name': 'mac-ContentionResolutionTimer',
                                                                                     'type': 'ENUMERATED',
                                                                                     'values': [('sf8',
                                                                                                 0),
                                                                                                ('sf16',
                                                                                                 1),
                                                                                                ('sf24',
                                                                                                 2),
                                                                                                ('sf32',
                                                                                                 3),
                                                                                                ('sf40',
                                                                                                 4),
                                                                                                ('sf48',
                                                                                                 5),
                                                                                                ('sf56',
                                                                                                 6),
                                                                                                ('sf64',
                                                                                                 7)]}],
                                                                        'name': 'ra-SupervisionInfo',
                                                                        'type': 'SEQUENCE'},
                                                                       {'name': 'maxHARQ-Msg3Tx',
                                                                        'restricted-to': [(1,
                                                                                           8)],
                                                                        'type': 'INTEGER'},
                                                                       None],
                                                           'type': 'SEQUENCE'},
                                     'RACH-ConfigDedicated': {'members': [{'name': 'ra-PreambleIndex',
                                                                           'restricted-to': [(0,
                                                                                              63)],
                                                                           'type': 'INTEGER'},
                                                                          {'name': 'ra-PRACH-MaskIndex',
                                                                           'restricted-to': [(0,
                                                                                              15)],
                                                                           'type': 'INTEGER'}],
                                                              'type': 'SEQUENCE'},
                                     'RAND-CDMA2000': {'size': [32],
                                                       'type': 'BIT STRING'},
                                     'RAT-Type': {'type': 'ENUMERATED',
                                                  'values': [('eutra', 0),
                                                             ('utra', 1),
                                                             ('geran-cs', 2),
                                                             ('geran-ps', 3),
                                                             ('cdma2000-1XRTT',
                                                              4),
                                                             ('spare3', 5),
                                                             ('spare2', 6),
                                                             ('spare1', 7),
                                                             None]},
                                     'RF-Parameters': {'members': [{'name': 'supportedBandListEUTRA',
                                                                    'type': 'SupportedBandListEUTRA'}],
                                                       'type': 'SEQUENCE'},
                                     'RLC-Config': {'members': [{'members': [{'name': 'ul-AM-RLC',
                                                                              'type': 'UL-AM-RLC'},
                                                                             {'name': 'dl-AM-RLC',
                                                                              'type': 'DL-AM-RLC'}],
                                                                 'name': 'am',
                                                                 'type': 'SEQUENCE'},
                                                                {'members': [{'name': 'ul-UM-RLC',
                                                                              'type': 'UL-UM-RLC'},
                                                                             {'name': 'dl-UM-RLC',
                                                                              'type': 'DL-UM-RLC'}],
                                                                 'name': 'um-Bi-Directional',
                                                                 'type': 'SEQUENCE'},
                                                                {'members': [{'name': 'ul-UM-RLC',
                                                                              'type': 'UL-UM-RLC'}],
                                                                 'name': 'um-Uni-Directional-UL',
                                                                 'type': 'SEQUENCE'},
                                                                {'members': [{'name': 'dl-UM-RLC',
                                                                              'type': 'DL-UM-RLC'}],
                                                                 'name': 'um-Uni-Directional-DL',
                                                                 'type': 'SEQUENCE'},
                                                                None],
                                                    'type': 'CHOICE'},
                                     'RRC-TransactionIdentifier': {'restricted-to': [(0,
                                                                                      3)],
                                                                   'type': 'INTEGER'},
                                     'RRCConnectionReconfiguration': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                                   'type': 'RRC-TransactionIdentifier'},
                                                                                  {'members': [{'members': [{'name': 'rrcConnectionReconfiguration-r8',
                                                                                                             'type': 'RRCConnectionReconfiguration-r8-IEs'},
                                                                                                            {'name': 'spare7',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare6',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare5',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare4',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare3',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare2',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare1',
                                                                                                             'type': 'NULL'}],
                                                                                                'name': 'c1',
                                                                                                'type': 'CHOICE'},
                                                                                               {'members': [],
                                                                                                'name': 'criticalExtensionsFuture',
                                                                                                'type': 'SEQUENCE'}],
                                                                                   'name': 'criticalExtensions',
                                                                                   'type': 'CHOICE'}],
                                                                      'type': 'SEQUENCE'},
                                     'RRCConnectionReconfiguration-r8-IEs': {'members': [{'name': 'measConfig',
                                                                                          'optional': True,
                                                                                          'type': 'MeasConfig'},
                                                                                         {'name': 'mobilityControlInfo',
                                                                                          'optional': True,
                                                                                          'type': 'MobilityControlInfo'},
                                                                                         {'element': {'type': 'DedicatedInfoNAS'},
                                                                                          'name': 'dedicatedInfoNASList',
                                                                                          'optional': True,
                                                                                          'size': [(1,
                                                                                                    'maxDRB')],
                                                                                          'type': 'SEQUENCE '
                                                                                                  'OF'},
                                                                                         {'name': 'radioResourceConfigDedicated',
                                                                                          'optional': True,
                                                                                          'type': 'RadioResourceConfigDedicated'},
                                                                                         {'name': 'securityConfigHO',
                                                                                          'optional': True,
                                                                                          'type': 'SecurityConfigHO'},
                                                                                         {'members': [],
                                                                                          'name': 'nonCriticalExtension',
                                                                                          'optional': True,
                                                                                          'type': 'SEQUENCE'}],
                                                                             'type': 'SEQUENCE'},
                                     'RRCConnectionReconfigurationComplete': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                                           'type': 'RRC-TransactionIdentifier'},
                                                                                          {'members': [{'name': 'rrcConnectionReconfigurationComplete-r8',
                                                                                                        'type': 'RRCConnectionReconfigurationComplete-r8-IEs'},
                                                                                                       {'members': [],
                                                                                                        'name': 'criticalExtensionsFuture',
                                                                                                        'type': 'SEQUENCE'}],
                                                                                           'name': 'criticalExtensions',
                                                                                           'type': 'CHOICE'}],
                                                                              'type': 'SEQUENCE'},
                                     'RRCConnectionReconfigurationComplete-r8-IEs': {'members': [{'members': [],
                                                                                                  'name': 'nonCriticalExtension',
                                                                                                  'optional': True,
                                                                                                  'type': 'SEQUENCE'}],
                                                                                     'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishment': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                                   'type': 'RRC-TransactionIdentifier'},
                                                                                  {'members': [{'members': [{'name': 'rrcConnectionReestablishment-r8',
                                                                                                             'type': 'RRCConnectionReestablishment-r8-IEs'},
                                                                                                            {'name': 'spare7',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare6',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare5',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare4',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare3',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare2',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare1',
                                                                                                             'type': 'NULL'}],
                                                                                                'name': 'c1',
                                                                                                'type': 'CHOICE'},
                                                                                               {'members': [],
                                                                                                'name': 'criticalExtensionsFuture',
                                                                                                'type': 'SEQUENCE'}],
                                                                                   'name': 'criticalExtensions',
                                                                                   'type': 'CHOICE'}],
                                                                      'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishment-r8-IEs': {'members': [{'name': 'radioResourceConfigDedicated',
                                                                                          'type': 'RadioResourceConfigDedicated'},
                                                                                         {'name': 'nextHopChainingCount',
                                                                                          'type': 'NextHopChainingCount'},
                                                                                         {'members': [],
                                                                                          'name': 'nonCriticalExtension',
                                                                                          'optional': True,
                                                                                          'type': 'SEQUENCE'}],
                                                                             'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishmentComplete': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                                           'type': 'RRC-TransactionIdentifier'},
                                                                                          {'members': [{'name': 'rrcConnectionReestablishmentComplete-r8',
                                                                                                        'type': 'RRCConnectionReestablishmentComplete-r8-IEs'},
                                                                                                       {'members': [],
                                                                                                        'name': 'criticalExtensionsFuture',
                                                                                                        'type': 'SEQUENCE'}],
                                                                                           'name': 'criticalExtensions',
                                                                                           'type': 'CHOICE'}],
                                                                              'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishmentComplete-r8-IEs': {'members': [{'members': [],
                                                                                                  'name': 'nonCriticalExtension',
                                                                                                  'optional': True,
                                                                                                  'type': 'SEQUENCE'}],
                                                                                     'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishmentReject': {'members': [{'members': [{'name': 'rrcConnectionReestablishmentReject-r8',
                                                                                                      'type': 'RRCConnectionReestablishmentReject-r8-IEs'},
                                                                                                     {'members': [],
                                                                                                      'name': 'criticalExtensionsFuture',
                                                                                                      'type': 'SEQUENCE'}],
                                                                                         'name': 'criticalExtensions',
                                                                                         'type': 'CHOICE'}],
                                                                            'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishmentReject-r8-IEs': {'members': [{'members': [],
                                                                                                'name': 'nonCriticalExtension',
                                                                                                'optional': True,
                                                                                                'type': 'SEQUENCE'}],
                                                                                   'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishmentRequest': {'members': [{'members': [{'name': 'rrcConnectionReestablishmentRequest-r8',
                                                                                                       'type': 'RRCConnectionReestablishmentRequest-r8-IEs'},
                                                                                                      {'members': [],
                                                                                                       'name': 'criticalExtensionsFuture',
                                                                                                       'type': 'SEQUENCE'}],
                                                                                          'name': 'criticalExtensions',
                                                                                          'type': 'CHOICE'}],
                                                                             'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishmentRequest-r8-IEs': {'members': [{'name': 'ue-Identity',
                                                                                                 'type': 'ReestabUE-Identity'},
                                                                                                {'name': 'reestablishmentCause',
                                                                                                 'type': 'ReestablishmentCause'},
                                                                                                {'name': 'spare',
                                                                                                 'size': [2],
                                                                                                 'type': 'BIT '
                                                                                                         'STRING'}],
                                                                                    'type': 'SEQUENCE'},
                                     'RRCConnectionReject': {'members': [{'members': [{'members': [{'name': 'rrcConnectionReject-r8',
                                                                                                    'type': 'RRCConnectionReject-r8-IEs'},
                                                                                                   {'name': 'spare3',
                                                                                                    'type': 'NULL'},
                                                                                                   {'name': 'spare2',
                                                                                                    'type': 'NULL'},
                                                                                                   {'name': 'spare1',
                                                                                                    'type': 'NULL'}],
                                                                                       'name': 'c1',
                                                                                       'type': 'CHOICE'},
                                                                                      {'members': [],
                                                                                       'name': 'criticalExtensionsFuture',
                                                                                       'type': 'SEQUENCE'}],
                                                                          'name': 'criticalExtensions',
                                                                          'type': 'CHOICE'}],
                                                             'type': 'SEQUENCE'},
                                     'RRCConnectionReject-r8-IEs': {'members': [{'name': 'waitTime',
                                                                                 'restricted-to': [(1,
                                                                                                    16)],
                                                                                 'type': 'INTEGER'},
                                                                                {'members': [],
                                                                                 'name': 'nonCriticalExtension',
                                                                                 'optional': True,
                                                                                 'type': 'SEQUENCE'}],
                                                                    'type': 'SEQUENCE'},
                                     'RRCConnectionRelease': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                           'type': 'RRC-TransactionIdentifier'},
                                                                          {'members': [{'members': [{'name': 'rrcConnectionRelease-r8',
                                                                                                     'type': 'RRCConnectionRelease-r8-IEs'},
                                                                                                    {'name': 'spare3',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare2',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare1',
                                                                                                     'type': 'NULL'}],
                                                                                        'name': 'c1',
                                                                                        'type': 'CHOICE'},
                                                                                       {'members': [],
                                                                                        'name': 'criticalExtensionsFuture',
                                                                                        'type': 'SEQUENCE'}],
                                                                           'name': 'criticalExtensions',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                     'RRCConnectionRelease-r8-IEs': {'members': [{'name': 'releaseCause',
                                                                                  'type': 'ReleaseCause'},
                                                                                 {'name': 'redirectedCarrierInfo',
                                                                                  'optional': True,
                                                                                  'type': 'RedirectedCarrierInfo'},
                                                                                 {'name': 'idleModeMobilityControlInfo',
                                                                                  'optional': True,
                                                                                  'type': 'IdleModeMobilityControlInfo'},
                                                                                 {'members': [],
                                                                                  'name': 'nonCriticalExtension',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'}],
                                                                     'type': 'SEQUENCE'},
                                     'RRCConnectionRequest': {'members': [{'members': [{'name': 'rrcConnectionRequest-r8',
                                                                                        'type': 'RRCConnectionRequest-r8-IEs'},
                                                                                       {'members': [],
                                                                                        'name': 'criticalExtensionsFuture',
                                                                                        'type': 'SEQUENCE'}],
                                                                           'name': 'criticalExtensions',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                     'RRCConnectionRequest-r8-IEs': {'members': [{'name': 'ue-Identity',
                                                                                  'type': 'InitialUE-Identity'},
                                                                                 {'name': 'establishmentCause',
                                                                                  'type': 'EstablishmentCause'},
                                                                                 {'name': 'spare',
                                                                                  'size': [1],
                                                                                  'type': 'BIT '
                                                                                          'STRING'}],
                                                                     'type': 'SEQUENCE'},
                                     'RRCConnectionSetup': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                         'type': 'RRC-TransactionIdentifier'},
                                                                        {'members': [{'members': [{'name': 'rrcConnectionSetup-r8',
                                                                                                   'type': 'RRCConnectionSetup-r8-IEs'},
                                                                                                  {'name': 'spare7',
                                                                                                   'type': 'NULL'},
                                                                                                  {'name': 'spare6',
                                                                                                   'type': 'NULL'},
                                                                                                  {'name': 'spare5',
                                                                                                   'type': 'NULL'},
                                                                                                  {'name': 'spare4',
                                                                                                   'type': 'NULL'},
                                                                                                  {'name': 'spare3',
                                                                                                   'type': 'NULL'},
                                                                                                  {'name': 'spare2',
                                                                                                   'type': 'NULL'},
                                                                                                  {'name': 'spare1',
                                                                                                   'type': 'NULL'}],
                                                                                      'name': 'c1',
                                                                                      'type': 'CHOICE'},
                                                                                     {'members': [],
                                                                                      'name': 'criticalExtensionsFuture',
                                                                                      'type': 'SEQUENCE'}],
                                                                         'name': 'criticalExtensions',
                                                                         'type': 'CHOICE'}],
                                                            'type': 'SEQUENCE'},
                                     'RRCConnectionSetup-r8-IEs': {'members': [{'name': 'radioResourceConfigDedicated',
                                                                                'type': 'RadioResourceConfigDedicated'},
                                                                               {'members': [],
                                                                                'name': 'nonCriticalExtension',
                                                                                'optional': True,
                                                                                'type': 'SEQUENCE'}],
                                                                   'type': 'SEQUENCE'},
                                     'RRCConnectionSetupComplete': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                                 'type': 'RRC-TransactionIdentifier'},
                                                                                {'members': [{'members': [{'name': 'rrcConnectionSetupComplete-r8',
                                                                                                           'type': 'RRCConnectionSetupComplete-r8-IEs'},
                                                                                                          {'name': 'spare3',
                                                                                                           'type': 'NULL'},
                                                                                                          {'name': 'spare2',
                                                                                                           'type': 'NULL'},
                                                                                                          {'name': 'spare1',
                                                                                                           'type': 'NULL'}],
                                                                                              'name': 'c1',
                                                                                              'type': 'CHOICE'},
                                                                                             {'members': [],
                                                                                              'name': 'criticalExtensionsFuture',
                                                                                              'type': 'SEQUENCE'}],
                                                                                 'name': 'criticalExtensions',
                                                                                 'type': 'CHOICE'}],
                                                                    'type': 'SEQUENCE'},
                                     'RRCConnectionSetupComplete-r8-IEs': {'members': [{'name': 'selectedPLMN-Identity',
                                                                                        'restricted-to': [(1,
                                                                                                           6)],
                                                                                        'type': 'INTEGER'},
                                                                                       {'name': 'registeredMME',
                                                                                        'optional': True,
                                                                                        'type': 'RegisteredMME'},
                                                                                       {'name': 'dedicatedInfoNAS',
                                                                                        'type': 'DedicatedInfoNAS'},
                                                                                       {'members': [],
                                                                                        'name': 'nonCriticalExtension',
                                                                                        'optional': True,
                                                                                        'type': 'SEQUENCE'}],
                                                                           'type': 'SEQUENCE'},
                                     'RSRP-Range': {'restricted-to': [(0, 97)],
                                                    'type': 'INTEGER'},
                                     'RSRQ-Range': {'restricted-to': [(0, 34)],
                                                    'type': 'INTEGER'},
                                     'RadioResourceConfigCommon': {'members': [{'name': 'rach-ConfigCommon',
                                                                                'optional': True,
                                                                                'type': 'RACH-ConfigCommon'},
                                                                               {'name': 'prach-Config',
                                                                                'type': 'PRACH-Config'},
                                                                               {'name': 'pdsch-ConfigCommon',
                                                                                'optional': True,
                                                                                'type': 'PDSCH-ConfigCommon'},
                                                                               {'name': 'pusch-ConfigCommon',
                                                                                'type': 'PUSCH-ConfigCommon'},
                                                                               {'name': 'phich-Config',
                                                                                'optional': True,
                                                                                'type': 'PHICH-Config'},
                                                                               {'name': 'pucch-ConfigCommon',
                                                                                'optional': True,
                                                                                'type': 'PUCCH-ConfigCommon'},
                                                                               {'name': 'soundingRS-UL-ConfigCommon',
                                                                                'optional': True,
                                                                                'type': 'SoundingRS-UL-ConfigCommon'},
                                                                               {'name': 'uplinkPowerControlCommon',
                                                                                'optional': True,
                                                                                'type': 'UplinkPowerControlCommon'},
                                                                               {'name': 'antennaInfoCommon',
                                                                                'optional': True,
                                                                                'type': 'AntennaInfoCommon'},
                                                                               {'name': 'p-Max',
                                                                                'optional': True,
                                                                                'type': 'P-Max'},
                                                                               {'name': 'tdd-Config',
                                                                                'optional': True,
                                                                                'type': 'TDD-Config'},
                                                                               {'name': 'ul-CyclicPrefixLength',
                                                                                'type': 'UL-CyclicPrefixLength'},
                                                                               None],
                                                                   'type': 'SEQUENCE'},
                                     'RadioResourceConfigCommonSIB': {'members': [{'name': 'rach-ConfigCommon',
                                                                                   'type': 'RACH-ConfigCommon'},
                                                                                  {'name': 'bcch-Config',
                                                                                   'type': 'BCCH-Config'},
                                                                                  {'name': 'pcch-Config',
                                                                                   'type': 'PCCH-Config'},
                                                                                  {'name': 'prach-Config',
                                                                                   'type': 'PRACH-ConfigSIB'},
                                                                                  {'name': 'pdsch-ConfigCommon',
                                                                                   'type': 'PDSCH-ConfigCommon'},
                                                                                  {'name': 'pusch-ConfigCommon',
                                                                                   'type': 'PUSCH-ConfigCommon'},
                                                                                  {'name': 'pucch-ConfigCommon',
                                                                                   'type': 'PUCCH-ConfigCommon'},
                                                                                  {'name': 'soundingRS-UL-ConfigCommon',
                                                                                   'type': 'SoundingRS-UL-ConfigCommon'},
                                                                                  {'name': 'uplinkPowerControlCommon',
                                                                                   'type': 'UplinkPowerControlCommon'},
                                                                                  {'name': 'ul-CyclicPrefixLength',
                                                                                   'type': 'UL-CyclicPrefixLength'},
                                                                                  None],
                                                                      'type': 'SEQUENCE'},
                                     'RadioResourceConfigDedicated': {'members': [{'name': 'srb-ToAddModList',
                                                                                   'optional': True,
                                                                                   'type': 'SRB-ToAddModList'},
                                                                                  {'name': 'drb-ToAddModList',
                                                                                   'optional': True,
                                                                                   'type': 'DRB-ToAddModList'},
                                                                                  {'name': 'drb-ToReleaseList',
                                                                                   'optional': True,
                                                                                   'type': 'DRB-ToReleaseList'},
                                                                                  {'members': [{'name': 'explicitValue',
                                                                                                'type': 'MAC-MainConfig'},
                                                                                               {'name': 'defaultValue',
                                                                                                'type': 'NULL'}],
                                                                                   'name': 'mac-MainConfig',
                                                                                   'optional': True,
                                                                                   'type': 'CHOICE'},
                                                                                  {'name': 'sps-Config',
                                                                                   'optional': True,
                                                                                   'type': 'SPS-Config'},
                                                                                  {'name': 'physicalConfigDedicated',
                                                                                   'optional': True,
                                                                                   'type': 'PhysicalConfigDedicated'},
                                                                                  None],
                                                                      'type': 'SEQUENCE'},
                                     'RedirectedCarrierInfo': {'members': [{'name': 'eutra',
                                                                            'type': 'ARFCN-ValueEUTRA'},
                                                                           {'name': 'geran',
                                                                            'type': 'CarrierFreqsGERAN'},
                                                                           {'name': 'utra-FDD',
                                                                            'type': 'ARFCN-ValueUTRA'},
                                                                           {'name': 'utra-TDD',
                                                                            'type': 'ARFCN-ValueUTRA'},
                                                                           {'name': 'cdma2000-HRPD',
                                                                            'type': 'CarrierFreqCDMA2000'},
                                                                           {'name': 'cdma2000-1xRTT',
                                                                            'type': 'CarrierFreqCDMA2000'},
                                                                           None],
                                                               'type': 'CHOICE'},
                                     'ReestabUE-Identity': {'members': [{'name': 'c-RNTI',
                                                                         'type': 'C-RNTI'},
                                                                        {'name': 'physCellId',
                                                                         'type': 'PhysCellId'},
                                                                        {'name': 'shortMAC-I',
                                                                         'type': 'ShortMAC-I'}],
                                                            'type': 'SEQUENCE'},
                                     'ReestablishmentCause': {'type': 'ENUMERATED',
                                                              'values': [('reconfigurationFailure',
                                                                          0),
                                                                         ('handoverFailure',
                                                                          1),
                                                                         ('otherFailure',
                                                                          2),
                                                                         ('spare1',
                                                                          3)]},
                                     'RegisteredMME': {'members': [{'name': 'plmn-Identity',
                                                                    'optional': True,
                                                                    'type': 'PLMN-Identity'},
                                                                   {'name': 'mmegi',
                                                                    'size': [16],
                                                                    'type': 'BIT '
                                                                            'STRING'},
                                                                   {'name': 'mmec',
                                                                    'type': 'MMEC'}],
                                                       'type': 'SEQUENCE'},
                                     'ReleaseCause': {'type': 'ENUMERATED',
                                                      'values': [('loadBalancingTAUrequired',
                                                                  0),
                                                                 ('other', 1),
                                                                 ('spare2', 2),
                                                                 ('spare1',
                                                                  3)]},
                                     'ReportConfigEUTRA': {'members': [{'members': [{'members': [{'members': [{'members': [{'name': 'a1-Threshold',
                                                                                                                            'type': 'ThresholdEUTRA'}],
                                                                                                               'name': 'eventA1',
                                                                                                               'type': 'SEQUENCE'},
                                                                                                              {'members': [{'name': 'a2-Threshold',
                                                                                                                            'type': 'ThresholdEUTRA'}],
                                                                                                               'name': 'eventA2',
                                                                                                               'type': 'SEQUENCE'},
                                                                                                              {'members': [{'name': 'a3-Offset',
                                                                                                                            'restricted-to': [(-30,
                                                                                                                                               30)],
                                                                                                                            'type': 'INTEGER'},
                                                                                                                           {'name': 'reportOnLeave',
                                                                                                                            'type': 'BOOLEAN'}],
                                                                                                               'name': 'eventA3',
                                                                                                               'type': 'SEQUENCE'},
                                                                                                              {'members': [{'name': 'a4-Threshold',
                                                                                                                            'type': 'ThresholdEUTRA'}],
                                                                                                               'name': 'eventA4',
                                                                                                               'type': 'SEQUENCE'},
                                                                                                              {'members': [{'name': 'a5-Threshold1',
                                                                                                                            'type': 'ThresholdEUTRA'},
                                                                                                                           {'name': 'a5-Threshold2',
                                                                                                                            'type': 'ThresholdEUTRA'}],
                                                                                                               'name': 'eventA5',
                                                                                                               'type': 'SEQUENCE'},
                                                                                                              None],
                                                                                                  'name': 'eventId',
                                                                                                  'type': 'CHOICE'},
                                                                                                 {'name': 'hysteresis',
                                                                                                  'type': 'Hysteresis'},
                                                                                                 {'name': 'timeToTrigger',
                                                                                                  'type': 'TimeToTrigger'}],
                                                                                     'name': 'event',
                                                                                     'type': 'SEQUENCE'},
                                                                                    {'members': [{'name': 'purpose',
                                                                                                  'type': 'ENUMERATED',
                                                                                                  'values': [('reportStrongestCells',
                                                                                                              0),
                                                                                                             ('reportCGI',
                                                                                                              1)]}],
                                                                                     'name': 'periodical',
                                                                                     'type': 'SEQUENCE'}],
                                                                        'name': 'triggerType',
                                                                        'type': 'CHOICE'},
                                                                       {'name': 'triggerQuantity',
                                                                        'type': 'ENUMERATED',
                                                                        'values': [('rsrp',
                                                                                    0),
                                                                                   ('rsrq',
                                                                                    1)]},
                                                                       {'name': 'reportQuantity',
                                                                        'type': 'ENUMERATED',
                                                                        'values': [('sameAsTriggerQuantity',
                                                                                    0),
                                                                                   ('both',
                                                                                    1)]},
                                                                       {'name': 'maxReportCells',
                                                                        'restricted-to': [(1,
                                                                                           'maxCellReport')],
                                                                        'type': 'INTEGER'},
                                                                       {'name': 'reportInterval',
                                                                        'type': 'ReportInterval'},
                                                                       {'name': 'reportAmount',
                                                                        'type': 'ENUMERATED',
                                                                        'values': [('r1',
                                                                                    0),
                                                                                   ('r2',
                                                                                    1),
                                                                                   ('r4',
                                                                                    2),
                                                                                   ('r8',
                                                                                    3),
                                                                                   ('r16',
                                                                                    4),
                                                                                   ('r32',
                                                                                    5),
                                                                                   ('r64',
                                                                                    6),
                                                                                   ('infinity',
                                                                                    7)]},
                                                                       None],
                                                           'type': 'SEQUENCE'},
                                     'ReportConfigId': {'restricted-to': [(1,
                                                                           'maxReportConfigId')],
                                                        'type': 'INTEGER'},
                                     'ReportConfigInterRAT': {'members': [{'members': [{'members': [{'members': [{'members': [{'members': [{'name': 'b1-ThresholdUTRA',
                                                                                                                                            'type': 'ThresholdUTRA'},
                                                                                                                                           {'name': 'b1-ThresholdGERAN',
                                                                                                                                            'type': 'ThresholdGERAN'},
                                                                                                                                           {'name': 'b1-ThresholdCDMA2000',
                                                                                                                                            'type': 'ThresholdCDMA2000'}],
                                                                                                                               'name': 'b1-Threshold',
                                                                                                                               'type': 'CHOICE'}],
                                                                                                                  'name': 'eventB1',
                                                                                                                  'type': 'SEQUENCE'},
                                                                                                                 {'members': [{'name': 'b2-Threshold1',
                                                                                                                               'type': 'ThresholdEUTRA'},
                                                                                                                              {'members': [{'name': 'b2-Threshold2UTRA',
                                                                                                                                            'type': 'ThresholdUTRA'},
                                                                                                                                           {'name': 'b2-Threshold2GERAN',
                                                                                                                                            'type': 'ThresholdGERAN'},
                                                                                                                                           {'name': 'b2-Threshold2CDMA2000',
                                                                                                                                            'type': 'ThresholdCDMA2000'}],
                                                                                                                               'name': 'b2-Threshold2',
                                                                                                                               'type': 'CHOICE'}],
                                                                                                                  'name': 'eventB2',
                                                                                                                  'type': 'SEQUENCE'},
                                                                                                                 None],
                                                                                                     'name': 'eventId',
                                                                                                     'type': 'CHOICE'},
                                                                                                    {'name': 'hysteresis',
                                                                                                     'type': 'Hysteresis'},
                                                                                                    {'name': 'timeToTrigger',
                                                                                                     'type': 'TimeToTrigger'}],
                                                                                        'name': 'event',
                                                                                        'type': 'SEQUENCE'},
                                                                                       {'members': [{'name': 'purpose',
                                                                                                     'type': 'ENUMERATED',
                                                                                                     'values': [('reportStrongestCells',
                                                                                                                 0),
                                                                                                                ('reportStrongestCellsForSON',
                                                                                                                 1),
                                                                                                                ('reportCGI',
                                                                                                                 2)]}],
                                                                                        'name': 'periodical',
                                                                                        'type': 'SEQUENCE'}],
                                                                           'name': 'triggerType',
                                                                           'type': 'CHOICE'},
                                                                          {'name': 'maxReportCells',
                                                                           'restricted-to': [(1,
                                                                                              'maxCellReport')],
                                                                           'type': 'INTEGER'},
                                                                          {'name': 'reportInterval',
                                                                           'type': 'ReportInterval'},
                                                                          {'name': 'reportAmount',
                                                                           'type': 'ENUMERATED',
                                                                           'values': [('r1',
                                                                                       0),
                                                                                      ('r2',
                                                                                       1),
                                                                                      ('r4',
                                                                                       2),
                                                                                      ('r8',
                                                                                       3),
                                                                                      ('r16',
                                                                                       4),
                                                                                      ('r32',
                                                                                       5),
                                                                                      ('r64',
                                                                                       6),
                                                                                      ('infinity',
                                                                                       7)]},
                                                                          None],
                                                              'type': 'SEQUENCE'},
                                     'ReportConfigToAddMod': {'members': [{'name': 'reportConfigId',
                                                                           'type': 'ReportConfigId'},
                                                                          {'members': [{'name': 'reportConfigEUTRA',
                                                                                        'type': 'ReportConfigEUTRA'},
                                                                                       {'name': 'reportConfigInterRAT',
                                                                                        'type': 'ReportConfigInterRAT'}],
                                                                           'name': 'reportConfig',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                     'ReportConfigToAddModList': {'element': {'type': 'ReportConfigToAddMod'},
                                                                  'size': [(1,
                                                                            'maxReportConfigId')],
                                                                  'type': 'SEQUENCE '
                                                                          'OF'},
                                     'ReportConfigToRemoveList': {'element': {'type': 'ReportConfigId'},
                                                                  'size': [(1,
                                                                            'maxReportConfigId')],
                                                                  'type': 'SEQUENCE '
                                                                          'OF'},
                                     'ReportInterval': {'type': 'ENUMERATED',
                                                        'values': [('ms120', 0),
                                                                   ('ms240', 1),
                                                                   ('ms480', 2),
                                                                   ('ms640', 3),
                                                                   ('ms1024',
                                                                    4),
                                                                   ('ms2048',
                                                                    5),
                                                                   ('ms5120',
                                                                    6),
                                                                   ('ms10240',
                                                                    7),
                                                                   ('min1', 8),
                                                                   ('min6', 9),
                                                                   ('min12',
                                                                    10),
                                                                   ('min30',
                                                                    11),
                                                                   ('min60',
                                                                    12),
                                                                   ('spare3',
                                                                    13),
                                                                   ('spare2',
                                                                    14),
                                                                   ('spare1',
                                                                    15)]},
                                     'ReselectionThreshold': {'restricted-to': [(0,
                                                                                 31)],
                                                              'type': 'INTEGER'},
                                     'S-TMSI': {'members': [{'name': 'mmec',
                                                             'type': 'MMEC'},
                                                            {'name': 'm-TMSI',
                                                             'size': [32],
                                                             'type': 'BIT '
                                                                     'STRING'}],
                                                'type': 'SEQUENCE'},
                                     'SI-OrPSI-GERAN': {'members': [{'name': 'si',
                                                                     'type': 'SystemInfoListGERAN'},
                                                                    {'name': 'psi',
                                                                     'type': 'SystemInfoListGERAN'}],
                                                        'type': 'CHOICE'},
                                     'SIB-MappingInfo': {'element': {'type': 'SIB-Type'},
                                                         'size': [(0,
                                                                   'maxSIB-1')],
                                                         'type': 'SEQUENCE OF'},
                                     'SIB-Type': {'type': 'ENUMERATED',
                                                  'values': [('sibType3', 0),
                                                             ('sibType4', 1),
                                                             ('sibType5', 2),
                                                             ('sibType6', 3),
                                                             ('sibType7', 4),
                                                             ('sibType8', 5),
                                                             ('sibType9', 6),
                                                             ('sibType10', 7),
                                                             ('sibType11', 8),
                                                             ('spare7', 9),
                                                             ('spare6', 10),
                                                             ('spare5', 11),
                                                             ('spare4', 12),
                                                             ('spare3', 13),
                                                             ('spare2', 14),
                                                             ('spare1', 15),
                                                             None]},
                                     'SN-FieldLength': {'type': 'ENUMERATED',
                                                        'values': [('size5', 0),
                                                                   ('size10',
                                                                    1)]},
                                     'SPS-Config': {'members': [{'name': 'semiPersistSchedC-RNTI',
                                                                 'optional': True,
                                                                 'type': 'C-RNTI'},
                                                                {'name': 'sps-ConfigDL',
                                                                 'optional': True,
                                                                 'type': 'SPS-ConfigDL'},
                                                                {'name': 'sps-ConfigUL',
                                                                 'optional': True,
                                                                 'type': 'SPS-ConfigUL'}],
                                                    'type': 'SEQUENCE'},
                                     'SPS-ConfigDL': {'members': [{'name': 'release',
                                                                   'type': 'NULL'},
                                                                  {'members': [{'name': 'semiPersistSchedIntervalDL',
                                                                                'type': 'ENUMERATED',
                                                                                'values': [('sf10',
                                                                                            0),
                                                                                           ('sf20',
                                                                                            1),
                                                                                           ('sf32',
                                                                                            2),
                                                                                           ('sf40',
                                                                                            3),
                                                                                           ('sf64',
                                                                                            4),
                                                                                           ('sf80',
                                                                                            5),
                                                                                           ('sf128',
                                                                                            6),
                                                                                           ('sf160',
                                                                                            7),
                                                                                           ('sf320',
                                                                                            8),
                                                                                           ('sf640',
                                                                                            9),
                                                                                           ('spare6',
                                                                                            10),
                                                                                           ('spare5',
                                                                                            11),
                                                                                           ('spare4',
                                                                                            12),
                                                                                           ('spare3',
                                                                                            13),
                                                                                           ('spare2',
                                                                                            14),
                                                                                           ('spare1',
                                                                                            15)]},
                                                                               {'name': 'numberOfConfSPS-Processes',
                                                                                'restricted-to': [(1,
                                                                                                   8)],
                                                                                'type': 'INTEGER'},
                                                                               {'name': 'n1-PUCCH-AN-PersistentList',
                                                                                'type': 'N1-PUCCH-AN-PersistentList'},
                                                                               None],
                                                                   'name': 'setup',
                                                                   'type': 'SEQUENCE'}],
                                                      'type': 'CHOICE'},
                                     'SPS-ConfigUL': {'members': [{'name': 'release',
                                                                   'type': 'NULL'},
                                                                  {'members': [{'name': 'semiPersistSchedIntervalUL',
                                                                                'type': 'ENUMERATED',
                                                                                'values': [('sf10',
                                                                                            0),
                                                                                           ('sf20',
                                                                                            1),
                                                                                           ('sf32',
                                                                                            2),
                                                                                           ('sf40',
                                                                                            3),
                                                                                           ('sf64',
                                                                                            4),
                                                                                           ('sf80',
                                                                                            5),
                                                                                           ('sf128',
                                                                                            6),
                                                                                           ('sf160',
                                                                                            7),
                                                                                           ('sf320',
                                                                                            8),
                                                                                           ('sf640',
                                                                                            9),
                                                                                           ('spare6',
                                                                                            10),
                                                                                           ('spare5',
                                                                                            11),
                                                                                           ('spare4',
                                                                                            12),
                                                                                           ('spare3',
                                                                                            13),
                                                                                           ('spare2',
                                                                                            14),
                                                                                           ('spare1',
                                                                                            15)]},
                                                                               {'name': 'implicitReleaseAfter',
                                                                                'type': 'ENUMERATED',
                                                                                'values': [('e2',
                                                                                            0),
                                                                                           ('e3',
                                                                                            1),
                                                                                           ('e4',
                                                                                            2),
                                                                                           ('e8',
                                                                                            3)]},
                                                                               {'members': [{'name': 'p0-NominalPUSCH-Persistent',
                                                                                             'restricted-to': [(-126,
                                                                                                                24)],
                                                                                             'type': 'INTEGER'},
                                                                                            {'name': 'p0-UE-PUSCH-Persistent',
                                                                                             'restricted-to': [(-8,
                                                                                                                7)],
                                                                                             'type': 'INTEGER'}],
                                                                                'name': 'p0-Persistent',
                                                                                'optional': True,
                                                                                'type': 'SEQUENCE'},
                                                                               {'name': 'twoIntervalsConfig',
                                                                                'optional': True,
                                                                                'type': 'ENUMERATED',
                                                                                'values': [('true',
                                                                                            0)]},
                                                                               None],
                                                                   'name': 'setup',
                                                                   'type': 'SEQUENCE'}],
                                                      'type': 'CHOICE'},
                                     'SRB-ToAddMod': {'members': [{'name': 'srb-Identity',
                                                                   'restricted-to': [(1,
                                                                                      2)],
                                                                   'type': 'INTEGER'},
                                                                  {'members': [{'name': 'explicitValue',
                                                                                'type': 'RLC-Config'},
                                                                               {'name': 'defaultValue',
                                                                                'type': 'NULL'}],
                                                                   'name': 'rlc-Config',
                                                                   'optional': True,
                                                                   'type': 'CHOICE'},
                                                                  {'members': [{'name': 'explicitValue',
                                                                                'type': 'LogicalChannelConfig'},
                                                                               {'name': 'defaultValue',
                                                                                'type': 'NULL'}],
                                                                   'name': 'logicalChannelConfig',
                                                                   'optional': True,
                                                                   'type': 'CHOICE'},
                                                                  None],
                                                      'type': 'SEQUENCE'},
                                     'SRB-ToAddModList': {'element': {'type': 'SRB-ToAddMod'},
                                                          'size': [(1, 2)],
                                                          'type': 'SEQUENCE '
                                                                  'OF'},
                                     'SchedulingInfo': {'members': [{'name': 'si-Periodicity',
                                                                     'type': 'ENUMERATED',
                                                                     'values': [('rf8',
                                                                                 0),
                                                                                ('rf16',
                                                                                 1),
                                                                                ('rf32',
                                                                                 2),
                                                                                ('rf64',
                                                                                 3),
                                                                                ('rf128',
                                                                                 4),
                                                                                ('rf256',
                                                                                 5),
                                                                                ('rf512',
                                                                                 6)]},
                                                                    {'name': 'sib-MappingInfo',
                                                                     'type': 'SIB-MappingInfo'}],
                                                        'type': 'SEQUENCE'},
                                     'SchedulingInfoList': {'element': {'type': 'SchedulingInfo'},
                                                            'size': [(1,
                                                                      'maxSI-Message')],
                                                            'type': 'SEQUENCE '
                                                                    'OF'},
                                     'SchedulingRequestConfig': {'members': [{'name': 'release',
                                                                              'type': 'NULL'},
                                                                             {'members': [{'name': 'sr-PUCCH-ResourceIndex',
                                                                                           'restricted-to': [(0,
                                                                                                              2047)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sr-ConfigIndex',
                                                                                           'restricted-to': [(0,
                                                                                                              155)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'dsr-TransMax',
                                                                                           'type': 'ENUMERATED',
                                                                                           'values': [('n4',
                                                                                                       0),
                                                                                                      ('n8',
                                                                                                       1),
                                                                                                      ('n16',
                                                                                                       2),
                                                                                                      ('n32',
                                                                                                       3),
                                                                                                      ('n64',
                                                                                                       4),
                                                                                                      ('spare3',
                                                                                                       5),
                                                                                                      ('spare2',
                                                                                                       6),
                                                                                                      ('spare1',
                                                                                                       7)]}],
                                                                              'name': 'setup',
                                                                              'type': 'SEQUENCE'}],
                                                                 'type': 'CHOICE'},
                                     'SecondaryPreRegistrationZoneIdListHRPD': {'element': {'type': 'PreRegistrationZoneIdHRPD'},
                                                                                'size': [(1,
                                                                                          2)],
                                                                                'type': 'SEQUENCE '
                                                                                        'OF'},
                                     'SecurityAlgorithmConfig': {'members': [{'name': 'cipheringAlgorithm',
                                                                              'type': 'ENUMERATED',
                                                                              'values': [('eea0',
                                                                                          0),
                                                                                         ('eea1',
                                                                                          1),
                                                                                         ('eea2',
                                                                                          2),
                                                                                         ('spare5',
                                                                                          3),
                                                                                         ('spare4',
                                                                                          4),
                                                                                         ('spare3',
                                                                                          5),
                                                                                         ('spare2',
                                                                                          6),
                                                                                         ('spare1',
                                                                                          7),
                                                                                         None]},
                                                                             {'name': 'integrityProtAlgorithm',
                                                                              'type': 'ENUMERATED',
                                                                              'values': [('reserved',
                                                                                          0),
                                                                                         ('eia1',
                                                                                          1),
                                                                                         ('eia2',
                                                                                          2),
                                                                                         ('spare5',
                                                                                          3),
                                                                                         ('spare4',
                                                                                          4),
                                                                                         ('spare3',
                                                                                          5),
                                                                                         ('spare2',
                                                                                          6),
                                                                                         ('spare1',
                                                                                          7),
                                                                                         None]}],
                                                                 'type': 'SEQUENCE'},
                                     'SecurityConfigHO': {'members': [{'members': [{'members': [{'name': 'securityAlgorithmConfig',
                                                                                                 'optional': True,
                                                                                                 'type': 'SecurityAlgorithmConfig'},
                                                                                                {'name': 'keyChangeIndicator',
                                                                                                 'type': 'BOOLEAN'},
                                                                                                {'name': 'nextHopChainingCount',
                                                                                                 'type': 'NextHopChainingCount'}],
                                                                                    'name': 'intraLTE',
                                                                                    'type': 'SEQUENCE'},
                                                                                   {'members': [{'name': 'securityAlgorithmConfig',
                                                                                                 'type': 'SecurityAlgorithmConfig'},
                                                                                                {'name': 'nas-SecurityParamToEUTRA',
                                                                                                 'size': [6],
                                                                                                 'type': 'OCTET '
                                                                                                         'STRING'}],
                                                                                    'name': 'interRAT',
                                                                                    'type': 'SEQUENCE'}],
                                                                       'name': 'handoverType',
                                                                       'type': 'CHOICE'},
                                                                      None],
                                                          'type': 'SEQUENCE'},
                                     'SecurityConfigSMC': {'members': [{'name': 'securityAlgorithmConfig',
                                                                        'type': 'SecurityAlgorithmConfig'},
                                                                       None],
                                                           'type': 'SEQUENCE'},
                                     'SecurityModeCommand': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                          'type': 'RRC-TransactionIdentifier'},
                                                                         {'members': [{'members': [{'name': 'securityModeCommand-r8',
                                                                                                    'type': 'SecurityModeCommand-r8-IEs'},
                                                                                                   {'name': 'spare3',
                                                                                                    'type': 'NULL'},
                                                                                                   {'name': 'spare2',
                                                                                                    'type': 'NULL'},
                                                                                                   {'name': 'spare1',
                                                                                                    'type': 'NULL'}],
                                                                                       'name': 'c1',
                                                                                       'type': 'CHOICE'},
                                                                                      {'members': [],
                                                                                       'name': 'criticalExtensionsFuture',
                                                                                       'type': 'SEQUENCE'}],
                                                                          'name': 'criticalExtensions',
                                                                          'type': 'CHOICE'}],
                                                             'type': 'SEQUENCE'},
                                     'SecurityModeCommand-r8-IEs': {'members': [{'name': 'securityConfigSMC',
                                                                                 'type': 'SecurityConfigSMC'},
                                                                                {'members': [],
                                                                                 'name': 'nonCriticalExtension',
                                                                                 'optional': True,
                                                                                 'type': 'SEQUENCE'}],
                                                                    'type': 'SEQUENCE'},
                                     'SecurityModeComplete': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                           'type': 'RRC-TransactionIdentifier'},
                                                                          {'members': [{'name': 'securityModeComplete-r8',
                                                                                        'type': 'SecurityModeComplete-r8-IEs'},
                                                                                       {'members': [],
                                                                                        'name': 'criticalExtensionsFuture',
                                                                                        'type': 'SEQUENCE'}],
                                                                           'name': 'criticalExtensions',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                     'SecurityModeComplete-r8-IEs': {'members': [{'members': [],
                                                                                  'name': 'nonCriticalExtension',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'}],
                                                                     'type': 'SEQUENCE'},
                                     'SecurityModeFailure': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                          'type': 'RRC-TransactionIdentifier'},
                                                                         {'members': [{'name': 'securityModeFailure-r8',
                                                                                       'type': 'SecurityModeFailure-r8-IEs'},
                                                                                      {'members': [],
                                                                                       'name': 'criticalExtensionsFuture',
                                                                                       'type': 'SEQUENCE'}],
                                                                          'name': 'criticalExtensions',
                                                                          'type': 'CHOICE'}],
                                                             'type': 'SEQUENCE'},
                                     'SecurityModeFailure-r8-IEs': {'members': [{'members': [],
                                                                                 'name': 'nonCriticalExtension',
                                                                                 'optional': True,
                                                                                 'type': 'SEQUENCE'}],
                                                                    'type': 'SEQUENCE'},
                                     'ShortMAC-I': {'size': [16],
                                                    'type': 'BIT STRING'},
                                     'SoundingRS-UL-ConfigCommon': {'members': [{'name': 'release',
                                                                                 'type': 'NULL'},
                                                                                {'members': [{'name': 'srs-BandwidthConfig',
                                                                                              'type': 'ENUMERATED',
                                                                                              'values': [('bw0',
                                                                                                          0),
                                                                                                         ('bw1',
                                                                                                          1),
                                                                                                         ('bw2',
                                                                                                          2),
                                                                                                         ('bw3',
                                                                                                          3),
                                                                                                         ('bw4',
                                                                                                          4),
                                                                                                         ('bw5',
                                                                                                          5),
                                                                                                         ('bw6',
                                                                                                          6),
                                                                                                         ('bw7',
                                                                                                          7)]},
                                                                                             {'name': 'srs-SubframeConfig',
                                                                                              'type': 'ENUMERATED',
                                                                                              'values': [('sc0',
                                                                                                          0),
                                                                                                         ('sc1',
                                                                                                          1),
                                                                                                         ('sc2',
                                                                                                          2),
                                                                                                         ('sc3',
                                                                                                          3),
                                                                                                         ('sc4',
                                                                                                          4),
                                                                                                         ('sc5',
                                                                                                          5),
                                                                                                         ('sc6',
                                                                                                          6),
                                                                                                         ('sc7',
                                                                                                          7),
                                                                                                         ('sc8',
                                                                                                          8),
                                                                                                         ('sc9',
                                                                                                          9),
                                                                                                         ('sc10',
                                                                                                          10),
                                                                                                         ('sc11',
                                                                                                          11),
                                                                                                         ('sc12',
                                                                                                          12),
                                                                                                         ('sc13',
                                                                                                          13),
                                                                                                         ('sc14',
                                                                                                          14),
                                                                                                         ('sc15',
                                                                                                          15)]},
                                                                                             {'name': 'ackNackSRS-SimultaneousTransmission',
                                                                                              'type': 'BOOLEAN'},
                                                                                             {'name': 'srs-MaxUpPts',
                                                                                              'optional': True,
                                                                                              'type': 'ENUMERATED',
                                                                                              'values': [('true',
                                                                                                          0)]}],
                                                                                 'name': 'setup',
                                                                                 'type': 'SEQUENCE'}],
                                                                    'type': 'CHOICE'},
                                     'SoundingRS-UL-ConfigDedicated': {'members': [{'name': 'release',
                                                                                    'type': 'NULL'},
                                                                                   {'members': [{'name': 'srs-Bandwidth',
                                                                                                 'type': 'ENUMERATED',
                                                                                                 'values': [('bw0',
                                                                                                             0),
                                                                                                            ('bw1',
                                                                                                             1),
                                                                                                            ('bw2',
                                                                                                             2),
                                                                                                            ('bw3',
                                                                                                             3)]},
                                                                                                {'name': 'srs-HoppingBandwidth',
                                                                                                 'type': 'ENUMERATED',
                                                                                                 'values': [('hbw0',
                                                                                                             0),
                                                                                                            ('hbw1',
                                                                                                             1),
                                                                                                            ('hbw2',
                                                                                                             2),
                                                                                                            ('hbw3',
                                                                                                             3)]},
                                                                                                {'name': 'freqDomainPosition',
                                                                                                 'restricted-to': [(0,
                                                                                                                    23)],
                                                                                                 'type': 'INTEGER'},
                                                                                                {'name': 'duration',
                                                                                                 'type': 'BOOLEAN'},
                                                                                                {'name': 'srs-ConfigIndex',
                                                                                                 'restricted-to': [(0,
                                                                                                                    1023)],
                                                                                                 'type': 'INTEGER'},
                                                                                                {'name': 'transmissionComb',
                                                                                                 'restricted-to': [(0,
                                                                                                                    1)],
                                                                                                 'type': 'INTEGER'},
                                                                                                {'name': 'cyclicShift',
                                                                                                 'type': 'ENUMERATED',
                                                                                                 'values': [('cs0',
                                                                                                             0),
                                                                                                            ('cs1',
                                                                                                             1),
                                                                                                            ('cs2',
                                                                                                             2),
                                                                                                            ('cs3',
                                                                                                             3),
                                                                                                            ('cs4',
                                                                                                             4),
                                                                                                            ('cs5',
                                                                                                             5),
                                                                                                            ('cs6',
                                                                                                             6),
                                                                                                            ('cs7',
                                                                                                             7)]}],
                                                                                    'name': 'setup',
                                                                                    'type': 'SEQUENCE'}],
                                                                       'type': 'CHOICE'},
                                     'SpeedStateScaleFactors': {'members': [{'name': 'sf-Medium',
                                                                             'type': 'ENUMERATED',
                                                                             'values': [('oDot25',
                                                                                         0),
                                                                                        ('oDot5',
                                                                                         1),
                                                                                        ('oDot75',
                                                                                         2),
                                                                                        ('lDot0',
                                                                                         3)]},
                                                                            {'name': 'sf-High',
                                                                             'type': 'ENUMERATED',
                                                                             'values': [('oDot25',
                                                                                         0),
                                                                                        ('oDot5',
                                                                                         1),
                                                                                        ('oDot75',
                                                                                         2),
                                                                                        ('lDot0',
                                                                                         3)]}],
                                                                'type': 'SEQUENCE'},
                                     'SupportedBandEUTRA': {'members': [{'name': 'bandEUTRA',
                                                                         'restricted-to': [(1,
                                                                                            64)],
                                                                         'type': 'INTEGER'},
                                                                        {'name': 'halfDuplex',
                                                                         'type': 'BOOLEAN'}],
                                                            'type': 'SEQUENCE'},
                                     'SupportedBandGERAN': {'type': 'ENUMERATED',
                                                            'values': [('gsm450',
                                                                        0),
                                                                       ('gsm480',
                                                                        1),
                                                                       ('gsm710',
                                                                        2),
                                                                       ('gsm750',
                                                                        3),
                                                                       ('gsm810',
                                                                        4),
                                                                       ('gsm850',
                                                                        5),
                                                                       ('gsm900P',
                                                                        6),
                                                                       ('gsm900E',
                                                                        7),
                                                                       ('gsm900R',
                                                                        8),
                                                                       ('gsm1800',
                                                                        9),
                                                                       ('gsm1900',
                                                                        10),
                                                                       ('spare5',
                                                                        11),
                                                                       ('spare4',
                                                                        12),
                                                                       ('spare3',
                                                                        13),
                                                                       ('spare2',
                                                                        14),
                                                                       ('spare1',
                                                                        15),
                                                                       None]},
                                     'SupportedBandList1XRTT': {'element': {'type': 'BandclassCDMA2000'},
                                                                'size': [(1,
                                                                          'maxCDMA-BandClass')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'SupportedBandListEUTRA': {'element': {'type': 'SupportedBandEUTRA'},
                                                                'size': [(1,
                                                                          'maxBands')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'SupportedBandListGERAN': {'element': {'type': 'SupportedBandGERAN'},
                                                                'size': [(1,
                                                                          'maxBands')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'SupportedBandListHRPD': {'element': {'type': 'BandclassCDMA2000'},
                                                               'size': [(1,
                                                                         'maxCDMA-BandClass')],
                                                               'type': 'SEQUENCE '
                                                                       'OF'},
                                     'SupportedBandListUTRA-FDD': {'element': {'type': 'SupportedBandUTRA-FDD'},
                                                                   'size': [(1,
                                                                             'maxBands')],
                                                                   'type': 'SEQUENCE '
                                                                           'OF'},
                                     'SupportedBandListUTRA-TDD128': {'element': {'type': 'SupportedBandUTRA-TDD128'},
                                                                      'size': [(1,
                                                                                'maxBands')],
                                                                      'type': 'SEQUENCE '
                                                                              'OF'},
                                     'SupportedBandListUTRA-TDD384': {'element': {'type': 'SupportedBandUTRA-TDD384'},
                                                                      'size': [(1,
                                                                                'maxBands')],
                                                                      'type': 'SEQUENCE '
                                                                              'OF'},
                                     'SupportedBandListUTRA-TDD768': {'element': {'type': 'SupportedBandUTRA-TDD768'},
                                                                      'size': [(1,
                                                                                'maxBands')],
                                                                      'type': 'SEQUENCE '
                                                                              'OF'},
                                     'SupportedBandUTRA-FDD': {'type': 'ENUMERATED',
                                                               'values': [('bandI',
                                                                           0),
                                                                          ('bandII',
                                                                           1),
                                                                          ('bandIII',
                                                                           2),
                                                                          ('bandIV',
                                                                           3),
                                                                          ('bandV',
                                                                           4),
                                                                          ('bandVI',
                                                                           5),
                                                                          ('bandVII',
                                                                           6),
                                                                          ('bandVIII',
                                                                           7),
                                                                          ('bandIX',
                                                                           8),
                                                                          ('bandX',
                                                                           9),
                                                                          ('bandXI',
                                                                           10),
                                                                          ('bandXII',
                                                                           11),
                                                                          ('bandXIII',
                                                                           12),
                                                                          ('bandXIV',
                                                                           13),
                                                                          ('bandXV',
                                                                           14),
                                                                          ('bandXVI',
                                                                           15),
                                                                          None,
                                                                          ('bandXVII-8a0',
                                                                           16),
                                                                          ('bandXVIII-8a0',
                                                                           17),
                                                                          ('bandXIX-8a0',
                                                                           18),
                                                                          ('bandXX-8a0',
                                                                           19),
                                                                          ('bandXXI-8a0',
                                                                           20),
                                                                          ('bandXXII-8a0',
                                                                           21),
                                                                          ('bandXXIII-8a0',
                                                                           22),
                                                                          ('bandXXIV-8a0',
                                                                           23),
                                                                          ('bandXXV-8a0',
                                                                           24),
                                                                          ('bandXXVI-8a0',
                                                                           25),
                                                                          ('bandXXVII-8a0',
                                                                           26),
                                                                          ('bandXXVIII-8a0',
                                                                           27),
                                                                          ('bandXXIX-8a0',
                                                                           28),
                                                                          ('bandXXX-8a0',
                                                                           29),
                                                                          ('bandXXXI-8a0',
                                                                           30),
                                                                          ('bandXXXII-8a0',
                                                                           31)]},
                                     'SupportedBandUTRA-TDD128': {'type': 'ENUMERATED',
                                                                  'values': [('a',
                                                                              0),
                                                                             ('b',
                                                                              1),
                                                                             ('c',
                                                                              2),
                                                                             ('d',
                                                                              3),
                                                                             ('e',
                                                                              4),
                                                                             ('f',
                                                                              5),
                                                                             ('g',
                                                                              6),
                                                                             ('h',
                                                                              7),
                                                                             ('i',
                                                                              8),
                                                                             ('j',
                                                                              9),
                                                                             ('k',
                                                                              10),
                                                                             ('l',
                                                                              11),
                                                                             ('m',
                                                                              12),
                                                                             ('n',
                                                                              13),
                                                                             ('o',
                                                                              14),
                                                                             ('p',
                                                                              15),
                                                                             None]},
                                     'SupportedBandUTRA-TDD384': {'type': 'ENUMERATED',
                                                                  'values': [('a',
                                                                              0),
                                                                             ('b',
                                                                              1),
                                                                             ('c',
                                                                              2),
                                                                             ('d',
                                                                              3),
                                                                             ('e',
                                                                              4),
                                                                             ('f',
                                                                              5),
                                                                             ('g',
                                                                              6),
                                                                             ('h',
                                                                              7),
                                                                             ('i',
                                                                              8),
                                                                             ('j',
                                                                              9),
                                                                             ('k',
                                                                              10),
                                                                             ('l',
                                                                              11),
                                                                             ('m',
                                                                              12),
                                                                             ('n',
                                                                              13),
                                                                             ('o',
                                                                              14),
                                                                             ('p',
                                                                              15),
                                                                             None]},
                                     'SupportedBandUTRA-TDD768': {'type': 'ENUMERATED',
                                                                  'values': [('a',
                                                                              0),
                                                                             ('b',
                                                                              1),
                                                                             ('c',
                                                                              2),
                                                                             ('d',
                                                                              3),
                                                                             ('e',
                                                                              4),
                                                                             ('f',
                                                                              5),
                                                                             ('g',
                                                                              6),
                                                                             ('h',
                                                                              7),
                                                                             ('i',
                                                                              8),
                                                                             ('j',
                                                                              9),
                                                                             ('k',
                                                                              10),
                                                                             ('l',
                                                                              11),
                                                                             ('m',
                                                                              12),
                                                                             ('n',
                                                                              13),
                                                                             ('o',
                                                                              14),
                                                                             ('p',
                                                                              15),
                                                                             None]},
                                     'SystemInfoListGERAN': {'element': {'size': [(1,
                                                                                   23)],
                                                                         'type': 'OCTET '
                                                                                 'STRING'},
                                                             'size': [(1,
                                                                       'maxGERAN-SI')],
                                                             'type': 'SEQUENCE '
                                                                     'OF'},
                                     'SystemInformation': {'members': [{'members': [{'name': 'systemInformation-r8',
                                                                                     'type': 'SystemInformation-r8-IEs'},
                                                                                    {'members': [],
                                                                                     'name': 'criticalExtensionsFuture',
                                                                                     'type': 'SEQUENCE'}],
                                                                        'name': 'criticalExtensions',
                                                                        'type': 'CHOICE'}],
                                                           'type': 'SEQUENCE'},
                                     'SystemInformation-r8-IEs': {'members': [{'element': {'members': [{'name': 'sib2',
                                                                                                        'type': 'SystemInformationBlockType2'},
                                                                                                       {'name': 'sib3',
                                                                                                        'type': 'SystemInformationBlockType3'},
                                                                                                       {'name': 'sib4',
                                                                                                        'type': 'SystemInformationBlockType4'},
                                                                                                       {'name': 'sib5',
                                                                                                        'type': 'SystemInformationBlockType5'},
                                                                                                       {'name': 'sib6',
                                                                                                        'type': 'SystemInformationBlockType6'},
                                                                                                       {'name': 'sib7',
                                                                                                        'type': 'SystemInformationBlockType7'},
                                                                                                       {'name': 'sib8',
                                                                                                        'type': 'SystemInformationBlockType8'},
                                                                                                       {'name': 'sib9',
                                                                                                        'type': 'SystemInformationBlockType9'},
                                                                                                       {'name': 'sib10',
                                                                                                        'type': 'SystemInformationBlockType10'},
                                                                                                       {'name': 'sib11',
                                                                                                        'type': 'SystemInformationBlockType11'},
                                                                                                       None],
                                                                                           'type': 'CHOICE'},
                                                                               'name': 'sib-TypeAndInfo',
                                                                               'size': [(1,
                                                                                         'maxSIB')],
                                                                               'type': 'SEQUENCE '
                                                                                       'OF'},
                                                                              {'members': [],
                                                                               'name': 'nonCriticalExtension',
                                                                               'optional': True,
                                                                               'type': 'SEQUENCE'}],
                                                                  'type': 'SEQUENCE'},
                                     'SystemInformationBlockType1': {'members': [{'members': [{'name': 'plmn-IdentityList',
                                                                                               'type': 'PLMN-IdentityList'},
                                                                                              {'name': 'trackingAreaCode',
                                                                                               'type': 'TrackingAreaCode'},
                                                                                              {'name': 'cellIdentity',
                                                                                               'type': 'CellIdentity'},
                                                                                              {'name': 'cellBarred',
                                                                                               'type': 'ENUMERATED',
                                                                                               'values': [('barred',
                                                                                                           0),
                                                                                                          ('notBarred',
                                                                                                           1)]},
                                                                                              {'name': 'intraFreqReselection',
                                                                                               'type': 'ENUMERATED',
                                                                                               'values': [('allowed',
                                                                                                           0),
                                                                                                          ('notAllowed',
                                                                                                           1)]},
                                                                                              {'name': 'csg-Indication',
                                                                                               'type': 'BOOLEAN'},
                                                                                              {'name': 'csg-Identity',
                                                                                               'optional': True,
                                                                                               'size': [27],
                                                                                               'type': 'BIT '
                                                                                                       'STRING'}],
                                                                                  'name': 'cellAccessRelatedInfo',
                                                                                  'type': 'SEQUENCE'},
                                                                                 {'members': [{'name': 'q-RxLevMin',
                                                                                               'type': 'Q-RxLevMin'},
                                                                                              {'name': 'q-RxLevMinOffset',
                                                                                               'optional': True,
                                                                                               'restricted-to': [(1,
                                                                                                                  8)],
                                                                                               'type': 'INTEGER'}],
                                                                                  'name': 'cellSelectionInfo',
                                                                                  'type': 'SEQUENCE'},
                                                                                 {'name': 'p-Max',
                                                                                  'optional': True,
                                                                                  'type': 'P-Max'},
                                                                                 {'name': 'freqBandIndicator',
                                                                                  'restricted-to': [(1,
                                                                                                     64)],
                                                                                  'type': 'INTEGER'},
                                                                                 {'name': 'schedulingInfoList',
                                                                                  'type': 'SchedulingInfoList'},
                                                                                 {'name': 'tdd-Config',
                                                                                  'optional': True,
                                                                                  'type': 'TDD-Config'},
                                                                                 {'name': 'si-WindowLength',
                                                                                  'type': 'ENUMERATED',
                                                                                  'values': [('ms1',
                                                                                              0),
                                                                                             ('ms2',
                                                                                              1),
                                                                                             ('ms5',
                                                                                              2),
                                                                                             ('ms10',
                                                                                              3),
                                                                                             ('ms15',
                                                                                              4),
                                                                                             ('ms20',
                                                                                              5),
                                                                                             ('ms40',
                                                                                              6)]},
                                                                                 {'name': 'systemInfoValueTag',
                                                                                  'restricted-to': [(0,
                                                                                                     31)],
                                                                                  'type': 'INTEGER'},
                                                                                 {'members': [],
                                                                                  'name': 'nonCriticalExtension',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'}],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType10': {'members': [{'name': 'messageIdentifier',
                                                                                   'size': [16],
                                                                                   'type': 'BIT '
                                                                                           'STRING'},
                                                                                  {'name': 'serialNumber',
                                                                                   'size': [16],
                                                                                   'type': 'BIT '
                                                                                           'STRING'},
                                                                                  {'name': 'warningType',
                                                                                   'size': [2],
                                                                                   'type': 'OCTET '
                                                                                           'STRING'},
                                                                                  {'name': 'warningSecurityInfo',
                                                                                   'optional': True,
                                                                                   'size': [50],
                                                                                   'type': 'OCTET '
                                                                                           'STRING'},
                                                                                  None],
                                                                      'type': 'SEQUENCE'},
                                     'SystemInformationBlockType11': {'members': [{'name': 'messageIdentifier',
                                                                                   'size': [16],
                                                                                   'type': 'BIT '
                                                                                           'STRING'},
                                                                                  {'name': 'serialNumber',
                                                                                   'size': [16],
                                                                                   'type': 'BIT '
                                                                                           'STRING'},
                                                                                  {'name': 'warningMessageSegmentType',
                                                                                   'type': 'ENUMERATED',
                                                                                   'values': [('notLastSegment',
                                                                                               0),
                                                                                              ('lastSegment',
                                                                                               1)]},
                                                                                  {'name': 'warningMessageSegmentNumber',
                                                                                   'restricted-to': [(0,
                                                                                                      63)],
                                                                                   'type': 'INTEGER'},
                                                                                  {'name': 'warningMessageSegment',
                                                                                   'type': 'OCTET '
                                                                                           'STRING'},
                                                                                  {'name': 'dataCodingScheme',
                                                                                   'optional': True,
                                                                                   'size': [1],
                                                                                   'type': 'OCTET '
                                                                                           'STRING'},
                                                                                  None],
                                                                      'type': 'SEQUENCE'},
                                     'SystemInformationBlockType2': {'members': [{'members': [{'name': 'ac-BarringForEmergency',
                                                                                               'type': 'BOOLEAN'},
                                                                                              {'name': 'ac-BarringForMO-Signalling',
                                                                                               'optional': True,
                                                                                               'type': 'AC-BarringConfig'},
                                                                                              {'name': 'ac-BarringForMO-Data',
                                                                                               'optional': True,
                                                                                               'type': 'AC-BarringConfig'}],
                                                                                  'name': 'ac-BarringInfo',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'},
                                                                                 {'name': 'radioResourceConfigCommon',
                                                                                  'type': 'RadioResourceConfigCommonSIB'},
                                                                                 {'name': 'ue-TimersAndConstants',
                                                                                  'type': 'UE-TimersAndConstants'},
                                                                                 {'members': [{'name': 'ul-CarrierFreq',
                                                                                               'optional': True,
                                                                                               'type': 'ARFCN-ValueEUTRA'},
                                                                                              {'name': 'ul-Bandwidth',
                                                                                               'optional': True,
                                                                                               'type': 'ENUMERATED',
                                                                                               'values': [('n6',
                                                                                                           0),
                                                                                                          ('n15',
                                                                                                           1),
                                                                                                          ('n25',
                                                                                                           2),
                                                                                                          ('n50',
                                                                                                           3),
                                                                                                          ('n75',
                                                                                                           4),
                                                                                                          ('n100',
                                                                                                           5)]},
                                                                                              {'name': 'additionalSpectrumEmission',
                                                                                               'type': 'AdditionalSpectrumEmission'}],
                                                                                  'name': 'freqInfo',
                                                                                  'type': 'SEQUENCE'},
                                                                                 {'name': 'mbsfn-SubframeConfigList',
                                                                                  'optional': True,
                                                                                  'type': 'MBSFN-SubframeConfigList'},
                                                                                 {'name': 'timeAlignmentTimerCommon',
                                                                                  'type': 'TimeAlignmentTimer'},
                                                                                 None],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType3': {'members': [{'members': [{'name': 'q-Hyst',
                                                                                               'type': 'ENUMERATED',
                                                                                               'values': [('dB0',
                                                                                                           0),
                                                                                                          ('dB1',
                                                                                                           1),
                                                                                                          ('dB2',
                                                                                                           2),
                                                                                                          ('dB3',
                                                                                                           3),
                                                                                                          ('dB4',
                                                                                                           4),
                                                                                                          ('dB5',
                                                                                                           5),
                                                                                                          ('dB6',
                                                                                                           6),
                                                                                                          ('dB8',
                                                                                                           7),
                                                                                                          ('dB10',
                                                                                                           8),
                                                                                                          ('dB12',
                                                                                                           9),
                                                                                                          ('dB14',
                                                                                                           10),
                                                                                                          ('dB16',
                                                                                                           11),
                                                                                                          ('dB18',
                                                                                                           12),
                                                                                                          ('dB20',
                                                                                                           13),
                                                                                                          ('dB22',
                                                                                                           14),
                                                                                                          ('dB24',
                                                                                                           15)]},
                                                                                              {'members': [{'name': 'mobilityStateParameters',
                                                                                                            'type': 'MobilityStateParameters'},
                                                                                                           {'members': [{'name': 'sf-Medium',
                                                                                                                         'type': 'ENUMERATED',
                                                                                                                         'values': [('dB-6',
                                                                                                                                     0),
                                                                                                                                    ('dB-4',
                                                                                                                                     1),
                                                                                                                                    ('dB-2',
                                                                                                                                     2),
                                                                                                                                    ('dB0',
                                                                                                                                     3)]},
                                                                                                                        {'name': 'sf-High',
                                                                                                                         'type': 'ENUMERATED',
                                                                                                                         'values': [('dB-6',
                                                                                                                                     0),
                                                                                                                                    ('dB-4',
                                                                                                                                     1),
                                                                                                                                    ('dB-2',
                                                                                                                                     2),
                                                                                                                                    ('dB0',
                                                                                                                                     3)]}],
                                                                                                            'name': 'q-HystSF',
                                                                                                            'type': 'SEQUENCE'}],
                                                                                               'name': 'speedStateReselectionPars',
                                                                                               'optional': True,
                                                                                               'type': 'SEQUENCE'}],
                                                                                  'name': 'cellReselectionInfoCommon',
                                                                                  'type': 'SEQUENCE'},
                                                                                 {'members': [{'name': 's-NonIntraSearch',
                                                                                               'optional': True,
                                                                                               'type': 'ReselectionThreshold'},
                                                                                              {'name': 'threshServingLow',
                                                                                               'type': 'ReselectionThreshold'},
                                                                                              {'name': 'cellReselectionPriority',
                                                                                               'type': 'CellReselectionPriority'}],
                                                                                  'name': 'cellReselectionServingFreqInfo',
                                                                                  'type': 'SEQUENCE'},
                                                                                 {'members': [{'name': 'q-RxLevMin',
                                                                                               'type': 'Q-RxLevMin'},
                                                                                              {'name': 'p-Max',
                                                                                               'optional': True,
                                                                                               'type': 'P-Max'},
                                                                                              {'name': 's-IntraSearch',
                                                                                               'optional': True,
                                                                                               'type': 'ReselectionThreshold'},
                                                                                              {'name': 'allowedMeasBandwidth',
                                                                                               'optional': True,
                                                                                               'type': 'AllowedMeasBandwidth'},
                                                                                              {'name': 'presenceAntennaPort1',
                                                                                               'type': 'PresenceAntennaPort1'},
                                                                                              {'name': 'neighCellConfig',
                                                                                               'type': 'NeighCellConfig'},
                                                                                              {'name': 't-ReselectionEUTRA',
                                                                                               'type': 'T-Reselection'},
                                                                                              {'name': 't-ReselectionEUTRA-SF',
                                                                                               'optional': True,
                                                                                               'type': 'SpeedStateScaleFactors'}],
                                                                                  'name': 'intraFreqCellReselectionInfo',
                                                                                  'type': 'SEQUENCE'},
                                                                                 None],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType4': {'members': [{'name': 'intraFreqNeighCellList',
                                                                                  'optional': True,
                                                                                  'type': 'IntraFreqNeighCellList'},
                                                                                 {'name': 'intraFreqBlackCellList',
                                                                                  'optional': True,
                                                                                  'type': 'IntraFreqBlackCellList'},
                                                                                 {'name': 'csg-PhysCellIdRange',
                                                                                  'optional': True,
                                                                                  'type': 'PhysCellIdRange'},
                                                                                 None],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType5': {'members': [{'name': 'interFreqCarrierFreqList',
                                                                                  'type': 'InterFreqCarrierFreqList'},
                                                                                 None],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType6': {'members': [{'name': 'carrierFreqListUTRA-FDD',
                                                                                  'optional': True,
                                                                                  'type': 'CarrierFreqListUTRA-FDD'},
                                                                                 {'name': 'carrierFreqListUTRA-TDD',
                                                                                  'optional': True,
                                                                                  'type': 'CarrierFreqListUTRA-TDD'},
                                                                                 {'name': 't-ReselectionUTRA',
                                                                                  'type': 'T-Reselection'},
                                                                                 {'name': 't-ReselectionUTRA-SF',
                                                                                  'optional': True,
                                                                                  'type': 'SpeedStateScaleFactors'},
                                                                                 None],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType7': {'members': [{'name': 't-ReselectionGERAN',
                                                                                  'type': 'T-Reselection'},
                                                                                 {'name': 't-ReselectionGERAN-SF',
                                                                                  'optional': True,
                                                                                  'type': 'SpeedStateScaleFactors'},
                                                                                 {'name': 'carrierFreqsInfoList',
                                                                                  'optional': True,
                                                                                  'type': 'CarrierFreqsInfoListGERAN'},
                                                                                 None],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType8': {'members': [{'name': 'systemTimeInfo',
                                                                                  'optional': True,
                                                                                  'type': 'SystemTimeInfoCDMA2000'},
                                                                                 {'name': 'searchWindowSize',
                                                                                  'optional': True,
                                                                                  'restricted-to': [(0,
                                                                                                     15)],
                                                                                  'type': 'INTEGER'},
                                                                                 {'members': [{'name': 'preRegistrationInfoHRPD',
                                                                                               'type': 'PreRegistrationInfoHRPD'},
                                                                                              {'name': 'cellReselectionParametersHRPD',
                                                                                               'optional': True,
                                                                                               'type': 'CellReselectionParametersCDMA2000'}],
                                                                                  'name': 'parametersHRPD',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'},
                                                                                 {'members': [{'name': 'csfb-RegistrationParam1XRTT',
                                                                                               'optional': True,
                                                                                               'type': 'CSFB-RegistrationParam1XRTT'},
                                                                                              {'name': 'longCodeState1XRTT',
                                                                                               'optional': True,
                                                                                               'size': [42],
                                                                                               'type': 'BIT '
                                                                                                       'STRING'},
                                                                                              {'name': 'cellReselectionParameters1XRTT',
                                                                                               'optional': True,
                                                                                               'type': 'CellReselectionParametersCDMA2000'}],
                                                                                  'name': 'parameters1XRTT',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'},
                                                                                 None],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType9': {'members': [{'name': 'hnb-Name',
                                                                                  'optional': True,
                                                                                  'size': [(1,
                                                                                            48)],
                                                                                  'type': 'OCTET '
                                                                                          'STRING'},
                                                                                 None],
                                                                     'type': 'SEQUENCE'},
                                     'SystemTimeInfoCDMA2000': {'members': [{'name': 'cdma-EUTRA-Synchronisation',
                                                                             'type': 'BOOLEAN'},
                                                                            {'members': [{'name': 'synchronousSystemTime',
                                                                                          'size': [39],
                                                                                          'type': 'BIT '
                                                                                                  'STRING'},
                                                                                         {'name': 'asynchronousSystemTime',
                                                                                          'size': [49],
                                                                                          'type': 'BIT '
                                                                                                  'STRING'}],
                                                                             'name': 'cdma-SystemTime',
                                                                             'type': 'CHOICE'}],
                                                                'type': 'SEQUENCE'},
                                     'T-PollRetransmit': {'type': 'ENUMERATED',
                                                          'values': [('ms5', 0),
                                                                     ('ms10',
                                                                      1),
                                                                     ('ms15',
                                                                      2),
                                                                     ('ms20',
                                                                      3),
                                                                     ('ms25',
                                                                      4),
                                                                     ('ms30',
                                                                      5),
                                                                     ('ms35',
                                                                      6),
                                                                     ('ms40',
                                                                      7),
                                                                     ('ms45',
                                                                      8),
                                                                     ('ms50',
                                                                      9),
                                                                     ('ms55',
                                                                      10),
                                                                     ('ms60',
                                                                      11),
                                                                     ('ms65',
                                                                      12),
                                                                     ('ms70',
                                                                      13),
                                                                     ('ms75',
                                                                      14),
                                                                     ('ms80',
                                                                      15),
                                                                     ('ms85',
                                                                      16),
                                                                     ('ms90',
                                                                      17),
                                                                     ('ms95',
                                                                      18),
                                                                     ('ms100',
                                                                      19),
                                                                     ('ms105',
                                                                      20),
                                                                     ('ms110',
                                                                      21),
                                                                     ('ms115',
                                                                      22),
                                                                     ('ms120',
                                                                      23),
                                                                     ('ms125',
                                                                      24),
                                                                     ('ms130',
                                                                      25),
                                                                     ('ms135',
                                                                      26),
                                                                     ('ms140',
                                                                      27),
                                                                     ('ms145',
                                                                      28),
                                                                     ('ms150',
                                                                      29),
                                                                     ('ms155',
                                                                      30),
                                                                     ('ms160',
                                                                      31),
                                                                     ('ms165',
                                                                      32),
                                                                     ('ms170',
                                                                      33),
                                                                     ('ms175',
                                                                      34),
                                                                     ('ms180',
                                                                      35),
                                                                     ('ms185',
                                                                      36),
                                                                     ('ms190',
                                                                      37),
                                                                     ('ms195',
                                                                      38),
                                                                     ('ms200',
                                                                      39),
                                                                     ('ms205',
                                                                      40),
                                                                     ('ms210',
                                                                      41),
                                                                     ('ms215',
                                                                      42),
                                                                     ('ms220',
                                                                      43),
                                                                     ('ms225',
                                                                      44),
                                                                     ('ms230',
                                                                      45),
                                                                     ('ms235',
                                                                      46),
                                                                     ('ms240',
                                                                      47),
                                                                     ('ms245',
                                                                      48),
                                                                     ('ms250',
                                                                      49),
                                                                     ('ms300',
                                                                      50),
                                                                     ('ms350',
                                                                      51),
                                                                     ('ms400',
                                                                      52),
                                                                     ('ms450',
                                                                      53),
                                                                     ('ms500',
                                                                      54),
                                                                     ('spare9',
                                                                      55),
                                                                     ('spare8',
                                                                      56),
                                                                     ('spare7',
                                                                      57),
                                                                     ('spare6',
                                                                      58),
                                                                     ('spare5',
                                                                      59),
                                                                     ('spare4',
                                                                      60),
                                                                     ('spare3',
                                                                      61),
                                                                     ('spare2',
                                                                      62),
                                                                     ('spare1',
                                                                      63)]},
                                     'T-Reordering': {'type': 'ENUMERATED',
                                                      'values': [('ms0', 0),
                                                                 ('ms5', 1),
                                                                 ('ms10', 2),
                                                                 ('ms15', 3),
                                                                 ('ms20', 4),
                                                                 ('ms25', 5),
                                                                 ('ms30', 6),
                                                                 ('ms35', 7),
                                                                 ('ms40', 8),
                                                                 ('ms45', 9),
                                                                 ('ms50', 10),
                                                                 ('ms55', 11),
                                                                 ('ms60', 12),
                                                                 ('ms65', 13),
                                                                 ('ms70', 14),
                                                                 ('ms75', 15),
                                                                 ('ms80', 16),
                                                                 ('ms85', 17),
                                                                 ('ms90', 18),
                                                                 ('ms95', 19),
                                                                 ('ms100', 20),
                                                                 ('ms110', 21),
                                                                 ('ms120', 22),
                                                                 ('ms130', 23),
                                                                 ('ms140', 24),
                                                                 ('ms150', 25),
                                                                 ('ms160', 26),
                                                                 ('ms170', 27),
                                                                 ('ms180', 28),
                                                                 ('ms190', 29),
                                                                 ('ms200', 30),
                                                                 ('spare1',
                                                                  31)]},
                                     'T-Reselection': {'restricted-to': [(0,
                                                                          7)],
                                                       'type': 'INTEGER'},
                                     'T-StatusProhibit': {'type': 'ENUMERATED',
                                                          'values': [('ms0', 0),
                                                                     ('ms5', 1),
                                                                     ('ms10',
                                                                      2),
                                                                     ('ms15',
                                                                      3),
                                                                     ('ms20',
                                                                      4),
                                                                     ('ms25',
                                                                      5),
                                                                     ('ms30',
                                                                      6),
                                                                     ('ms35',
                                                                      7),
                                                                     ('ms40',
                                                                      8),
                                                                     ('ms45',
                                                                      9),
                                                                     ('ms50',
                                                                      10),
                                                                     ('ms55',
                                                                      11),
                                                                     ('ms60',
                                                                      12),
                                                                     ('ms65',
                                                                      13),
                                                                     ('ms70',
                                                                      14),
                                                                     ('ms75',
                                                                      15),
                                                                     ('ms80',
                                                                      16),
                                                                     ('ms85',
                                                                      17),
                                                                     ('ms90',
                                                                      18),
                                                                     ('ms95',
                                                                      19),
                                                                     ('ms100',
                                                                      20),
                                                                     ('ms105',
                                                                      21),
                                                                     ('ms110',
                                                                      22),
                                                                     ('ms115',
                                                                      23),
                                                                     ('ms120',
                                                                      24),
                                                                     ('ms125',
                                                                      25),
                                                                     ('ms130',
                                                                      26),
                                                                     ('ms135',
                                                                      27),
                                                                     ('ms140',
                                                                      28),
                                                                     ('ms145',
                                                                      29),
                                                                     ('ms150',
                                                                      30),
                                                                     ('ms155',
                                                                      31),
                                                                     ('ms160',
                                                                      32),
                                                                     ('ms165',
                                                                      33),
                                                                     ('ms170',
                                                                      34),
                                                                     ('ms175',
                                                                      35),
                                                                     ('ms180',
                                                                      36),
                                                                     ('ms185',
                                                                      37),
                                                                     ('ms190',
                                                                      38),
                                                                     ('ms195',
                                                                      39),
                                                                     ('ms200',
                                                                      40),
                                                                     ('ms205',
                                                                      41),
                                                                     ('ms210',
                                                                      42),
                                                                     ('ms215',
                                                                      43),
                                                                     ('ms220',
                                                                      44),
                                                                     ('ms225',
                                                                      45),
                                                                     ('ms230',
                                                                      46),
                                                                     ('ms235',
                                                                      47),
                                                                     ('ms240',
                                                                      48),
                                                                     ('ms245',
                                                                      49),
                                                                     ('ms250',
                                                                      50),
                                                                     ('ms300',
                                                                      51),
                                                                     ('ms350',
                                                                      52),
                                                                     ('ms400',
                                                                      53),
                                                                     ('ms450',
                                                                      54),
                                                                     ('ms500',
                                                                      55),
                                                                     ('spare8',
                                                                      56),
                                                                     ('spare7',
                                                                      57),
                                                                     ('spare6',
                                                                      58),
                                                                     ('spare5',
                                                                      59),
                                                                     ('spare4',
                                                                      60),
                                                                     ('spare3',
                                                                      61),
                                                                     ('spare2',
                                                                      62),
                                                                     ('spare1',
                                                                      63)]},
                                     'TDD-Config': {'members': [{'name': 'subframeAssignment',
                                                                 'type': 'ENUMERATED',
                                                                 'values': [('sa0',
                                                                             0),
                                                                            ('sa1',
                                                                             1),
                                                                            ('sa2',
                                                                             2),
                                                                            ('sa3',
                                                                             3),
                                                                            ('sa4',
                                                                             4),
                                                                            ('sa5',
                                                                             5),
                                                                            ('sa6',
                                                                             6)]},
                                                                {'name': 'specialSubframePatterns',
                                                                 'type': 'ENUMERATED',
                                                                 'values': [('ssp0',
                                                                             0),
                                                                            ('ssp1',
                                                                             1),
                                                                            ('ssp2',
                                                                             2),
                                                                            ('ssp3',
                                                                             3),
                                                                            ('ssp4',
                                                                             4),
                                                                            ('ssp5',
                                                                             5),
                                                                            ('ssp6',
                                                                             6),
                                                                            ('ssp7',
                                                                             7),
                                                                            ('ssp8',
                                                                             8)]}],
                                                    'type': 'SEQUENCE'},
                                     'TPC-Index': {'members': [{'name': 'indexOfFormat3',
                                                                'restricted-to': [(1,
                                                                                   15)],
                                                                'type': 'INTEGER'},
                                                               {'name': 'indexOfFormat3A',
                                                                'restricted-to': [(1,
                                                                                   31)],
                                                                'type': 'INTEGER'}],
                                                   'type': 'CHOICE'},
                                     'TPC-PDCCH-Config': {'members': [{'name': 'release',
                                                                       'type': 'NULL'},
                                                                      {'members': [{'name': 'tpc-RNTI',
                                                                                    'size': [16],
                                                                                    'type': 'BIT '
                                                                                            'STRING'},
                                                                                   {'name': 'tpc-Index',
                                                                                    'type': 'TPC-Index'}],
                                                                       'name': 'setup',
                                                                       'type': 'SEQUENCE'}],
                                                          'type': 'CHOICE'},
                                     'ThresholdCDMA2000': {'restricted-to': [(0,
                                                                              63)],
                                                           'type': 'INTEGER'},
                                     'ThresholdEUTRA': {'members': [{'name': 'threshold-RSRP',
                                                                     'type': 'RSRP-Range'},
                                                                    {'name': 'threshold-RSRQ',
                                                                     'type': 'RSRQ-Range'}],
                                                        'type': 'CHOICE'},
                                     'ThresholdGERAN': {'restricted-to': [(0,
                                                                           63)],
                                                        'type': 'INTEGER'},
                                     'ThresholdUTRA': {'members': [{'name': 'utra-RSCP',
                                                                    'restricted-to': [(-5,
                                                                                       91)],
                                                                    'type': 'INTEGER'},
                                                                   {'name': 'utra-EcN0',
                                                                    'restricted-to': [(0,
                                                                                       49)],
                                                                    'type': 'INTEGER'}],
                                                       'type': 'CHOICE'},
                                     'TimeAlignmentTimer': {'type': 'ENUMERATED',
                                                            'values': [('sf500',
                                                                        0),
                                                                       ('sf750',
                                                                        1),
                                                                       ('sf1280',
                                                                        2),
                                                                       ('sf1920',
                                                                        3),
                                                                       ('sf2560',
                                                                        4),
                                                                       ('sf5120',
                                                                        5),
                                                                       ('sf10240',
                                                                        6),
                                                                       ('infinity',
                                                                        7)]},
                                     'TimeToTrigger': {'type': 'ENUMERATED',
                                                       'values': [('ms0', 0),
                                                                  ('ms40', 1),
                                                                  ('ms64', 2),
                                                                  ('ms80', 3),
                                                                  ('ms100', 4),
                                                                  ('ms128', 5),
                                                                  ('ms160', 6),
                                                                  ('ms256', 7),
                                                                  ('ms320', 8),
                                                                  ('ms480', 9),
                                                                  ('ms512', 10),
                                                                  ('ms640', 11),
                                                                  ('ms1024',
                                                                   12),
                                                                  ('ms1280',
                                                                   13),
                                                                  ('ms2560',
                                                                   14),
                                                                  ('ms5120',
                                                                   15)]},
                                     'TrackingAreaCode': {'size': [16],
                                                          'type': 'BIT STRING'},
                                     'UE-CapabilityRAT-Container': {'members': [{'name': 'rat-Type',
                                                                                 'type': 'RAT-Type'},
                                                                                {'name': 'ueCapabilityRAT-Container',
                                                                                 'type': 'OCTET '
                                                                                         'STRING'}],
                                                                    'type': 'SEQUENCE'},
                                     'UE-CapabilityRAT-ContainerList': {'element': {'type': 'UE-CapabilityRAT-Container'},
                                                                        'size': [(0,
                                                                                  'maxRAT-Capabilities')],
                                                                        'type': 'SEQUENCE '
                                                                                'OF'},
                                     'UE-CapabilityRequest': {'element': {'type': 'RAT-Type'},
                                                              'size': [(1,
                                                                        'maxRAT-Capabilities')],
                                                              'type': 'SEQUENCE '
                                                                      'OF'},
                                     'UE-EUTRA-Capability': {'members': [{'name': 'accessStratumRelease',
                                                                          'type': 'AccessStratumRelease'},
                                                                         {'name': 'ue-Category',
                                                                          'restricted-to': [(1,
                                                                                             5)],
                                                                          'type': 'INTEGER'},
                                                                         {'name': 'pdcp-Parameters',
                                                                          'type': 'PDCP-Parameters'},
                                                                         {'name': 'phyLayerParameters',
                                                                          'type': 'PhyLayerParameters'},
                                                                         {'name': 'rf-Parameters',
                                                                          'type': 'RF-Parameters'},
                                                                         {'name': 'measParameters',
                                                                          'type': 'MeasParameters'},
                                                                         {'name': 'featureGroupIndicators',
                                                                          'optional': True,
                                                                          'size': [32],
                                                                          'type': 'BIT '
                                                                                  'STRING'},
                                                                         {'members': [{'name': 'utraFDD',
                                                                                       'optional': True,
                                                                                       'type': 'IRAT-ParametersUTRA-FDD'},
                                                                                      {'name': 'utraTDD128',
                                                                                       'optional': True,
                                                                                       'type': 'IRAT-ParametersUTRA-TDD128'},
                                                                                      {'name': 'utraTDD384',
                                                                                       'optional': True,
                                                                                       'type': 'IRAT-ParametersUTRA-TDD384'},
                                                                                      {'name': 'utraTDD768',
                                                                                       'optional': True,
                                                                                       'type': 'IRAT-ParametersUTRA-TDD768'},
                                                                                      {'name': 'geran',
                                                                                       'optional': True,
                                                                                       'type': 'IRAT-ParametersGERAN'},
                                                                                      {'name': 'cdma2000-HRPD',
                                                                                       'optional': True,
                                                                                       'type': 'IRAT-ParametersCDMA2000-HRPD'},
                                                                                      {'name': 'cdma2000-1xRTT',
                                                                                       'optional': True,
                                                                                       'type': 'IRAT-ParametersCDMA2000-1XRTT'}],
                                                                          'name': 'interRAT-Parameters',
                                                                          'type': 'SEQUENCE'},
                                                                         {'members': [],
                                                                          'name': 'nonCriticalExtension',
                                                                          'optional': True,
                                                                          'type': 'SEQUENCE'}],
                                                             'type': 'SEQUENCE'},
                                     'UE-TimersAndConstants': {'members': [{'name': 't300',
                                                                            'type': 'ENUMERATED',
                                                                            'values': [('ms100',
                                                                                        0),
                                                                                       ('ms200',
                                                                                        1),
                                                                                       ('ms300',
                                                                                        2),
                                                                                       ('ms400',
                                                                                        3),
                                                                                       ('ms600',
                                                                                        4),
                                                                                       ('ms1000',
                                                                                        5),
                                                                                       ('ms1500',
                                                                                        6),
                                                                                       ('ms2000',
                                                                                        7)]},
                                                                           {'name': 't301',
                                                                            'type': 'ENUMERATED',
                                                                            'values': [('ms100',
                                                                                        0),
                                                                                       ('ms200',
                                                                                        1),
                                                                                       ('ms300',
                                                                                        2),
                                                                                       ('ms400',
                                                                                        3),
                                                                                       ('ms600',
                                                                                        4),
                                                                                       ('ms1000',
                                                                                        5),
                                                                                       ('ms1500',
                                                                                        6),
                                                                                       ('ms2000',
                                                                                        7)]},
                                                                           {'name': 't310',
                                                                            'type': 'ENUMERATED',
                                                                            'values': [('ms0',
                                                                                        0),
                                                                                       ('ms50',
                                                                                        1),
                                                                                       ('ms100',
                                                                                        2),
                                                                                       ('ms200',
                                                                                        3),
                                                                                       ('ms500',
                                                                                        4),
                                                                                       ('ms1000',
                                                                                        5),
                                                                                       ('ms2000',
                                                                                        6)]},
                                                                           {'name': 'n310',
                                                                            'type': 'ENUMERATED',
                                                                            'values': [('n1',
                                                                                        0),
                                                                                       ('n2',
                                                                                        1),
                                                                                       ('n3',
                                                                                        2),
                                                                                       ('n4',
                                                                                        3),
                                                                                       ('n6',
                                                                                        4),
                                                                                       ('n8',
                                                                                        5),
                                                                                       ('n10',
                                                                                        6),
                                                                                       ('n20',
                                                                                        7)]},
                                                                           {'name': 't311',
                                                                            'type': 'ENUMERATED',
                                                                            'values': [('ms1000',
                                                                                        0),
                                                                                       ('ms3000',
                                                                                        1),
                                                                                       ('ms5000',
                                                                                        2),
                                                                                       ('ms10000',
                                                                                        3),
                                                                                       ('ms15000',
                                                                                        4),
                                                                                       ('ms20000',
                                                                                        5),
                                                                                       ('ms30000',
                                                                                        6)]},
                                                                           {'name': 'n311',
                                                                            'type': 'ENUMERATED',
                                                                            'values': [('n1',
                                                                                        0),
                                                                                       ('n2',
                                                                                        1),
                                                                                       ('n3',
                                                                                        2),
                                                                                       ('n4',
                                                                                        3),
                                                                                       ('n5',
                                                                                        4),
                                                                                       ('n6',
                                                                                        5),
                                                                                       ('n8',
                                                                                        6),
                                                                                       ('n10',
                                                                                        7)]},
                                                                           None],
                                                               'type': 'SEQUENCE'},
                                     'UECapabilityEnquiry': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                          'type': 'RRC-TransactionIdentifier'},
                                                                         {'members': [{'members': [{'name': 'ueCapabilityEnquiry-r8',
                                                                                                    'type': 'UECapabilityEnquiry-r8-IEs'},
                                                                                                   {'name': 'spare3',
                                                                                                    'type': 'NULL'},
                                                                                                   {'name': 'spare2',
                                                                                                    'type': 'NULL'},
                                                                                                   {'name': 'spare1',
                                                                                                    'type': 'NULL'}],
                                                                                       'name': 'c1',
                                                                                       'type': 'CHOICE'},
                                                                                      {'members': [],
                                                                                       'name': 'criticalExtensionsFuture',
                                                                                       'type': 'SEQUENCE'}],
                                                                          'name': 'criticalExtensions',
                                                                          'type': 'CHOICE'}],
                                                             'type': 'SEQUENCE'},
                                     'UECapabilityEnquiry-r8-IEs': {'members': [{'name': 'ue-CapabilityRequest',
                                                                                 'type': 'UE-CapabilityRequest'},
                                                                                {'members': [],
                                                                                 'name': 'nonCriticalExtension',
                                                                                 'optional': True,
                                                                                 'type': 'SEQUENCE'}],
                                                                    'type': 'SEQUENCE'},
                                     'UECapabilityInformation': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                              'type': 'RRC-TransactionIdentifier'},
                                                                             {'members': [{'members': [{'name': 'ueCapabilityInformation-r8',
                                                                                                        'type': 'UECapabilityInformation-r8-IEs'},
                                                                                                       {'name': 'spare7',
                                                                                                        'type': 'NULL'},
                                                                                                       {'name': 'spare6',
                                                                                                        'type': 'NULL'},
                                                                                                       {'name': 'spare5',
                                                                                                        'type': 'NULL'},
                                                                                                       {'name': 'spare4',
                                                                                                        'type': 'NULL'},
                                                                                                       {'name': 'spare3',
                                                                                                        'type': 'NULL'},
                                                                                                       {'name': 'spare2',
                                                                                                        'type': 'NULL'},
                                                                                                       {'name': 'spare1',
                                                                                                        'type': 'NULL'}],
                                                                                           'name': 'c1',
                                                                                           'type': 'CHOICE'},
                                                                                          {'members': [],
                                                                                           'name': 'criticalExtensionsFuture',
                                                                                           'type': 'SEQUENCE'}],
                                                                              'name': 'criticalExtensions',
                                                                              'type': 'CHOICE'}],
                                                                 'type': 'SEQUENCE'},
                                     'UECapabilityInformation-r8-IEs': {'members': [{'name': 'ue-CapabilityRAT-ContainerList',
                                                                                     'type': 'UE-CapabilityRAT-ContainerList'},
                                                                                    {'members': [],
                                                                                     'name': 'nonCriticalExtension',
                                                                                     'optional': True,
                                                                                     'type': 'SEQUENCE'}],
                                                                        'type': 'SEQUENCE'},
                                     'UL-AM-RLC': {'members': [{'name': 't-PollRetransmit',
                                                                'type': 'T-PollRetransmit'},
                                                               {'name': 'pollPDU',
                                                                'type': 'PollPDU'},
                                                               {'name': 'pollByte',
                                                                'type': 'PollByte'},
                                                               {'name': 'maxRetxThreshold',
                                                                'type': 'ENUMERATED',
                                                                'values': [('t1',
                                                                            0),
                                                                           ('t2',
                                                                            1),
                                                                           ('t3',
                                                                            2),
                                                                           ('t4',
                                                                            3),
                                                                           ('t6',
                                                                            4),
                                                                           ('t8',
                                                                            5),
                                                                           ('t16',
                                                                            6),
                                                                           ('t32',
                                                                            7)]}],
                                                   'type': 'SEQUENCE'},
                                     'UL-CCCH-Message': {'members': [{'name': 'message',
                                                                      'type': 'UL-CCCH-MessageType'}],
                                                         'type': 'SEQUENCE'},
                                     'UL-CCCH-MessageType': {'members': [{'members': [{'name': 'rrcConnectionReestablishmentRequest',
                                                                                       'type': 'RRCConnectionReestablishmentRequest'},
                                                                                      {'name': 'rrcConnectionRequest',
                                                                                       'type': 'RRCConnectionRequest'}],
                                                                          'name': 'c1',
                                                                          'type': 'CHOICE'},
                                                                         {'members': [],
                                                                          'name': 'messageClassExtension',
                                                                          'type': 'SEQUENCE'}],
                                                             'type': 'CHOICE'},
                                     'UL-CyclicPrefixLength': {'type': 'ENUMERATED',
                                                               'values': [('len1',
                                                                           0),
                                                                          ('len2',
                                                                           1)]},
                                     'UL-DCCH-Message': {'members': [{'name': 'message',
                                                                      'type': 'UL-DCCH-MessageType'}],
                                                         'type': 'SEQUENCE'},
                                     'UL-DCCH-MessageType': {'members': [{'members': [{'name': 'csfbParametersRequestCDMA2000',
                                                                                       'type': 'CSFBParametersRequestCDMA2000'},
                                                                                      {'name': 'measurementReport',
                                                                                       'type': 'MeasurementReport'},
                                                                                      {'name': 'rrcConnectionReconfigurationComplete',
                                                                                       'type': 'RRCConnectionReconfigurationComplete'},
                                                                                      {'name': 'rrcConnectionReestablishmentComplete',
                                                                                       'type': 'RRCConnectionReestablishmentComplete'},
                                                                                      {'name': 'rrcConnectionSetupComplete',
                                                                                       'type': 'RRCConnectionSetupComplete'},
                                                                                      {'name': 'securityModeComplete',
                                                                                       'type': 'SecurityModeComplete'},
                                                                                      {'name': 'securityModeFailure',
                                                                                       'type': 'SecurityModeFailure'},
                                                                                      {'name': 'ueCapabilityInformation',
                                                                                       'type': 'UECapabilityInformation'},
                                                                                      {'name': 'ulHandoverPreparationTransfer',
                                                                                       'type': 'ULHandoverPreparationTransfer'},
                                                                                      {'name': 'ulInformationTransfer',
                                                                                       'type': 'ULInformationTransfer'},
                                                                                      {'name': 'counterCheckResponse',
                                                                                       'type': 'CounterCheckResponse'},
                                                                                      {'name': 'spare5',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare4',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare3',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare2',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare1',
                                                                                       'type': 'NULL'}],
                                                                          'name': 'c1',
                                                                          'type': 'CHOICE'},
                                                                         {'members': [],
                                                                          'name': 'messageClassExtension',
                                                                          'type': 'SEQUENCE'}],
                                                             'type': 'CHOICE'},
                                     'UL-ReferenceSignalsPUSCH': {'members': [{'name': 'groupHoppingEnabled',
                                                                               'type': 'BOOLEAN'},
                                                                              {'name': 'groupAssignmentPUSCH',
                                                                               'restricted-to': [(0,
                                                                                                  29)],
                                                                               'type': 'INTEGER'},
                                                                              {'name': 'sequenceHoppingEnabled',
                                                                               'type': 'BOOLEAN'},
                                                                              {'name': 'cyclicShift',
                                                                               'restricted-to': [(0,
                                                                                                  7)],
                                                                               'type': 'INTEGER'}],
                                                                  'type': 'SEQUENCE'},
                                     'UL-UM-RLC': {'members': [{'name': 'sn-FieldLength',
                                                                'type': 'SN-FieldLength'}],
                                                   'type': 'SEQUENCE'},
                                     'ULHandoverPreparationTransfer': {'members': [{'members': [{'members': [{'name': 'ulHandoverPreparationTransfer-r8',
                                                                                                              'type': 'ULHandoverPreparationTransfer-r8-IEs'},
                                                                                                             {'name': 'spare3',
                                                                                                              'type': 'NULL'},
                                                                                                             {'name': 'spare2',
                                                                                                              'type': 'NULL'},
                                                                                                             {'name': 'spare1',
                                                                                                              'type': 'NULL'}],
                                                                                                 'name': 'c1',
                                                                                                 'type': 'CHOICE'},
                                                                                                {'members': [],
                                                                                                 'name': 'criticalExtensionsFuture',
                                                                                                 'type': 'SEQUENCE'}],
                                                                                    'name': 'criticalExtensions',
                                                                                    'type': 'CHOICE'}],
                                                                       'type': 'SEQUENCE'},
                                     'ULHandoverPreparationTransfer-r8-IEs': {'members': [{'name': 'cdma2000-Type',
                                                                                           'type': 'CDMA2000-Type'},
                                                                                          {'name': 'meid',
                                                                                           'optional': True,
                                                                                           'size': [56],
                                                                                           'type': 'BIT '
                                                                                                   'STRING'},
                                                                                          {'name': 'dedicatedInfo',
                                                                                           'type': 'DedicatedInfoCDMA2000'},
                                                                                          {'members': [],
                                                                                           'name': 'nonCriticalExtension',
                                                                                           'optional': True,
                                                                                           'type': 'SEQUENCE'}],
                                                                              'type': 'SEQUENCE'},
                                     'ULInformationTransfer': {'members': [{'members': [{'members': [{'name': 'ulInformationTransfer-r8',
                                                                                                      'type': 'ULInformationTransfer-r8-IEs'},
                                                                                                     {'name': 'spare3',
                                                                                                      'type': 'NULL'},
                                                                                                     {'name': 'spare2',
                                                                                                      'type': 'NULL'},
                                                                                                     {'name': 'spare1',
                                                                                                      'type': 'NULL'}],
                                                                                         'name': 'c1',
                                                                                         'type': 'CHOICE'},
                                                                                        {'members': [],
                                                                                         'name': 'criticalExtensionsFuture',
                                                                                         'type': 'SEQUENCE'}],
                                                                            'name': 'criticalExtensions',
                                                                            'type': 'CHOICE'}],
                                                               'type': 'SEQUENCE'},
                                     'ULInformationTransfer-r8-IEs': {'members': [{'members': [{'name': 'dedicatedInfoNAS',
                                                                                                'type': 'DedicatedInfoNAS'},
                                                                                               {'name': 'dedicatedInfoCDMA2000-1XRTT',
                                                                                                'type': 'DedicatedInfoCDMA2000'},
                                                                                               {'name': 'dedicatedInfoCDMA2000-HRPD',
                                                                                                'type': 'DedicatedInfoCDMA2000'}],
                                                                                   'name': 'dedicatedInfoType',
                                                                                   'type': 'CHOICE'},
                                                                                  {'members': [],
                                                                                   'name': 'nonCriticalExtension',
                                                                                   'optional': True,
                                                                                   'type': 'SEQUENCE'}],
                                                                      'type': 'SEQUENCE'},
                                     'UplinkPowerControlCommon': {'members': [{'name': 'p0-NominalPUSCH',
                                                                               'restricted-to': [(-126,
                                                                                                  24)],
                                                                               'type': 'INTEGER'},
                                                                              {'name': 'alpha',
                                                                               'type': 'ENUMERATED',
                                                                               'values': [('al0',
                                                                                           0),
                                                                                          ('al04',
                                                                                           1),
                                                                                          ('al05',
                                                                                           2),
                                                                                          ('al06',
                                                                                           3),
                                                                                          ('al07',
                                                                                           4),
                                                                                          ('al08',
                                                                                           5),
                                                                                          ('al09',
                                                                                           6),
                                                                                          ('al1',
                                                                                           7)]},
                                                                              {'name': 'p0-NominalPUCCH',
                                                                               'restricted-to': [(-127,
                                                                                                  -96)],
                                                                               'type': 'INTEGER'},
                                                                              {'name': 'deltaFList-PUCCH',
                                                                               'type': 'DeltaFList-PUCCH'},
                                                                              {'name': 'deltaPreambleMsg3',
                                                                               'restricted-to': [(-1,
                                                                                                  6)],
                                                                               'type': 'INTEGER'}],
                                                                  'type': 'SEQUENCE'},
                                     'UplinkPowerControlDedicated': {'members': [{'name': 'p0-UE-PUSCH',
                                                                                  'restricted-to': [(-8,
                                                                                                     7)],
                                                                                  'type': 'INTEGER'},
                                                                                 {'name': 'deltaMCS-Enabled',
                                                                                  'type': 'ENUMERATED',
                                                                                  'values': [('en0',
                                                                                              0),
                                                                                             ('en1',
                                                                                              1)]},
                                                                                 {'name': 'accumulationEnabled',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'p0-UE-PUCCH',
                                                                                  'restricted-to': [(-8,
                                                                                                     7)],
                                                                                  'type': 'INTEGER'},
                                                                                 {'name': 'pSRS-Offset',
                                                                                  'restricted-to': [(0,
                                                                                                     15)],
                                                                                  'type': 'INTEGER'},
                                                                                 {'default': 'fc4',
                                                                                  'name': 'filterCoefficient',
                                                                                  'type': 'FilterCoefficient'}],
                                                                     'type': 'SEQUENCE'}},
                           'values': {'maxBands': {'type': 'INTEGER',
                                                   'value': 64},
                                      'maxCDMA-BandClass': {'type': 'INTEGER',
                                                            'value': 32},
                                      'maxCellBlack': {'type': 'INTEGER',
                                                       'value': 16},
                                      'maxCellInter': {'type': 'INTEGER',
                                                       'value': 16},
                                      'maxCellIntra': {'type': 'INTEGER',
                                                       'value': 16},
                                      'maxCellMeas': {'type': 'INTEGER',
                                                      'value': 32},
                                      'maxCellReport': {'type': 'INTEGER',
                                                        'value': 8},
                                      'maxDRB': {'type': 'INTEGER',
                                                 'value': 11},
                                      'maxEARFCN': {'type': 'INTEGER',
                                                    'value': 65535},
                                      'maxFreq': {'type': 'INTEGER',
                                                  'value': 8},
                                      'maxGERAN-SI': {'type': 'INTEGER',
                                                      'value': 10},
                                      'maxGNFG': {'type': 'INTEGER',
                                                  'value': 16},
                                      'maxMBSFN-Allocations': {'type': 'INTEGER',
                                                               'value': 8},
                                      'maxMCS-1': {'type': 'INTEGER',
                                                   'value': 16},
                                      'maxMeasId': {'type': 'INTEGER',
                                                    'value': 32},
                                      'maxObjectId': {'type': 'INTEGER',
                                                      'value': 32},
                                      'maxPNOffset': {'type': 'INTEGER',
                                                      'value': 511},
                                      'maxPageRec': {'type': 'INTEGER',
                                                     'value': 16},
                                      'maxRAT-Capabilities': {'type': 'INTEGER',
                                                              'value': 8},
                                      'maxReportConfigId': {'type': 'INTEGER',
                                                            'value': 32},
                                      'maxSI-Message': {'type': 'INTEGER',
                                                        'value': 32},
                                      'maxSIB': {'type': 'INTEGER',
                                                 'value': 32},
                                      'maxSIB-1': {'type': 'INTEGER',
                                                   'value': 31},
                                      'maxUTRA-FDD-Carrier': {'type': 'INTEGER',
                                                              'value': 16},
                                      'maxUTRA-TDD-Carrier': {'type': 'INTEGER',
                                                              'value': 16}}},
 'EUTRA-UE-Variables': {'extensibility-implied': False,
                        'imports': {'EUTRA-RRC-Definitions': ['C-RNTI',
                                                              'CellIdentity',
                                                              'MeasId',
                                                              'MeasIdToAddModList',
                                                              'MeasObjectToAddModList',
                                                              'MobilityStateParameters',
                                                              'NeighCellConfig',
                                                              'PhysCellId',
                                                              'QuantityConfig',
                                                              'RSRP-Range',
                                                              'ReportConfigToAddModList',
                                                              'SpeedStateScaleFactors',
                                                              'maxCellMeas',
                                                              'maxMeasId']},
                        'object-classes': {},
                        'object-sets': {},
                        'tags': 'AUTOMATIC',
                        'types': {'CellsTriggeredList': {'element': {'type': 'PhysCellId'},
                                                         'size': [(1,
                                                                   'maxCellMeas')],
                                                         'type': 'SEQUENCE OF'},
                                  'VarMeasConfig': {'members': [{'name': 'measIdList',
                                                                 'optional': True,
                                                                 'type': 'MeasIdToAddModList'},
                                                                {'name': 'measObjectList',
                                                                 'optional': True,
                                                                 'type': 'MeasObjectToAddModList'},
                                                                {'name': 'reportConfigList',
                                                                 'optional': True,
                                                                 'type': 'ReportConfigToAddModList'},
                                                                {'name': 'quantityConfig',
                                                                 'optional': True,
                                                                 'type': 'QuantityConfig'},
                                                                {'name': 's-Measure',
                                                                 'optional': True,
                                                                 'type': 'RSRP-Range'},
                                                                {'members': [{'name': 'release',
                                                                              'type': 'NULL'},
                                                                             {'members': [{'name': 'mobilityStateParameters',
                                                                                           'type': 'MobilityStateParameters'},
                                                                                          {'name': 'timeToTrigger-SF',
                                                                                           'type': 'SpeedStateScaleFactors'}],
                                                                              'name': 'setup',
                                                                              'type': 'SEQUENCE'}],
                                                                 'name': 'speedStatePars',
                                                                 'optional': True,
                                                                 'type': 'CHOICE'}],
                                                    'type': 'SEQUENCE'},
                                  'VarMeasReport': {'members': [{'name': 'measId',
                                                                 'type': 'MeasId'},
                                                                {'name': 'cellsTriggeredList',
                                                                 'optional': True,
                                                                 'type': 'CellsTriggeredList'},
                                                                {'name': 'numberOfReportsSent',
                                                                 'type': 'INTEGER'}],
                                                    'type': 'SEQUENCE'},
                                  'VarMeasReportList': {'element': {'type': 'VarMeasReport'},
                                                        'size': [(1,
                                                                  'maxMeasId')],
                                                        'type': 'SEQUENCE OF'},
                                  'VarShortMAC-Input': {'members': [{'name': 'cellIdentity',
                                                                     'type': 'CellIdentity'},
                                                                    {'name': 'physCellId',
                                                                     'type': 'PhysCellId'},
                                                                    {'name': 'c-RNTI',
                                                                     'type': 'C-RNTI'}],
                                                        'type': 'SEQUENCE'}},
                        'values': {}}}